from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.HumanInterfaceDevice
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Registry
DIRECTINPUT_VERSION: UInt32 = 2048
JOY_HW_NONE: UInt32 = 0
JOY_HW_CUSTOM: UInt32 = 1
JOY_HW_2A_2B_GENERIC: UInt32 = 2
JOY_HW_2A_4B_GENERIC: UInt32 = 3
JOY_HW_2B_GAMEPAD: UInt32 = 4
JOY_HW_2B_FLIGHTYOKE: UInt32 = 5
JOY_HW_2B_FLIGHTYOKETHROTTLE: UInt32 = 6
JOY_HW_3A_2B_GENERIC: UInt32 = 7
JOY_HW_3A_4B_GENERIC: UInt32 = 8
JOY_HW_4B_GAMEPAD: UInt32 = 9
JOY_HW_4B_FLIGHTYOKE: UInt32 = 10
JOY_HW_4B_FLIGHTYOKETHROTTLE: UInt32 = 11
JOY_HW_TWO_2A_2B_WITH_Y: UInt32 = 12
JOY_HW_LASTENTRY: UInt32 = 13
JOY_ISCAL_XY: Int32 = 1
JOY_ISCAL_Z: Int32 = 2
JOY_ISCAL_R: Int32 = 4
JOY_ISCAL_U: Int32 = 8
JOY_ISCAL_V: Int32 = 16
JOY_ISCAL_POV: Int32 = 32
JOY_POV_NUMDIRS: UInt32 = 4
JOY_POVVAL_FORWARD: UInt32 = 0
JOY_POVVAL_BACKWARD: UInt32 = 1
JOY_POVVAL_LEFT: UInt32 = 2
JOY_POVVAL_RIGHT: UInt32 = 3
JOY_HWS_HASZ: Int32 = 1
JOY_HWS_HASPOV: Int32 = 2
JOY_HWS_POVISBUTTONCOMBOS: Int32 = 4
JOY_HWS_POVISPOLL: Int32 = 8
JOY_HWS_ISYOKE: Int32 = 16
JOY_HWS_ISGAMEPAD: Int32 = 32
JOY_HWS_ISCARCTRL: Int32 = 64
JOY_HWS_XISJ1Y: Int32 = 128
JOY_HWS_XISJ2X: Int32 = 256
JOY_HWS_XISJ2Y: Int32 = 512
JOY_HWS_YISJ1X: Int32 = 1024
JOY_HWS_YISJ2X: Int32 = 2048
JOY_HWS_YISJ2Y: Int32 = 4096
JOY_HWS_ZISJ1X: Int32 = 8192
JOY_HWS_ZISJ1Y: Int32 = 16384
JOY_HWS_ZISJ2X: Int32 = 32768
JOY_HWS_POVISJ1X: Int32 = 65536
JOY_HWS_POVISJ1Y: Int32 = 131072
JOY_HWS_POVISJ2X: Int32 = 262144
JOY_HWS_HASR: Int32 = 524288
JOY_HWS_RISJ1X: Int32 = 1048576
JOY_HWS_RISJ1Y: Int32 = 2097152
JOY_HWS_RISJ2Y: Int32 = 4194304
JOY_HWS_HASU: Int32 = 8388608
JOY_HWS_HASV: Int32 = 16777216
JOY_US_HASRUDDER: Int32 = 1
JOY_US_PRESENT: Int32 = 2
JOY_US_ISOEM: Int32 = 4
JOY_US_RESERVED: Int32 = -2147483648
JOYTYPE_ZEROGAMEENUMOEMDATA: Int32 = 1
JOYTYPE_NOAUTODETECTGAMEPORT: Int32 = 2
JOYTYPE_NOHIDDIRECT: Int32 = 4
JOYTYPE_ANALOGCOMPAT: Int32 = 8
JOYTYPE_DEFAULTPROPSHEET: Int32 = -2147483648
JOYTYPE_DEVICEHIDE: Int32 = 65536
JOYTYPE_MOUSEHIDE: Int32 = 131072
JOYTYPE_KEYBHIDE: Int32 = 262144
JOYTYPE_GAMEHIDE: Int32 = 524288
JOYTYPE_HIDEACTIVE: Int32 = 1048576
JOYTYPE_INFOMASK: Int32 = 14680064
JOYTYPE_INFODEFAULT: Int32 = 0
JOYTYPE_INFOYYPEDALS: Int32 = 2097152
JOYTYPE_INFOZYPEDALS: Int32 = 4194304
JOYTYPE_INFOYRPEDALS: Int32 = 6291456
JOYTYPE_INFOZRPEDALS: Int32 = 8388608
JOYTYPE_INFOZISSLIDER: Int32 = 2097152
JOYTYPE_INFOZISZ: Int32 = 4194304
JOYTYPE_ENABLEINPUTREPORT: Int32 = 16777216
MAX_JOYSTRING: UInt32 = 256
MAX_JOYSTICKOEMVXDNAME: UInt32 = 260
DITC_REGHWSETTINGS: UInt32 = 1
DITC_CLSIDCONFIG: UInt32 = 2
DITC_DISPLAYNAME: UInt32 = 4
DITC_CALLOUT: UInt32 = 8
DITC_HARDWAREID: UInt32 = 16
DITC_FLAGS1: UInt32 = 32
DITC_FLAGS2: UInt32 = 64
DITC_MAPFILE: UInt32 = 128
DIJC_GUIDINSTANCE: UInt32 = 1
DIJC_REGHWCONFIGTYPE: UInt32 = 2
DIJC_GAIN: UInt32 = 4
DIJC_CALLOUT: UInt32 = 8
DIJC_WDMGAMEPORT: UInt32 = 16
DIJU_USERVALUES: UInt32 = 1
DIJU_GLOBALDRIVER: UInt32 = 2
DIJU_GAMEPORTEMULATOR: UInt32 = 4
GUID_KeyboardClass: Guid = Guid('{4d36e96b-e325-11ce-bfc1-08002be10318}')
GUID_MediaClass: Guid = Guid('{4d36e96c-e325-11ce-bfc1-08002be10318}')
GUID_MouseClass: Guid = Guid('{4d36e96f-e325-11ce-bfc1-08002be10318}')
GUID_HIDClass: Guid = Guid('{745a17a0-74d3-11d0-b6fe-00a0c90f57da}')
DIRECTINPUT_NOTIFICATION_MSGSTRINGA: String = 'DIRECTINPUT_NOTIFICATION_MSGSTRING'
DIRECTINPUT_NOTIFICATION_MSGSTRINGW: String = 'DIRECTINPUT_NOTIFICATION_MSGSTRING'
DIRECTINPUT_NOTIFICATION_MSGSTRING: String = 'DIRECTINPUT_NOTIFICATION_MSGSTRING'
DIMSGWP_NEWAPPSTART: UInt32 = 1
DIMSGWP_DX8APPSTART: UInt32 = 2
DIMSGWP_DX8MAPPERAPPSTART: UInt32 = 3
DIAPPIDFLAG_NOTIME: UInt32 = 1
DIAPPIDFLAG_NOSIZE: UInt32 = 2
DIRECTINPUT_REGSTR_VAL_APPIDFLAGA: String = 'AppIdFlag'
DIRECTINPUT_REGSTR_KEY_LASTAPPA: String = 'MostRecentApplication'
DIRECTINPUT_REGSTR_KEY_LASTMAPAPPA: String = 'MostRecentMapperApplication'
DIRECTINPUT_REGSTR_VAL_VERSIONA: String = 'Version'
DIRECTINPUT_REGSTR_VAL_NAMEA: String = 'Name'
DIRECTINPUT_REGSTR_VAL_IDA: String = 'Id'
DIRECTINPUT_REGSTR_VAL_MAPPERA: String = 'UsesMapper'
DIRECTINPUT_REGSTR_VAL_LASTSTARTA: String = 'MostRecentStart'
DIRECTINPUT_REGSTR_VAL_APPIDFLAGW: String = 'AppIdFlag'
DIRECTINPUT_REGSTR_KEY_LASTAPPW: String = 'MostRecentApplication'
DIRECTINPUT_REGSTR_KEY_LASTMAPAPPW: String = 'MostRecentMapperApplication'
DIRECTINPUT_REGSTR_VAL_VERSIONW: String = 'Version'
DIRECTINPUT_REGSTR_VAL_NAMEW: String = 'Name'
DIRECTINPUT_REGSTR_VAL_IDW: String = 'Id'
DIRECTINPUT_REGSTR_VAL_MAPPERW: String = 'UsesMapper'
DIRECTINPUT_REGSTR_VAL_LASTSTARTW: String = 'MostRecentStart'
DIRECTINPUT_REGSTR_VAL_APPIDFLAG: String = 'AppIdFlag'
DIRECTINPUT_REGSTR_KEY_LASTAPP: String = 'MostRecentApplication'
DIRECTINPUT_REGSTR_KEY_LASTMAPAPP: String = 'MostRecentMapperApplication'
DIRECTINPUT_REGSTR_VAL_VERSION: String = 'Version'
DIRECTINPUT_REGSTR_VAL_NAME: String = 'Name'
DIRECTINPUT_REGSTR_VAL_ID: String = 'Id'
DIRECTINPUT_REGSTR_VAL_MAPPER: String = 'UsesMapper'
DIRECTINPUT_REGSTR_VAL_LASTSTART: String = 'MostRecentStart'
DIERR_NOMOREITEMS: win32more.Windows.Win32.Foundation.HRESULT = -2147024637
DIERR_DRIVERFIRST: Int32 = -2147220736
DIERR_DRIVERLAST: Int32 = -2147220481
DIERR_INVALIDCLASSINSTALLER: Int32 = -2147220480
DIERR_CANCELLED: Int32 = -2147220479
DIERR_BADINF: Int32 = -2147220478
DIDIFT_DELETE: UInt32 = 16777216
GUID_DEVINTERFACE_HID: Guid = Guid('{4d1e55b2-f16f-11cf-88cb-001111000030}')
GUID_HID_INTERFACE_NOTIFY: Guid = Guid('{2c4e2e88-25e6-4c33-882f-3d82e6073681}')
GUID_HID_INTERFACE_HIDPARSE: Guid = Guid('{f5c315a5-69ac-4bc2-9279-d0b64576f44b}')
DEVPKEY_DeviceInterface_HID_UsagePage: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=2)
DEVPKEY_DeviceInterface_HID_UsageId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=3)
DEVPKEY_DeviceInterface_HID_IsReadOnly: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=4)
DEVPKEY_DeviceInterface_HID_VendorId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=5)
DEVPKEY_DeviceInterface_HID_ProductId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=6)
DEVPKEY_DeviceInterface_HID_VersionNumber: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=7)
DEVPKEY_DeviceInterface_HID_BackgroundAccess: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=8)
DEVPKEY_DeviceInterface_HID_WakeScreenOnInputCapable: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cbf38310-4a17-4310-a1eb-247f0b67593b}'), pid=9)
HID_REVISION: UInt32 = 1
HIDP_STATUS_SUCCESS: win32more.Windows.Win32.Foundation.NTSTATUS = 1114112
HIDP_STATUS_NULL: win32more.Windows.Win32.Foundation.NTSTATUS = -2146369535
HIDP_STATUS_INVALID_PREPARSED_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627711
HIDP_STATUS_INVALID_REPORT_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627710
HIDP_STATUS_INVALID_REPORT_LENGTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627709
HIDP_STATUS_USAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627708
HIDP_STATUS_VALUE_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627707
HIDP_STATUS_BAD_LOG_PHY_VALUES: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627706
HIDP_STATUS_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627705
HIDP_STATUS_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627704
HIDP_STATUS_I8042_TRANS_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627703
HIDP_STATUS_INCOMPATIBLE_REPORT_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627702
HIDP_STATUS_NOT_VALUE_ARRAY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627701
HIDP_STATUS_IS_VALUE_ARRAY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627700
HIDP_STATUS_DATA_INDEX_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627699
HIDP_STATUS_DATA_INDEX_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627698
HIDP_STATUS_BUTTON_NOT_PRESSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627697
HIDP_STATUS_REPORT_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627696
HIDP_STATUS_NOT_IMPLEMENTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627680
HIDP_STATUS_NOT_BUTTON_ARRAY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627679
HIDP_STATUS_I8242_TRANS_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1072627703
HID_USAGE_PAGE_UNDEFINED: UInt16 = 0
HID_USAGE_PAGE_GENERIC: UInt16 = 1
HID_USAGE_PAGE_SIMULATION: UInt16 = 2
HID_USAGE_PAGE_VR: UInt16 = 3
HID_USAGE_PAGE_SPORT: UInt16 = 4
HID_USAGE_PAGE_GAME: UInt16 = 5
HID_USAGE_PAGE_GENERIC_DEVICE: UInt16 = 6
HID_USAGE_PAGE_KEYBOARD: UInt16 = 7
HID_USAGE_PAGE_LED: UInt16 = 8
HID_USAGE_PAGE_BUTTON: UInt16 = 9
HID_USAGE_PAGE_ORDINAL: UInt16 = 10
HID_USAGE_PAGE_TELEPHONY: UInt16 = 11
HID_USAGE_PAGE_CONSUMER: UInt16 = 12
HID_USAGE_PAGE_DIGITIZER: UInt16 = 13
HID_USAGE_PAGE_HAPTICS: UInt16 = 14
HID_USAGE_PAGE_PID: UInt16 = 15
HID_USAGE_PAGE_UNICODE: UInt16 = 16
HID_USAGE_PAGE_ALPHANUMERIC: UInt16 = 20
HID_USAGE_PAGE_SENSOR: UInt16 = 32
HID_USAGE_PAGE_LIGHTING_ILLUMINATION: UInt16 = 89
HID_USAGE_PAGE_BARCODE_SCANNER: UInt16 = 140
HID_USAGE_PAGE_WEIGHING_DEVICE: UInt16 = 141
HID_USAGE_PAGE_MAGNETIC_STRIPE_READER: UInt16 = 142
HID_USAGE_PAGE_CAMERA_CONTROL: UInt16 = 144
HID_USAGE_PAGE_ARCADE: UInt16 = 145
HID_USAGE_PAGE_MICROSOFT_BLUETOOTH_HANDSFREE: UInt16 = 65523
HID_USAGE_PAGE_VENDOR_DEFINED_BEGIN: UInt16 = 65280
HID_USAGE_PAGE_VENDOR_DEFINED_END: UInt16 = 65535
HID_USAGE_GENERIC_POINTER: UInt16 = 1
HID_USAGE_GENERIC_MOUSE: UInt16 = 2
HID_USAGE_GENERIC_JOYSTICK: UInt16 = 4
HID_USAGE_GENERIC_GAMEPAD: UInt16 = 5
HID_USAGE_GENERIC_KEYBOARD: UInt16 = 6
HID_USAGE_GENERIC_KEYPAD: UInt16 = 7
HID_USAGE_GENERIC_MULTI_AXIS_CONTROLLER: UInt16 = 8
HID_USAGE_GENERIC_TABLET_PC_SYSTEM_CTL: UInt16 = 9
HID_USAGE_GENERIC_PORTABLE_DEVICE_CONTROL: UInt16 = 13
HID_USAGE_GENERIC_INTERACTIVE_CONTROL: UInt16 = 14
HID_USAGE_GENERIC_COUNTED_BUFFER: UInt16 = 58
HID_USAGE_GENERIC_SYSTEM_CTL: UInt16 = 128
HID_USAGE_GENERIC_X: UInt16 = 48
HID_USAGE_GENERIC_Y: UInt16 = 49
HID_USAGE_GENERIC_Z: UInt16 = 50
HID_USAGE_GENERIC_RX: UInt16 = 51
HID_USAGE_GENERIC_RY: UInt16 = 52
HID_USAGE_GENERIC_RZ: UInt16 = 53
HID_USAGE_GENERIC_SLIDER: UInt16 = 54
HID_USAGE_GENERIC_DIAL: UInt16 = 55
HID_USAGE_GENERIC_WHEEL: UInt16 = 56
HID_USAGE_GENERIC_HATSWITCH: UInt16 = 57
HID_USAGE_GENERIC_BYTE_COUNT: UInt16 = 59
HID_USAGE_GENERIC_MOTION_WAKEUP: UInt16 = 60
HID_USAGE_GENERIC_START: UInt16 = 61
HID_USAGE_GENERIC_SELECT: UInt16 = 62
HID_USAGE_GENERIC_VX: UInt16 = 64
HID_USAGE_GENERIC_VY: UInt16 = 65
HID_USAGE_GENERIC_VZ: UInt16 = 66
HID_USAGE_GENERIC_VBRX: UInt16 = 67
HID_USAGE_GENERIC_VBRY: UInt16 = 68
HID_USAGE_GENERIC_VBRZ: UInt16 = 69
HID_USAGE_GENERIC_VNO: UInt16 = 70
HID_USAGE_GENERIC_FEATURE_NOTIFICATION: UInt16 = 71
HID_USAGE_GENERIC_RESOLUTION_MULTIPLIER: UInt16 = 72
HID_USAGE_GENERIC_SYSCTL_POWER: UInt16 = 129
HID_USAGE_GENERIC_SYSCTL_SLEEP: UInt16 = 130
HID_USAGE_GENERIC_SYSCTL_WAKE: UInt16 = 131
HID_USAGE_GENERIC_SYSCTL_CONTEXT_MENU: UInt16 = 132
HID_USAGE_GENERIC_SYSCTL_MAIN_MENU: UInt16 = 133
HID_USAGE_GENERIC_SYSCTL_APP_MENU: UInt16 = 134
HID_USAGE_GENERIC_SYSCTL_HELP_MENU: UInt16 = 135
HID_USAGE_GENERIC_SYSCTL_MENU_EXIT: UInt16 = 136
HID_USAGE_GENERIC_SYSCTL_MENU_SELECT: UInt16 = 137
HID_USAGE_GENERIC_SYSCTL_MENU_RIGHT: UInt16 = 138
HID_USAGE_GENERIC_SYSCTL_MENU_LEFT: UInt16 = 139
HID_USAGE_GENERIC_SYSCTL_MENU_UP: UInt16 = 140
HID_USAGE_GENERIC_SYSCTL_MENU_DOWN: UInt16 = 141
HID_USAGE_GENERIC_SYSCTL_COLD_RESTART: UInt16 = 142
HID_USAGE_GENERIC_SYSCTL_WARM_RESTART: UInt16 = 143
HID_USAGE_GENERIC_DPAD_UP: UInt16 = 144
HID_USAGE_GENERIC_DPAD_DOWN: UInt16 = 145
HID_USAGE_GENERIC_DPAD_RIGHT: UInt16 = 146
HID_USAGE_GENERIC_DPAD_LEFT: UInt16 = 147
HID_USAGE_GENERIC_SYSCTL_FN: UInt16 = 151
HID_USAGE_GENERIC_SYSCTL_FN_LOCK: UInt16 = 152
HID_USAGE_GENERIC_SYSCTL_FN_LOCK_INDICATOR: UInt16 = 153
HID_USAGE_GENERIC_SYSCTL_DISMISS_NOTIFICATION: UInt16 = 154
HID_USAGE_GENERIC_SYSCTL_DOCK: UInt16 = 160
HID_USAGE_GENERIC_SYSCTL_UNDOCK: UInt16 = 161
HID_USAGE_GENERIC_SYSCTL_SETUP: UInt16 = 162
HID_USAGE_GENERIC_SYSCTL_SYS_BREAK: UInt16 = 163
HID_USAGE_GENERIC_SYSCTL_SYS_DBG_BREAK: UInt16 = 164
HID_USAGE_GENERIC_SYSCTL_APP_BREAK: UInt16 = 165
HID_USAGE_GENERIC_SYSCTL_APP_DBG_BREAK: UInt16 = 166
HID_USAGE_GENERIC_SYSCTL_MUTE: UInt16 = 167
HID_USAGE_GENERIC_SYSCTL_HIBERNATE: UInt16 = 168
HID_USAGE_GENERIC_SYSCTL_DISP_INVERT: UInt16 = 176
HID_USAGE_GENERIC_SYSCTL_DISP_INTERNAL: UInt16 = 177
HID_USAGE_GENERIC_SYSCTL_DISP_EXTERNAL: UInt16 = 178
HID_USAGE_GENERIC_SYSCTL_DISP_BOTH: UInt16 = 179
HID_USAGE_GENERIC_SYSCTL_DISP_DUAL: UInt16 = 180
HID_USAGE_GENERIC_SYSCTL_DISP_TOGGLE: UInt16 = 181
HID_USAGE_GENERIC_SYSCTL_DISP_SWAP: UInt16 = 182
HID_USAGE_GENERIC_SYSCTL_DISP_AUTOSCALE: UInt16 = 183
HID_USAGE_GENERIC_SYSTEM_DISPLAY_ROTATION_LOCK_BUTTON: UInt16 = 201
HID_USAGE_GENERIC_SYSTEM_DISPLAY_ROTATION_LOCK_SLIDER_SWITCH: UInt16 = 202
HID_USAGE_GENERIC_CONTROL_ENABLE: UInt16 = 203
HID_USAGE_SIMULATION_FLIGHT_SIMULATION_DEVICE: UInt16 = 1
HID_USAGE_SIMULATION_AUTOMOBILE_SIMULATION_DEVICE: UInt16 = 2
HID_USAGE_SIMULATION_TANK_SIMULATION_DEVICE: UInt16 = 3
HID_USAGE_SIMULATION_SPACESHIP_SIMULATION_DEVICE: UInt16 = 4
HID_USAGE_SIMULATION_SUBMARINE_SIMULATION_DEVICE: UInt16 = 5
HID_USAGE_SIMULATION_SAILING_SIMULATION_DEVICE: UInt16 = 6
HID_USAGE_SIMULATION_MOTORCYCLE_SIMULATION_DEVICE: UInt16 = 7
HID_USAGE_SIMULATION_SPORTS_SIMULATION_DEVICE: UInt16 = 8
HID_USAGE_SIMULATION_AIRPLANE_SIMULATION_DEVICE: UInt16 = 9
HID_USAGE_SIMULATION_HELICOPTER_SIMULATION_DEVICE: UInt16 = 10
HID_USAGE_SIMULATION_MAGIC_CARPET_SIMULATION_DEVICE: UInt16 = 11
HID_USAGE_SIMULATION_BICYCLE_SIMULATION_DEVICE: UInt16 = 12
HID_USAGE_SIMULATION_FLIGHT_CONTROL_STICK: UInt16 = 32
HID_USAGE_SIMULATION_FLIGHT_STICK: UInt16 = 33
HID_USAGE_SIMULATION_CYCLIC_CONTROL: UInt16 = 34
HID_USAGE_SIMULATION_CYCLIC_TRIM: UInt16 = 35
HID_USAGE_SIMULATION_FLIGHT_YOKE: UInt16 = 36
HID_USAGE_SIMULATION_TRACK_CONTROL: UInt16 = 37
HID_USAGE_SIMULATION_AILERON: UInt16 = 176
HID_USAGE_SIMULATION_AILERON_TRIM: UInt16 = 177
HID_USAGE_SIMULATION_ANTI_TORQUE_CONTROL: UInt16 = 178
HID_USAGE_SIMULATION_AUTOPIOLOT_ENABLE: UInt16 = 179
HID_USAGE_SIMULATION_CHAFF_RELEASE: UInt16 = 180
HID_USAGE_SIMULATION_COLLECTIVE_CONTROL: UInt16 = 181
HID_USAGE_SIMULATION_DIVE_BRAKE: UInt16 = 182
HID_USAGE_SIMULATION_ELECTRONIC_COUNTERMEASURES: UInt16 = 183
HID_USAGE_SIMULATION_ELEVATOR: UInt16 = 184
HID_USAGE_SIMULATION_ELEVATOR_TRIM: UInt16 = 185
HID_USAGE_SIMULATION_RUDDER: UInt16 = 186
HID_USAGE_SIMULATION_THROTTLE: UInt16 = 187
HID_USAGE_SIMULATION_FLIGHT_COMMUNICATIONS: UInt16 = 188
HID_USAGE_SIMULATION_FLARE_RELEASE: UInt16 = 189
HID_USAGE_SIMULATION_LANDING_GEAR: UInt16 = 190
HID_USAGE_SIMULATION_TOE_BRAKE: UInt16 = 191
HID_USAGE_SIMULATION_TRIGGER: UInt16 = 192
HID_USAGE_SIMULATION_WEAPONS_ARM: UInt16 = 193
HID_USAGE_SIMULATION_WEAPONS_SELECT: UInt16 = 194
HID_USAGE_SIMULATION_WING_FLAPS: UInt16 = 195
HID_USAGE_SIMULATION_ACCELLERATOR: UInt16 = 196
HID_USAGE_SIMULATION_BRAKE: UInt16 = 197
HID_USAGE_SIMULATION_CLUTCH: UInt16 = 198
HID_USAGE_SIMULATION_SHIFTER: UInt16 = 199
HID_USAGE_SIMULATION_STEERING: UInt16 = 200
HID_USAGE_SIMULATION_TURRET_DIRECTION: UInt16 = 201
HID_USAGE_SIMULATION_BARREL_ELEVATION: UInt16 = 202
HID_USAGE_SIMULATION_DIVE_PLANE: UInt16 = 203
HID_USAGE_SIMULATION_BALLAST: UInt16 = 204
HID_USAGE_SIMULATION_BICYCLE_CRANK: UInt16 = 205
HID_USAGE_SIMULATION_HANDLE_BARS: UInt16 = 206
HID_USAGE_SIMULATION_FRONT_BRAKE: UInt16 = 207
HID_USAGE_SIMULATION_REAR_BRAKE: UInt16 = 208
HID_USAGE_VR_BELT: UInt16 = 1
HID_USAGE_VR_BODY_SUIT: UInt16 = 2
HID_USAGE_VR_FLEXOR: UInt16 = 3
HID_USAGE_VR_GLOVE: UInt16 = 4
HID_USAGE_VR_HEAD_TRACKER: UInt16 = 5
HID_USAGE_VR_HEAD_MOUNTED_DISPLAY: UInt16 = 6
HID_USAGE_VR_HAND_TRACKER: UInt16 = 7
HID_USAGE_VR_OCULOMETER: UInt16 = 8
HID_USAGE_VR_VEST: UInt16 = 9
HID_USAGE_VR_ANIMATRONIC_DEVICE: UInt16 = 10
HID_USAGE_VR_STEREO_ENABLE: UInt16 = 32
HID_USAGE_VR_DISPLAY_ENABLE: UInt16 = 33
HID_USAGE_SPORT_BASEBALL_BAT: UInt16 = 1
HID_USAGE_SPORT_GOLF_CLUB: UInt16 = 2
HID_USAGE_SPORT_ROWING_MACHINE: UInt16 = 3
HID_USAGE_SPORT_TREADMILL: UInt16 = 4
HID_USAGE_SPORT_STICK_TYPE: UInt16 = 56
HID_USAGE_SPORT_OAR: UInt16 = 48
HID_USAGE_SPORT_SLOPE: UInt16 = 49
HID_USAGE_SPORT_RATE: UInt16 = 50
HID_USAGE_SPORT_STICK_SPEED: UInt16 = 51
HID_USAGE_SPORT_STICK_FACE_ANGLE: UInt16 = 52
HID_USAGE_SPORT_HEEL_TOE: UInt16 = 53
HID_USAGE_SPORT_FOLLOW_THROUGH: UInt16 = 54
HID_USAGE_SPORT_TEMPO: UInt16 = 55
HID_USAGE_SPORT_HEIGHT: UInt16 = 57
HID_USAGE_SPORT_PUTTER: UInt16 = 80
HID_USAGE_SPORT_1_IRON: UInt16 = 81
HID_USAGE_SPORT_2_IRON: UInt16 = 82
HID_USAGE_SPORT_3_IRON: UInt16 = 83
HID_USAGE_SPORT_4_IRON: UInt16 = 84
HID_USAGE_SPORT_5_IRON: UInt16 = 85
HID_USAGE_SPORT_6_IRON: UInt16 = 86
HID_USAGE_SPORT_7_IRON: UInt16 = 87
HID_USAGE_SPORT_8_IRON: UInt16 = 88
HID_USAGE_SPORT_9_IRON: UInt16 = 89
HID_USAGE_SPORT_10_IRON: UInt16 = 90
HID_USAGE_SPORT_11_IRON: UInt16 = 91
HID_USAGE_SPORT_SAND_WEDGE: UInt16 = 92
HID_USAGE_SPORT_LOFT_WEDGE: UInt16 = 93
HID_USAGE_SPORT_POWER_WEDGE: UInt16 = 94
HID_USAGE_SPORT_1_WOOD: UInt16 = 95
HID_USAGE_SPORT_3_WOOD: UInt16 = 96
HID_USAGE_SPORT_5_WOOD: UInt16 = 97
HID_USAGE_SPORT_7_WOOD: UInt16 = 98
HID_USAGE_SPORT_9_WOOD: UInt16 = 99
HID_USAGE_GAME_3D_GAME_CONTROLLER: UInt16 = 1
HID_USAGE_GAME_PINBALL_DEVICE: UInt16 = 2
HID_USAGE_GAME_GUN_DEVICE: UInt16 = 3
HID_USAGE_GAME_POINT_OF_VIEW: UInt16 = 32
HID_USAGE_GAME_GUN_SELECTOR: UInt16 = 50
HID_USAGE_GAME_GAMEPAD_FIRE_JUMP: UInt16 = 55
HID_USAGE_GAME_GAMEPAD_TRIGGER: UInt16 = 57
HID_USAGE_GAME_TURN_RIGHT_LEFT: UInt16 = 33
HID_USAGE_GAME_PITCH_FORWARD_BACK: UInt16 = 34
HID_USAGE_GAME_ROLL_RIGHT_LEFT: UInt16 = 35
HID_USAGE_GAME_MOVE_RIGHT_LEFT: UInt16 = 36
HID_USAGE_GAME_MOVE_FORWARD_BACK: UInt16 = 37
HID_USAGE_GAME_MOVE_UP_DOWN: UInt16 = 38
HID_USAGE_GAME_LEAN_RIGHT_LEFT: UInt16 = 39
HID_USAGE_GAME_LEAN_FORWARD_BACK: UInt16 = 40
HID_USAGE_GAME_POV_HEIGHT: UInt16 = 41
HID_USAGE_GAME_FLIPPER: UInt16 = 42
HID_USAGE_GAME_SECONDARY_FLIPPER: UInt16 = 43
HID_USAGE_GAME_BUMP: UInt16 = 44
HID_USAGE_GAME_NEW_GAME: UInt16 = 45
HID_USAGE_GAME_SHOOT_BALL: UInt16 = 46
HID_USAGE_GAME_PLAYER: UInt16 = 47
HID_USAGE_GAME_GUN_BOLT: UInt16 = 48
HID_USAGE_GAME_GUN_CLIP: UInt16 = 49
HID_USAGE_GAME_GUN_SINGLE_SHOT: UInt16 = 51
HID_USAGE_GAME_GUN_BURST: UInt16 = 52
HID_USAGE_GAME_GUN_AUTOMATIC: UInt16 = 53
HID_USAGE_GAME_GUN_SAFETY: UInt16 = 54
HID_USAGE_GENERIC_DEVICE_BATTERY_STRENGTH: UInt16 = 32
HID_USAGE_GENERIC_DEVICE_WIRELESS_CHANNEL: UInt16 = 33
HID_USAGE_GENERIC_DEVICE_WIRELESS_ID: UInt16 = 34
HID_USAGE_GENERIC_DEVICE_DISCOVER_WIRELESS_CONTROL: UInt16 = 35
HID_USAGE_GENERIC_DEVICE_SECURITY_CODE_CHAR_ENTERED: UInt16 = 36
HID_USAGE_GENERIC_DEVICE_SECURITY_CODE_CHAR_ERASED: UInt16 = 37
HID_USAGE_GENERIC_DEVICE_SECURITY_CODE_CLEARED: UInt16 = 38
HID_USAGE_KEYBOARD_NOEVENT: UInt16 = 0
HID_USAGE_KEYBOARD_ROLLOVER: UInt16 = 1
HID_USAGE_KEYBOARD_POSTFAIL: UInt16 = 2
HID_USAGE_KEYBOARD_UNDEFINED: UInt16 = 3
HID_USAGE_KEYBOARD_aA: UInt16 = 4
HID_USAGE_KEYBOARD_zZ: UInt16 = 29
HID_USAGE_KEYBOARD_ONE: UInt16 = 30
HID_USAGE_KEYBOARD_ZERO: UInt16 = 39
HID_USAGE_KEYBOARD_LCTRL: UInt16 = 224
HID_USAGE_KEYBOARD_LSHFT: UInt16 = 225
HID_USAGE_KEYBOARD_LALT: UInt16 = 226
HID_USAGE_KEYBOARD_LGUI: UInt16 = 227
HID_USAGE_KEYBOARD_RCTRL: UInt16 = 228
HID_USAGE_KEYBOARD_RSHFT: UInt16 = 229
HID_USAGE_KEYBOARD_RALT: UInt16 = 230
HID_USAGE_KEYBOARD_RGUI: UInt16 = 231
HID_USAGE_KEYBOARD_SCROLL_LOCK: UInt16 = 71
HID_USAGE_KEYBOARD_NUM_LOCK: UInt16 = 83
HID_USAGE_KEYBOARD_CAPS_LOCK: UInt16 = 57
HID_USAGE_KEYBOARD_F1: UInt16 = 58
HID_USAGE_KEYBOARD_F2: UInt16 = 59
HID_USAGE_KEYBOARD_F3: UInt16 = 60
HID_USAGE_KEYBOARD_F4: UInt16 = 61
HID_USAGE_KEYBOARD_F5: UInt16 = 62
HID_USAGE_KEYBOARD_F6: UInt16 = 63
HID_USAGE_KEYBOARD_F7: UInt16 = 64
HID_USAGE_KEYBOARD_F8: UInt16 = 65
HID_USAGE_KEYBOARD_F9: UInt16 = 66
HID_USAGE_KEYBOARD_F10: UInt16 = 67
HID_USAGE_KEYBOARD_F11: UInt16 = 68
HID_USAGE_KEYBOARD_F12: UInt16 = 69
HID_USAGE_KEYBOARD_F13: UInt16 = 104
HID_USAGE_KEYBOARD_F14: UInt16 = 105
HID_USAGE_KEYBOARD_F15: UInt16 = 106
HID_USAGE_KEYBOARD_F16: UInt16 = 107
HID_USAGE_KEYBOARD_F17: UInt16 = 108
HID_USAGE_KEYBOARD_F18: UInt16 = 109
HID_USAGE_KEYBOARD_F19: UInt16 = 110
HID_USAGE_KEYBOARD_F20: UInt16 = 111
HID_USAGE_KEYBOARD_F21: UInt16 = 112
HID_USAGE_KEYBOARD_F22: UInt16 = 113
HID_USAGE_KEYBOARD_F23: UInt16 = 114
HID_USAGE_KEYBOARD_F24: UInt16 = 115
HID_USAGE_KEYBOARD_RETURN: UInt16 = 40
HID_USAGE_KEYBOARD_ESCAPE: UInt16 = 41
HID_USAGE_KEYBOARD_DELETE: UInt16 = 42
HID_USAGE_KEYBOARD_PRINT_SCREEN: UInt16 = 70
HID_USAGE_KEYBOARD_DELETE_FORWARD: UInt16 = 76
HID_USAGE_KEYBOARD_KEYPAD_1_AND_END: UInt16 = 89
HID_USAGE_KEYBOARD_KEYPAD_0_AND_INSERT: UInt16 = 98
HID_USAGE_LED_NUM_LOCK: UInt16 = 1
HID_USAGE_LED_CAPS_LOCK: UInt16 = 2
HID_USAGE_LED_SCROLL_LOCK: UInt16 = 3
HID_USAGE_LED_COMPOSE: UInt16 = 4
HID_USAGE_LED_KANA: UInt16 = 5
HID_USAGE_LED_POWER: UInt16 = 6
HID_USAGE_LED_SHIFT: UInt16 = 7
HID_USAGE_LED_DO_NOT_DISTURB: UInt16 = 8
HID_USAGE_LED_MUTE: UInt16 = 9
HID_USAGE_LED_TONE_ENABLE: UInt16 = 10
HID_USAGE_LED_HIGH_CUT_FILTER: UInt16 = 11
HID_USAGE_LED_LOW_CUT_FILTER: UInt16 = 12
HID_USAGE_LED_EQUALIZER_ENABLE: UInt16 = 13
HID_USAGE_LED_SOUND_FIELD_ON: UInt16 = 14
HID_USAGE_LED_SURROUND_FIELD_ON: UInt16 = 15
HID_USAGE_LED_REPEAT: UInt16 = 16
HID_USAGE_LED_STEREO: UInt16 = 17
HID_USAGE_LED_SAMPLING_RATE_DETECT: UInt16 = 18
HID_USAGE_LED_SPINNING: UInt16 = 19
HID_USAGE_LED_CAV: UInt16 = 20
HID_USAGE_LED_CLV: UInt16 = 21
HID_USAGE_LED_RECORDING_FORMAT_DET: UInt16 = 22
HID_USAGE_LED_OFF_HOOK: UInt16 = 23
HID_USAGE_LED_RING: UInt16 = 24
HID_USAGE_LED_MESSAGE_WAITING: UInt16 = 25
HID_USAGE_LED_DATA_MODE: UInt16 = 26
HID_USAGE_LED_BATTERY_OPERATION: UInt16 = 27
HID_USAGE_LED_BATTERY_OK: UInt16 = 28
HID_USAGE_LED_BATTERY_LOW: UInt16 = 29
HID_USAGE_LED_SPEAKER: UInt16 = 30
HID_USAGE_LED_HEAD_SET: UInt16 = 31
HID_USAGE_LED_HOLD: UInt16 = 32
HID_USAGE_LED_MICROPHONE: UInt16 = 33
HID_USAGE_LED_COVERAGE: UInt16 = 34
HID_USAGE_LED_NIGHT_MODE: UInt16 = 35
HID_USAGE_LED_SEND_CALLS: UInt16 = 36
HID_USAGE_LED_CALL_PICKUP: UInt16 = 37
HID_USAGE_LED_CONFERENCE: UInt16 = 38
HID_USAGE_LED_STAND_BY: UInt16 = 39
HID_USAGE_LED_CAMERA_ON: UInt16 = 40
HID_USAGE_LED_CAMERA_OFF: UInt16 = 41
HID_USAGE_LED_ON_LINE: UInt16 = 42
HID_USAGE_LED_OFF_LINE: UInt16 = 43
HID_USAGE_LED_BUSY: UInt16 = 44
HID_USAGE_LED_READY: UInt16 = 45
HID_USAGE_LED_PAPER_OUT: UInt16 = 46
HID_USAGE_LED_PAPER_JAM: UInt16 = 47
HID_USAGE_LED_REMOTE: UInt16 = 48
HID_USAGE_LED_FORWARD: UInt16 = 49
HID_USAGE_LED_REVERSE: UInt16 = 50
HID_USAGE_LED_STOP: UInt16 = 51
HID_USAGE_LED_REWIND: UInt16 = 52
HID_USAGE_LED_FAST_FORWARD: UInt16 = 53
HID_USAGE_LED_PLAY: UInt16 = 54
HID_USAGE_LED_PAUSE: UInt16 = 55
HID_USAGE_LED_RECORD: UInt16 = 56
HID_USAGE_LED_ERROR: UInt16 = 57
HID_USAGE_LED_SELECTED_INDICATOR: UInt16 = 58
HID_USAGE_LED_IN_USE_INDICATOR: UInt16 = 59
HID_USAGE_LED_MULTI_MODE_INDICATOR: UInt16 = 60
HID_USAGE_LED_INDICATOR_ON: UInt16 = 61
HID_USAGE_LED_INDICATOR_FLASH: UInt16 = 62
HID_USAGE_LED_INDICATOR_SLOW_BLINK: UInt16 = 63
HID_USAGE_LED_INDICATOR_FAST_BLINK: UInt16 = 64
HID_USAGE_LED_INDICATOR_OFF: UInt16 = 65
HID_USAGE_LED_FLASH_ON_TIME: UInt16 = 66
HID_USAGE_LED_SLOW_BLINK_ON_TIME: UInt16 = 67
HID_USAGE_LED_SLOW_BLINK_OFF_TIME: UInt16 = 68
HID_USAGE_LED_FAST_BLINK_ON_TIME: UInt16 = 69
HID_USAGE_LED_FAST_BLINK_OFF_TIME: UInt16 = 70
HID_USAGE_LED_INDICATOR_COLOR: UInt16 = 71
HID_USAGE_LED_RED: UInt16 = 72
HID_USAGE_LED_GREEN: UInt16 = 73
HID_USAGE_LED_AMBER: UInt16 = 74
HID_USAGE_LED_GENERIC_INDICATOR: UInt16 = 75
HID_USAGE_LED_SYSTEM_SUSPEND: UInt16 = 76
HID_USAGE_LED_EXTERNAL_POWER: UInt16 = 77
HID_USAGE_TELEPHONY_PHONE: UInt16 = 1
HID_USAGE_TELEPHONY_ANSWERING_MACHINE: UInt16 = 2
HID_USAGE_TELEPHONY_MESSAGE_CONTROLS: UInt16 = 3
HID_USAGE_TELEPHONY_HANDSET: UInt16 = 4
HID_USAGE_TELEPHONY_HEADSET: UInt16 = 5
HID_USAGE_TELEPHONY_KEYPAD: UInt16 = 6
HID_USAGE_TELEPHONY_PROGRAMMABLE_BUTTON: UInt16 = 7
HID_USAGE_TELEPHONY_REDIAL: UInt16 = 36
HID_USAGE_TELEPHONY_TRANSFER: UInt16 = 37
HID_USAGE_TELEPHONY_DROP: UInt16 = 38
HID_USAGE_TELEPHONY_LINE: UInt16 = 42
HID_USAGE_TELEPHONY_RING_ENABLE: UInt16 = 45
HID_USAGE_TELEPHONY_SEND: UInt16 = 49
HID_USAGE_TELEPHONY_KEYPAD_0: UInt16 = 176
HID_USAGE_TELEPHONY_KEYPAD_D: UInt16 = 191
HID_USAGE_TELEPHONY_HOST_AVAILABLE: UInt16 = 241
HID_USAGE_CONSUMERCTRL: UInt16 = 1
HID_USAGE_CONSUMER_CHANNEL_INCREMENT: UInt16 = 156
HID_USAGE_CONSUMER_CHANNEL_DECREMENT: UInt16 = 157
HID_USAGE_CONSUMER_PLAY: UInt16 = 176
HID_USAGE_CONSUMER_PAUSE: UInt16 = 177
HID_USAGE_CONSUMER_RECORD: UInt16 = 178
HID_USAGE_CONSUMER_FAST_FORWARD: UInt16 = 179
HID_USAGE_CONSUMER_REWIND: UInt16 = 180
HID_USAGE_CONSUMER_SCAN_NEXT_TRACK: UInt16 = 181
HID_USAGE_CONSUMER_SCAN_PREV_TRACK: UInt16 = 182
HID_USAGE_CONSUMER_STOP: UInt16 = 183
HID_USAGE_CONSUMER_PLAY_PAUSE: UInt16 = 205
HID_USAGE_CONSUMER_GAMEDVR_OPEN_GAMEBAR: UInt16 = 208
HID_USAGE_CONSUMER_GAMEDVR_TOGGLE_RECORD: UInt16 = 209
HID_USAGE_CONSUMER_GAMEDVR_RECORD_CLIP: UInt16 = 210
HID_USAGE_CONSUMER_GAMEDVR_SCREENSHOT: UInt16 = 211
HID_USAGE_CONSUMER_GAMEDVR_TOGGLE_INDICATOR: UInt16 = 212
HID_USAGE_CONSUMER_GAMEDVR_TOGGLE_MICROPHONE: UInt16 = 213
HID_USAGE_CONSUMER_GAMEDVR_TOGGLE_CAMERA: UInt16 = 214
HID_USAGE_CONSUMER_GAMEDVR_TOGGLE_BROADCAST: UInt16 = 215
HID_USAGE_CONSUMER_VOLUME: UInt16 = 224
HID_USAGE_CONSUMER_BALANCE: UInt16 = 225
HID_USAGE_CONSUMER_MUTE: UInt16 = 226
HID_USAGE_CONSUMER_BASS: UInt16 = 227
HID_USAGE_CONSUMER_TREBLE: UInt16 = 228
HID_USAGE_CONSUMER_BASS_BOOST: UInt16 = 229
HID_USAGE_CONSUMER_SURROUND_MODE: UInt16 = 230
HID_USAGE_CONSUMER_LOUDNESS: UInt16 = 231
HID_USAGE_CONSUMER_MPX: UInt16 = 232
HID_USAGE_CONSUMER_VOLUME_INCREMENT: UInt16 = 233
HID_USAGE_CONSUMER_VOLUME_DECREMENT: UInt16 = 234
HID_USAGE_CONSUMER_BASS_INCREMENT: UInt16 = 338
HID_USAGE_CONSUMER_BASS_DECREMENT: UInt16 = 339
HID_USAGE_CONSUMER_TREBLE_INCREMENT: UInt16 = 340
HID_USAGE_CONSUMER_TREBLE_DECREMENT: UInt16 = 341
HID_USAGE_CONSUMER_AL_CONFIGURATION: UInt16 = 387
HID_USAGE_CONSUMER_AL_EMAIL: UInt16 = 394
HID_USAGE_CONSUMER_AL_CALCULATOR: UInt16 = 402
HID_USAGE_CONSUMER_AL_BROWSER: UInt16 = 404
HID_USAGE_CONSUMER_AL_SEARCH: UInt16 = 454
HID_USAGE_CONSUMER_AC_SEARCH: UInt16 = 545
HID_USAGE_CONSUMER_AC_GOTO: UInt16 = 546
HID_USAGE_CONSUMER_AC_HOME: UInt16 = 547
HID_USAGE_CONSUMER_AC_BACK: UInt16 = 548
HID_USAGE_CONSUMER_AC_FORWARD: UInt16 = 549
HID_USAGE_CONSUMER_AC_STOP: UInt16 = 550
HID_USAGE_CONSUMER_AC_REFRESH: UInt16 = 551
HID_USAGE_CONSUMER_AC_PREVIOUS: UInt16 = 552
HID_USAGE_CONSUMER_AC_NEXT: UInt16 = 553
HID_USAGE_CONSUMER_AC_BOOKMARKS: UInt16 = 554
HID_USAGE_CONSUMER_AC_PAN: UInt16 = 568
HID_USAGE_CONSUMER_EXTENDED_KEYBOARD_ATTRIBUTES_COLLECTION: UInt16 = 704
HID_USAGE_CONSUMER_KEYBOARD_FORM_FACTOR: UInt16 = 705
HID_USAGE_CONSUMER_KEYBOARD_KEY_TYPE: UInt16 = 706
HID_USAGE_CONSUMER_KEYBOARD_PHYSICAL_LAYOUT: UInt16 = 707
HID_USAGE_CONSUMER_VENDOR_SPECIFIC_KEYBOARD_PHYSICAL_LAYOUT: UInt16 = 708
HID_USAGE_CONSUMER_KEYBOARD_IETF_LANGUAGE_TAG_INDEX: UInt16 = 709
HID_USAGE_CONSUMER_IMPLEMENTED_KEYBOARD_INPUT_ASSIST_CONTROLS: UInt16 = 710
HID_USAGE_DIGITIZER_DIGITIZER: UInt16 = 1
HID_USAGE_DIGITIZER_PEN: UInt16 = 2
HID_USAGE_DIGITIZER_LIGHT_PEN: UInt16 = 3
HID_USAGE_DIGITIZER_TOUCH_SCREEN: UInt16 = 4
HID_USAGE_DIGITIZER_TOUCH_PAD: UInt16 = 5
HID_USAGE_DIGITIZER_WHITE_BOARD: UInt16 = 6
HID_USAGE_DIGITIZER_COORD_MEASURING: UInt16 = 7
HID_USAGE_DIGITIZER_3D_DIGITIZER: UInt16 = 8
HID_USAGE_DIGITIZER_STEREO_PLOTTER: UInt16 = 9
HID_USAGE_DIGITIZER_ARTICULATED_ARM: UInt16 = 10
HID_USAGE_DIGITIZER_ARMATURE: UInt16 = 11
HID_USAGE_DIGITIZER_MULTI_POINT: UInt16 = 12
HID_USAGE_DIGITIZER_FREE_SPACE_WAND: UInt16 = 13
HID_USAGE_DIGITIZER_HEAT_MAP: UInt16 = 15
HID_USAGE_DIGITIZER_STYLUS: UInt16 = 32
HID_USAGE_DIGITIZER_PUCK: UInt16 = 33
HID_USAGE_DIGITIZER_FINGER: UInt16 = 34
HID_USAGE_DIGITIZER_TABLET_FUNC_KEYS: UInt16 = 57
HID_USAGE_DIGITIZER_PROG_CHANGE_KEYS: UInt16 = 58
HID_USAGE_DIGITIZER_TIP_PRESSURE: UInt16 = 48
HID_USAGE_DIGITIZER_BARREL_PRESSURE: UInt16 = 49
HID_USAGE_DIGITIZER_IN_RANGE: UInt16 = 50
HID_USAGE_DIGITIZER_TOUCH: UInt16 = 51
HID_USAGE_DIGITIZER_UNTOUCH: UInt16 = 52
HID_USAGE_DIGITIZER_TAP: UInt16 = 53
HID_USAGE_DIGITIZER_QUALITY: UInt16 = 54
HID_USAGE_DIGITIZER_DATA_VALID: UInt16 = 55
HID_USAGE_DIGITIZER_TRANSDUCER_INDEX: UInt16 = 56
HID_USAGE_DIGITIZER_BATTERY_STRENGTH: UInt16 = 59
HID_USAGE_DIGITIZER_INVERT: UInt16 = 60
HID_USAGE_DIGITIZER_X_TILT: UInt16 = 61
HID_USAGE_DIGITIZER_Y_TILT: UInt16 = 62
HID_USAGE_DIGITIZER_AZIMUTH: UInt16 = 63
HID_USAGE_DIGITIZER_ALTITUDE: UInt16 = 64
HID_USAGE_DIGITIZER_TWIST: UInt16 = 65
HID_USAGE_DIGITIZER_TIP_SWITCH: UInt16 = 66
HID_USAGE_DIGITIZER_SECONDARY_TIP_SWITCH: UInt16 = 67
HID_USAGE_DIGITIZER_BARREL_SWITCH: UInt16 = 68
HID_USAGE_DIGITIZER_ERASER: UInt16 = 69
HID_USAGE_DIGITIZER_TABLET_PICK: UInt16 = 70
HID_USAGE_DIGITIZER_TRANSDUCER_SERIAL: UInt16 = 91
HID_USAGE_DIGITIZER_HEAT_MAP_PROTOCOL_VENDOR_ID: UInt16 = 106
HID_USAGE_DIGITIZER_HEAT_MAP_PROTOCOL_VERSION: UInt16 = 107
HID_USAGE_DIGITIZER_HEAT_MAP_FRAME_DATA: UInt16 = 108
HID_USAGE_DIGITIZER_TRANSDUCER_SERIAL_PART2: UInt16 = 110
HID_USAGE_DIGITIZER_TRANSDUCER_VENDOR: UInt16 = 145
HID_USAGE_DIGITIZER_TRANSDUCER_PRODUCT: UInt16 = 146
HID_USAGE_DIGITIZER_TRANSDUCER_CONNECTED: UInt16 = 162
HID_USAGE_HAPTICS_SIMPLE_CONTROLLER: UInt16 = 1
HID_USAGE_HAPTICS_WAVEFORM_LIST: UInt16 = 16
HID_USAGE_HAPTICS_DURATION_LIST: UInt16 = 17
HID_USAGE_HAPTICS_AUTO_TRIGGER: UInt16 = 32
HID_USAGE_HAPTICS_MANUAL_TRIGGER: UInt16 = 33
HID_USAGE_HAPTICS_AUTO_ASSOCIATED_CONTROL: UInt16 = 34
HID_USAGE_HAPTICS_INTENSITY: UInt16 = 35
HID_USAGE_HAPTICS_REPEAT_COUNT: UInt16 = 36
HID_USAGE_HAPTICS_RETRIGGER_PERIOD: UInt16 = 37
HID_USAGE_HAPTICS_WAVEFORM_VENDOR_PAGE: UInt16 = 38
HID_USAGE_HAPTICS_WAVEFORM_VENDOR_ID: UInt16 = 39
HID_USAGE_HAPTICS_WAVEFORM_CUTOFF_TIME: UInt16 = 40
HID_USAGE_HAPTICS_WAVEFORM_BEGIN: UInt16 = 4096
HID_USAGE_HAPTICS_WAVEFORM_STOP: UInt16 = 4097
HID_USAGE_HAPTICS_WAVEFORM_NULL: UInt16 = 4098
HID_USAGE_HAPTICS_WAVEFORM_CLICK: UInt16 = 4099
HID_USAGE_HAPTICS_WAVEFORM_BUZZ: UInt16 = 4100
HID_USAGE_HAPTICS_WAVEFORM_RUMBLE: UInt16 = 4101
HID_USAGE_HAPTICS_WAVEFORM_PRESS: UInt16 = 4102
HID_USAGE_HAPTICS_WAVEFORM_RELEASE: UInt16 = 4103
HID_USAGE_HAPTICS_WAVEFORM_END: UInt16 = 8191
HID_USAGE_HAPTICS_WAVEFORM_VENDOR_BEGIN: UInt16 = 8192
HID_USAGE_HAPTICS_WAVEFORM_VENDOR_END: UInt16 = 12287
HID_USAGE_ALPHANUMERIC_ALPHANUMERIC_DISPLAY: UInt16 = 1
HID_USAGE_ALPHANUMERIC_BITMAPPED_DISPLAY: UInt16 = 2
HID_USAGE_ALPHANUMERIC_DISPLAY_ATTRIBUTES_REPORT: UInt16 = 32
HID_USAGE_ALPHANUMERIC_DISPLAY_CONTROL_REPORT: UInt16 = 36
HID_USAGE_ALPHANUMERIC_CHARACTER_REPORT: UInt16 = 43
HID_USAGE_ALPHANUMERIC_DISPLAY_STATUS: UInt16 = 45
HID_USAGE_ALPHANUMERIC_CURSOR_POSITION_REPORT: UInt16 = 50
HID_USAGE_ALPHANUMERIC_FONT_REPORT: UInt16 = 59
HID_USAGE_ALPHANUMERIC_FONT_DATA: UInt16 = 60
HID_USAGE_ALPHANUMERIC_CHARACTER_ATTRIBUTE: UInt16 = 72
HID_USAGE_ALPHANUMERIC_PALETTE_REPORT: UInt16 = 133
HID_USAGE_ALPHANUMERIC_PALETTE_DATA: UInt16 = 136
HID_USAGE_ALPHANUMERIC_BLIT_REPORT: UInt16 = 138
HID_USAGE_ALPHANUMERIC_BLIT_DATA: UInt16 = 143
HID_USAGE_ALPHANUMERIC_SOFT_BUTTON: UInt16 = 144
HID_USAGE_ALPHANUMERIC_ASCII_CHARACTER_SET: UInt16 = 33
HID_USAGE_ALPHANUMERIC_DATA_READ_BACK: UInt16 = 34
HID_USAGE_ALPHANUMERIC_FONT_READ_BACK: UInt16 = 35
HID_USAGE_ALPHANUMERIC_CLEAR_DISPLAY: UInt16 = 37
HID_USAGE_ALPHANUMERIC_DISPLAY_ENABLE: UInt16 = 38
HID_USAGE_ALPHANUMERIC_SCREEN_SAVER_DELAY: UInt16 = 39
HID_USAGE_ALPHANUMERIC_SCREEN_SAVER_ENABLE: UInt16 = 40
HID_USAGE_ALPHANUMERIC_VERTICAL_SCROLL: UInt16 = 41
HID_USAGE_ALPHANUMERIC_HORIZONTAL_SCROLL: UInt16 = 42
HID_USAGE_ALPHANUMERIC_DISPLAY_DATA: UInt16 = 44
HID_USAGE_ALPHANUMERIC_STATUS_NOT_READY: UInt16 = 46
HID_USAGE_ALPHANUMERIC_STATUS_READY: UInt16 = 47
HID_USAGE_ALPHANUMERIC_ERR_NOT_A_LOADABLE_CHARACTER: UInt16 = 48
HID_USAGE_ALPHANUMERIC_ERR_FONT_DATA_CANNOT_BE_READ: UInt16 = 49
HID_USAGE_ALPHANUMERIC_ROW: UInt16 = 51
HID_USAGE_ALPHANUMERIC_COLUMN: UInt16 = 52
HID_USAGE_ALPHANUMERIC_ROWS: UInt16 = 53
HID_USAGE_ALPHANUMERIC_COLUMNS: UInt16 = 54
HID_USAGE_ALPHANUMERIC_CURSOR_PIXEL_POSITIONING: UInt16 = 55
HID_USAGE_ALPHANUMERIC_CURSOR_MODE: UInt16 = 56
HID_USAGE_ALPHANUMERIC_CURSOR_ENABLE: UInt16 = 57
HID_USAGE_ALPHANUMERIC_CURSOR_BLINK: UInt16 = 58
HID_USAGE_ALPHANUMERIC_CHAR_WIDTH: UInt16 = 61
HID_USAGE_ALPHANUMERIC_CHAR_HEIGHT: UInt16 = 62
HID_USAGE_ALPHANUMERIC_CHAR_SPACING_HORIZONTAL: UInt16 = 63
HID_USAGE_ALPHANUMERIC_CHAR_SPACING_VERTICAL: UInt16 = 64
HID_USAGE_ALPHANUMERIC_UNICODE_CHAR_SET: UInt16 = 65
HID_USAGE_ALPHANUMERIC_FONT_7_SEGMENT: UInt16 = 66
HID_USAGE_ALPHANUMERIC_7_SEGMENT_DIRECT_MAP: UInt16 = 67
HID_USAGE_ALPHANUMERIC_FONT_14_SEGMENT: UInt16 = 68
HID_USAGE_ALPHANUMERIC_14_SEGMENT_DIRECT_MAP: UInt16 = 69
HID_USAGE_ALPHANUMERIC_DISPLAY_BRIGHTNESS: UInt16 = 70
HID_USAGE_ALPHANUMERIC_DISPLAY_CONTRAST: UInt16 = 71
HID_USAGE_ALPHANUMERIC_ATTRIBUTE_READBACK: UInt16 = 73
HID_USAGE_ALPHANUMERIC_ATTRIBUTE_DATA: UInt16 = 74
HID_USAGE_ALPHANUMERIC_CHAR_ATTR_ENHANCE: UInt16 = 75
HID_USAGE_ALPHANUMERIC_CHAR_ATTR_UNDERLINE: UInt16 = 76
HID_USAGE_ALPHANUMERIC_CHAR_ATTR_BLINK: UInt16 = 77
HID_USAGE_ALPHANUMERIC_BITMAP_SIZE_X: UInt16 = 128
HID_USAGE_ALPHANUMERIC_BITMAP_SIZE_Y: UInt16 = 129
HID_USAGE_ALPHANUMERIC_BIT_DEPTH_FORMAT: UInt16 = 131
HID_USAGE_ALPHANUMERIC_DISPLAY_ORIENTATION: UInt16 = 132
HID_USAGE_ALPHANUMERIC_PALETTE_DATA_SIZE: UInt16 = 134
HID_USAGE_ALPHANUMERIC_PALETTE_DATA_OFFSET: UInt16 = 135
HID_USAGE_ALPHANUMERIC_BLIT_RECTANGLE_X1: UInt16 = 139
HID_USAGE_ALPHANUMERIC_BLIT_RECTANGLE_Y1: UInt16 = 140
HID_USAGE_ALPHANUMERIC_BLIT_RECTANGLE_X2: UInt16 = 141
HID_USAGE_ALPHANUMERIC_BLIT_RECTANGLE_Y2: UInt16 = 142
HID_USAGE_ALPHANUMERIC_SOFT_BUTTON_ID: UInt16 = 145
HID_USAGE_ALPHANUMERIC_SOFT_BUTTON_SIDE: UInt16 = 146
HID_USAGE_ALPHANUMERIC_SOFT_BUTTON_OFFSET1: UInt16 = 147
HID_USAGE_ALPHANUMERIC_SOFT_BUTTON_OFFSET2: UInt16 = 148
HID_USAGE_ALPHANUMERIC_SOFT_BUTTON_REPORT: UInt16 = 149
HID_USAGE_LAMPARRAY: UInt16 = 1
HID_USAGE_LAMPARRAY_ATTRBIUTES_REPORT: UInt16 = 2
HID_USAGE_LAMPARRAY_LAMP_COUNT: UInt16 = 3
HID_USAGE_LAMPARRAY_BOUNDING_BOX_WIDTH_IN_MICROMETERS: UInt16 = 4
HID_USAGE_LAMPARRAY_BOUNDING_BOX_HEIGHT_IN_MICROMETERS: UInt16 = 5
HID_USAGE_LAMPARRAY_BOUNDING_BOX_DEPTH_IN_MICROMETERS: UInt16 = 6
HID_USAGE_LAMPARRAY_KIND: UInt16 = 7
HID_USAGE_LAMPARRAY_MIN_UPDATE_INTERVAL_IN_MICROSECONDS: UInt16 = 8
HID_USAGE_LAMPARRAY_LAMP_ATTRIBUTES_REQUEST_REPORT: UInt16 = 32
HID_USAGE_LAMPARRAY_LAMP_ID: UInt16 = 33
HID_USAGE_LAMPARRAY_LAMP_ATTRIBUTES_RESPONSE_REPORT: UInt16 = 34
HID_USAGE_LAMPARRAY_POSITION_X_IN_MICROMETERS: UInt16 = 35
HID_USAGE_LAMPARRAY_POSITION_Y_IN_MICROMETERS: UInt16 = 36
HID_USAGE_LAMPARRAY_POSITION_Z_IN_MICROMETERS: UInt16 = 37
HID_USAGE_LAMPARRAY_LAMP_PURPOSES: UInt16 = 38
HID_USAGE_LAMPARRAY_UPDATE_LATENCY_IN_MICROSECONDS: UInt16 = 39
HID_USAGE_LAMPARRAY_RED_LEVEL_COUNT: UInt16 = 40
HID_USAGE_LAMPARRAY_GREEN_LEVEL_COUNT: UInt16 = 41
HID_USAGE_LAMPARRAY_BLUE_LEVEL_COUNT: UInt16 = 42
HID_USAGE_LAMPARRAY_INTENSITY_LEVEL_COUNT: UInt16 = 43
HID_USAGE_LAMPARRAY_IS_PROGRAMMABLE: UInt16 = 44
HID_USAGE_LAMPARRAY_INPUT_BINDING: UInt16 = 45
HID_USAGE_LAMPARRAY_LAMP_MULTI_UPDATE_REPORT: UInt16 = 80
HID_USAGE_LAMPARRAY_LAMP_RED_UPDATE_CHANNEL: UInt16 = 81
HID_USAGE_LAMPARRAY_LAMP_GREEN_UPDATE_CHANNEL: UInt16 = 82
HID_USAGE_LAMPARRAY_LAMP_BLUE_UPDATE_CHANNEL: UInt16 = 83
HID_USAGE_LAMPARRAY_LAMP_INTENSITY_UPDATE_CHANNEL: UInt16 = 84
HID_USAGE_LAMPARRAY_LAMP_UPDATE_FLAGS: UInt16 = 85
HID_USAGE_LAMPARRAY_LAMP_RANGE_UPDATE_REPORT: UInt16 = 96
HID_USAGE_LAMPARRAY_LAMP_ID_START: UInt16 = 97
HID_USAGE_LAMPARRAY_LAMP_ID_END: UInt16 = 98
HID_USAGE_LAMPARRAY_CONTROL_REPORT: UInt16 = 112
HID_USAGE_LAMPARRAY_AUTONOMOUS_MODE: UInt16 = 113
HID_USAGE_CAMERA_AUTO_FOCUS: UInt16 = 32
HID_USAGE_CAMERA_SHUTTER: UInt16 = 33
HID_USAGE_MS_BTH_HF_DIALNUMBER: UInt16 = 33
HID_USAGE_MS_BTH_HF_DIALMEMORY: UInt16 = 34
DD_KEYBOARD_DEVICE_NAME: String = '\\Device\\KeyboardClass'
DD_KEYBOARD_DEVICE_NAME_U: String = '\\Device\\KeyboardClass'
IOCTL_KEYBOARD_QUERY_ATTRIBUTES: UInt32 = 720896
IOCTL_KEYBOARD_SET_TYPEMATIC: UInt32 = 720900
IOCTL_KEYBOARD_SET_INDICATORS: UInt32 = 720904
IOCTL_KEYBOARD_QUERY_TYPEMATIC: UInt32 = 720928
IOCTL_KEYBOARD_QUERY_INDICATORS: UInt32 = 720960
IOCTL_KEYBOARD_QUERY_INDICATOR_TRANSLATION: UInt32 = 721024
IOCTL_KEYBOARD_INSERT_DATA: UInt32 = 721152
IOCTL_KEYBOARD_QUERY_EXTENDED_ATTRIBUTES: UInt32 = 721408
IOCTL_KEYBOARD_QUERY_IME_STATUS: UInt32 = 724992
IOCTL_KEYBOARD_SET_IME_STATUS: UInt32 = 724996
GUID_DEVINTERFACE_KEYBOARD: Guid = Guid('{884b96c3-56ef-11d1-bc8c-00a0c91405dd}')
KEYBOARD_OVERRUN_MAKE_CODE: UInt32 = 255
KEY_MAKE: UInt32 = 0
KEY_BREAK: UInt32 = 1
KEY_E0: UInt32 = 2
KEY_E1: UInt32 = 4
KEY_TERMSRV_SET_LED: UInt32 = 8
KEY_TERMSRV_SHADOW: UInt32 = 16
KEY_TERMSRV_VKPACKET: UInt32 = 32
KEY_RIM_VKEY: UInt32 = 64
KEY_FROM_KEYBOARD_OVERRIDER: UInt32 = 128
KEY_UNICODE_SEQUENCE_ITEM: UInt32 = 256
KEY_UNICODE_SEQUENCE_END: UInt32 = 512
KEYBOARD_EXTENDED_ATTRIBUTES_STRUCT_VERSION_1: UInt32 = 1
KEYBOARD_LED_INJECTED: UInt32 = 32768
KEYBOARD_SHADOW: UInt32 = 16384
KEYBOARD_KANA_LOCK_ON: UInt32 = 8
KEYBOARD_CAPS_LOCK_ON: UInt32 = 4
KEYBOARD_NUM_LOCK_ON: UInt32 = 2
KEYBOARD_SCROLL_LOCK_ON: UInt32 = 1
KEYBOARD_ERROR_VALUE_BASE: UInt32 = 10000
DD_MOUSE_DEVICE_NAME: String = '\\Device\\PointerClass'
DD_MOUSE_DEVICE_NAME_U: String = '\\Device\\PointerClass'
IOCTL_MOUSE_QUERY_ATTRIBUTES: UInt32 = 983040
IOCTL_MOUSE_INSERT_DATA: UInt32 = 983044
GUID_DEVINTERFACE_MOUSE: Guid = Guid('{378de44c-56ef-11d1-bc8c-00a0c91405dd}')
MOUSE_LEFT_BUTTON_DOWN: UInt32 = 1
MOUSE_LEFT_BUTTON_UP: UInt32 = 2
MOUSE_RIGHT_BUTTON_DOWN: UInt32 = 4
MOUSE_RIGHT_BUTTON_UP: UInt32 = 8
MOUSE_MIDDLE_BUTTON_DOWN: UInt32 = 16
MOUSE_MIDDLE_BUTTON_UP: UInt32 = 32
MOUSE_BUTTON_1_DOWN: UInt32 = 1
MOUSE_BUTTON_1_UP: UInt32 = 2
MOUSE_BUTTON_2_DOWN: UInt32 = 4
MOUSE_BUTTON_2_UP: UInt32 = 8
MOUSE_BUTTON_3_DOWN: UInt32 = 16
MOUSE_BUTTON_3_UP: UInt32 = 32
MOUSE_BUTTON_4_DOWN: UInt32 = 64
MOUSE_BUTTON_4_UP: UInt32 = 128
MOUSE_BUTTON_5_DOWN: UInt32 = 256
MOUSE_BUTTON_5_UP: UInt32 = 512
MOUSE_WHEEL: UInt32 = 1024
MOUSE_HWHEEL: UInt32 = 2048
MOUSE_TERMSRV_SRC_SHADOW: UInt32 = 256
MOUSE_INPORT_HARDWARE: UInt32 = 1
MOUSE_I8042_HARDWARE: UInt32 = 2
MOUSE_SERIAL_HARDWARE: UInt32 = 4
BALLPOINT_I8042_HARDWARE: UInt32 = 8
BALLPOINT_SERIAL_HARDWARE: UInt32 = 16
WHEELMOUSE_I8042_HARDWARE: UInt32 = 32
WHEELMOUSE_SERIAL_HARDWARE: UInt32 = 64
MOUSE_HID_HARDWARE: UInt32 = 128
WHEELMOUSE_HID_HARDWARE: UInt32 = 256
HORIZONTAL_WHEEL_PRESENT: UInt32 = 32768
MOUSE_ERROR_VALUE_BASE: UInt32 = 20000
DIRECTINPUT_HEADER_VERSION: UInt32 = 2048
CLSID_DirectInput: Guid = Guid('{25e609e0-b259-11cf-bfc7-444553540000}')
CLSID_DirectInputDevice: Guid = Guid('{25e609e1-b259-11cf-bfc7-444553540000}')
CLSID_DirectInput8: Guid = Guid('{25e609e4-b259-11cf-bfc7-444553540000}')
CLSID_DirectInputDevice8: Guid = Guid('{25e609e5-b259-11cf-bfc7-444553540000}')
GUID_XAxis: Guid = Guid('{a36d02e0-c9f3-11cf-bfc7-444553540000}')
GUID_YAxis: Guid = Guid('{a36d02e1-c9f3-11cf-bfc7-444553540000}')
GUID_ZAxis: Guid = Guid('{a36d02e2-c9f3-11cf-bfc7-444553540000}')
GUID_RxAxis: Guid = Guid('{a36d02f4-c9f3-11cf-bfc7-444553540000}')
GUID_RyAxis: Guid = Guid('{a36d02f5-c9f3-11cf-bfc7-444553540000}')
GUID_RzAxis: Guid = Guid('{a36d02e3-c9f3-11cf-bfc7-444553540000}')
GUID_Slider: Guid = Guid('{a36d02e4-c9f3-11cf-bfc7-444553540000}')
GUID_Button: Guid = Guid('{a36d02f0-c9f3-11cf-bfc7-444553540000}')
GUID_Key: Guid = Guid('{55728220-d33c-11cf-bfc7-444553540000}')
GUID_POV: Guid = Guid('{a36d02f2-c9f3-11cf-bfc7-444553540000}')
GUID_Unknown: Guid = Guid('{a36d02f3-c9f3-11cf-bfc7-444553540000}')
GUID_SysMouse: Guid = Guid('{6f1d2b60-d5a0-11cf-bfc7-444553540000}')
GUID_SysKeyboard: Guid = Guid('{6f1d2b61-d5a0-11cf-bfc7-444553540000}')
GUID_Joystick: Guid = Guid('{6f1d2b70-d5a0-11cf-bfc7-444553540000}')
GUID_SysMouseEm: Guid = Guid('{6f1d2b80-d5a0-11cf-bfc7-444553540000}')
GUID_SysMouseEm2: Guid = Guid('{6f1d2b81-d5a0-11cf-bfc7-444553540000}')
GUID_SysKeyboardEm: Guid = Guid('{6f1d2b82-d5a0-11cf-bfc7-444553540000}')
GUID_SysKeyboardEm2: Guid = Guid('{6f1d2b83-d5a0-11cf-bfc7-444553540000}')
GUID_ConstantForce: Guid = Guid('{13541c20-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_RampForce: Guid = Guid('{13541c21-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_Square: Guid = Guid('{13541c22-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_Sine: Guid = Guid('{13541c23-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_Triangle: Guid = Guid('{13541c24-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_SawtoothUp: Guid = Guid('{13541c25-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_SawtoothDown: Guid = Guid('{13541c26-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_Spring: Guid = Guid('{13541c27-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_Damper: Guid = Guid('{13541c28-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_Inertia: Guid = Guid('{13541c29-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_Friction: Guid = Guid('{13541c2a-8e33-11d0-9ad0-00a0c9a06e35}')
GUID_CustomForce: Guid = Guid('{13541c2b-8e33-11d0-9ad0-00a0c9a06e35}')
DIEFT_ALL: UInt32 = 0
DIEFT_CONSTANTFORCE: UInt32 = 1
DIEFT_RAMPFORCE: UInt32 = 2
DIEFT_PERIODIC: UInt32 = 3
DIEFT_CONDITION: UInt32 = 4
DIEFT_CUSTOMFORCE: UInt32 = 5
DIEFT_HARDWARE: UInt32 = 255
DIEFT_FFATTACK: UInt32 = 512
DIEFT_FFFADE: UInt32 = 1024
DIEFT_SATURATION: UInt32 = 2048
DIEFT_POSNEGCOEFFICIENTS: UInt32 = 4096
DIEFT_POSNEGSATURATION: UInt32 = 8192
DIEFT_DEADBAND: UInt32 = 16384
DIEFT_STARTDELAY: UInt32 = 32768
DI_DEGREES: UInt32 = 100
DI_FFNOMINALMAX: UInt32 = 10000
DI_SECONDS: UInt32 = 1000000
DIEFF_OBJECTIDS: UInt32 = 1
DIEFF_OBJECTOFFSETS: UInt32 = 2
DIEFF_CARTESIAN: UInt32 = 16
DIEFF_POLAR: UInt32 = 32
DIEFF_SPHERICAL: UInt32 = 64
DIEP_DURATION: UInt32 = 1
DIEP_SAMPLEPERIOD: UInt32 = 2
DIEP_GAIN: UInt32 = 4
DIEP_TRIGGERBUTTON: UInt32 = 8
DIEP_TRIGGERREPEATINTERVAL: UInt32 = 16
DIEP_AXES: UInt32 = 32
DIEP_DIRECTION: UInt32 = 64
DIEP_ENVELOPE: UInt32 = 128
DIEP_TYPESPECIFICPARAMS: UInt32 = 256
DIEP_STARTDELAY: UInt32 = 512
DIEP_ALLPARAMS_DX5: UInt32 = 511
DIEP_ALLPARAMS: UInt32 = 1023
DIEP_START: UInt32 = 536870912
DIEP_NORESTART: UInt32 = 1073741824
DIEP_NODOWNLOAD: UInt32 = 2147483648
DIEB_NOTRIGGER: UInt32 = 4294967295
DIES_SOLO: UInt32 = 1
DIES_NODOWNLOAD: UInt32 = 2147483648
DIEGES_PLAYING: UInt32 = 1
DIEGES_EMULATED: UInt32 = 2
DIDEVTYPE_DEVICE: UInt32 = 1
DIDEVTYPE_MOUSE: UInt32 = 2
DIDEVTYPE_KEYBOARD: UInt32 = 3
DIDEVTYPE_JOYSTICK: UInt32 = 4
DI8DEVCLASS_ALL: UInt32 = 0
DI8DEVCLASS_DEVICE: UInt32 = 1
DI8DEVCLASS_POINTER: UInt32 = 2
DI8DEVCLASS_KEYBOARD: UInt32 = 3
DI8DEVCLASS_GAMECTRL: UInt32 = 4
DI8DEVTYPE_DEVICE: UInt32 = 17
DI8DEVTYPE_MOUSE: UInt32 = 18
DI8DEVTYPE_KEYBOARD: UInt32 = 19
DI8DEVTYPE_JOYSTICK: UInt32 = 20
DI8DEVTYPE_GAMEPAD: UInt32 = 21
DI8DEVTYPE_DRIVING: UInt32 = 22
DI8DEVTYPE_FLIGHT: UInt32 = 23
DI8DEVTYPE_1STPERSON: UInt32 = 24
DI8DEVTYPE_DEVICECTRL: UInt32 = 25
DI8DEVTYPE_SCREENPOINTER: UInt32 = 26
DI8DEVTYPE_REMOTE: UInt32 = 27
DI8DEVTYPE_SUPPLEMENTAL: UInt32 = 28
DIDEVTYPE_HID: UInt32 = 65536
DIDEVTYPEMOUSE_UNKNOWN: UInt32 = 1
DIDEVTYPEMOUSE_TRADITIONAL: UInt32 = 2
DIDEVTYPEMOUSE_FINGERSTICK: UInt32 = 3
DIDEVTYPEMOUSE_TOUCHPAD: UInt32 = 4
DIDEVTYPEMOUSE_TRACKBALL: UInt32 = 5
DIDEVTYPEKEYBOARD_UNKNOWN: UInt32 = 0
DIDEVTYPEKEYBOARD_PCXT: UInt32 = 1
DIDEVTYPEKEYBOARD_OLIVETTI: UInt32 = 2
DIDEVTYPEKEYBOARD_PCAT: UInt32 = 3
DIDEVTYPEKEYBOARD_PCENH: UInt32 = 4
DIDEVTYPEKEYBOARD_NOKIA1050: UInt32 = 5
DIDEVTYPEKEYBOARD_NOKIA9140: UInt32 = 6
DIDEVTYPEKEYBOARD_NEC98: UInt32 = 7
DIDEVTYPEKEYBOARD_NEC98LAPTOP: UInt32 = 8
DIDEVTYPEKEYBOARD_NEC98106: UInt32 = 9
DIDEVTYPEKEYBOARD_JAPAN106: UInt32 = 10
DIDEVTYPEKEYBOARD_JAPANAX: UInt32 = 11
DIDEVTYPEKEYBOARD_J3100: UInt32 = 12
DIDEVTYPEJOYSTICK_UNKNOWN: UInt32 = 1
DIDEVTYPEJOYSTICK_TRADITIONAL: UInt32 = 2
DIDEVTYPEJOYSTICK_FLIGHTSTICK: UInt32 = 3
DIDEVTYPEJOYSTICK_GAMEPAD: UInt32 = 4
DIDEVTYPEJOYSTICK_RUDDER: UInt32 = 5
DIDEVTYPEJOYSTICK_WHEEL: UInt32 = 6
DIDEVTYPEJOYSTICK_HEADTRACKER: UInt32 = 7
DI8DEVTYPEMOUSE_UNKNOWN: UInt32 = 1
DI8DEVTYPEMOUSE_TRADITIONAL: UInt32 = 2
DI8DEVTYPEMOUSE_FINGERSTICK: UInt32 = 3
DI8DEVTYPEMOUSE_TOUCHPAD: UInt32 = 4
DI8DEVTYPEMOUSE_TRACKBALL: UInt32 = 5
DI8DEVTYPEMOUSE_ABSOLUTE: UInt32 = 6
DI8DEVTYPEKEYBOARD_UNKNOWN: UInt32 = 0
DI8DEVTYPEKEYBOARD_PCXT: UInt32 = 1
DI8DEVTYPEKEYBOARD_OLIVETTI: UInt32 = 2
DI8DEVTYPEKEYBOARD_PCAT: UInt32 = 3
DI8DEVTYPEKEYBOARD_PCENH: UInt32 = 4
DI8DEVTYPEKEYBOARD_NOKIA1050: UInt32 = 5
DI8DEVTYPEKEYBOARD_NOKIA9140: UInt32 = 6
DI8DEVTYPEKEYBOARD_NEC98: UInt32 = 7
DI8DEVTYPEKEYBOARD_NEC98LAPTOP: UInt32 = 8
DI8DEVTYPEKEYBOARD_NEC98106: UInt32 = 9
DI8DEVTYPEKEYBOARD_JAPAN106: UInt32 = 10
DI8DEVTYPEKEYBOARD_JAPANAX: UInt32 = 11
DI8DEVTYPEKEYBOARD_J3100: UInt32 = 12
DI8DEVTYPE_LIMITEDGAMESUBTYPE: UInt32 = 1
DI8DEVTYPEJOYSTICK_LIMITED: UInt32 = 1
DI8DEVTYPEJOYSTICK_STANDARD: UInt32 = 2
DI8DEVTYPEGAMEPAD_LIMITED: UInt32 = 1
DI8DEVTYPEGAMEPAD_STANDARD: UInt32 = 2
DI8DEVTYPEGAMEPAD_TILT: UInt32 = 3
DI8DEVTYPEDRIVING_LIMITED: UInt32 = 1
DI8DEVTYPEDRIVING_COMBINEDPEDALS: UInt32 = 2
DI8DEVTYPEDRIVING_DUALPEDALS: UInt32 = 3
DI8DEVTYPEDRIVING_THREEPEDALS: UInt32 = 4
DI8DEVTYPEDRIVING_HANDHELD: UInt32 = 5
DI8DEVTYPEFLIGHT_LIMITED: UInt32 = 1
DI8DEVTYPEFLIGHT_STICK: UInt32 = 2
DI8DEVTYPEFLIGHT_YOKE: UInt32 = 3
DI8DEVTYPEFLIGHT_RC: UInt32 = 4
DI8DEVTYPE1STPERSON_LIMITED: UInt32 = 1
DI8DEVTYPE1STPERSON_UNKNOWN: UInt32 = 2
DI8DEVTYPE1STPERSON_SIXDOF: UInt32 = 3
DI8DEVTYPE1STPERSON_SHOOTER: UInt32 = 4
DI8DEVTYPESCREENPTR_UNKNOWN: UInt32 = 2
DI8DEVTYPESCREENPTR_LIGHTGUN: UInt32 = 3
DI8DEVTYPESCREENPTR_LIGHTPEN: UInt32 = 4
DI8DEVTYPESCREENPTR_TOUCH: UInt32 = 5
DI8DEVTYPEREMOTE_UNKNOWN: UInt32 = 2
DI8DEVTYPEDEVICECTRL_UNKNOWN: UInt32 = 2
DI8DEVTYPEDEVICECTRL_COMMSSELECTION: UInt32 = 3
DI8DEVTYPEDEVICECTRL_COMMSSELECTION_HARDWIRED: UInt32 = 4
DI8DEVTYPESUPPLEMENTAL_UNKNOWN: UInt32 = 2
DI8DEVTYPESUPPLEMENTAL_2NDHANDCONTROLLER: UInt32 = 3
DI8DEVTYPESUPPLEMENTAL_HEADTRACKER: UInt32 = 4
DI8DEVTYPESUPPLEMENTAL_HANDTRACKER: UInt32 = 5
DI8DEVTYPESUPPLEMENTAL_SHIFTSTICKGATE: UInt32 = 6
DI8DEVTYPESUPPLEMENTAL_SHIFTER: UInt32 = 7
DI8DEVTYPESUPPLEMENTAL_THROTTLE: UInt32 = 8
DI8DEVTYPESUPPLEMENTAL_SPLITTHROTTLE: UInt32 = 9
DI8DEVTYPESUPPLEMENTAL_COMBINEDPEDALS: UInt32 = 10
DI8DEVTYPESUPPLEMENTAL_DUALPEDALS: UInt32 = 11
DI8DEVTYPESUPPLEMENTAL_THREEPEDALS: UInt32 = 12
DI8DEVTYPESUPPLEMENTAL_RUDDERPEDALS: UInt32 = 13
DIDC_ATTACHED: UInt32 = 1
DIDC_POLLEDDEVICE: UInt32 = 2
DIDC_EMULATED: UInt32 = 4
DIDC_POLLEDDATAFORMAT: UInt32 = 8
DIDC_FORCEFEEDBACK: UInt32 = 256
DIDC_FFATTACK: UInt32 = 512
DIDC_FFFADE: UInt32 = 1024
DIDC_SATURATION: UInt32 = 2048
DIDC_POSNEGCOEFFICIENTS: UInt32 = 4096
DIDC_POSNEGSATURATION: UInt32 = 8192
DIDC_DEADBAND: UInt32 = 16384
DIDC_STARTDELAY: UInt32 = 32768
DIDC_ALIAS: UInt32 = 65536
DIDC_PHANTOM: UInt32 = 131072
DIDC_HIDDEN: UInt32 = 262144
DIDFT_ALL: UInt32 = 0
DIDFT_RELAXIS: UInt32 = 1
DIDFT_ABSAXIS: UInt32 = 2
DIDFT_AXIS: UInt32 = 3
DIDFT_PSHBUTTON: UInt32 = 4
DIDFT_TGLBUTTON: UInt32 = 8
DIDFT_BUTTON: UInt32 = 12
DIDFT_POV: UInt32 = 16
DIDFT_COLLECTION: UInt32 = 64
DIDFT_NODATA: UInt32 = 128
DIDFT_ANYINSTANCE: UInt32 = 16776960
DIDFT_INSTANCEMASK: UInt32 = 16776960
DIDFT_FFACTUATOR: UInt32 = 16777216
DIDFT_FFEFFECTTRIGGER: UInt32 = 33554432
DIDFT_OUTPUT: UInt32 = 268435456
DIDFT_VENDORDEFINED: UInt32 = 67108864
DIDFT_ALIAS: UInt32 = 134217728
DIDFT_NOCOLLECTION: UInt32 = 16776960
DIDF_ABSAXIS: UInt32 = 1
DIDF_RELAXIS: UInt32 = 2
DIA_FORCEFEEDBACK: UInt32 = 1
DIA_APPMAPPED: UInt32 = 2
DIA_APPNOMAP: UInt32 = 4
DIA_NORANGE: UInt32 = 8
DIA_APPFIXED: UInt32 = 16
DIAH_UNMAPPED: UInt32 = 0
DIAH_USERCONFIG: UInt32 = 1
DIAH_APPREQUESTED: UInt32 = 2
DIAH_HWAPP: UInt32 = 4
DIAH_HWDEFAULT: UInt32 = 8
DIAH_DEFAULT: UInt32 = 32
DIAH_ERROR: UInt32 = 2147483648
DIAFTS_NEWDEVICELOW: UInt32 = 4294967295
DIAFTS_NEWDEVICEHIGH: UInt32 = 4294967295
DIAFTS_UNUSEDDEVICELOW: UInt32 = 0
DIAFTS_UNUSEDDEVICEHIGH: UInt32 = 0
DIDBAM_DEFAULT: UInt32 = 0
DIDBAM_PRESERVE: UInt32 = 1
DIDBAM_INITIALIZE: UInt32 = 2
DIDBAM_HWDEFAULTS: UInt32 = 4
DIDSAM_DEFAULT: UInt32 = 0
DIDSAM_NOUSER: UInt32 = 1
DIDSAM_FORCESAVE: UInt32 = 2
DICD_DEFAULT: UInt32 = 0
DICD_EDIT: UInt32 = 1
DIDIFT_CONFIGURATION: UInt32 = 1
DIDIFT_OVERLAY: UInt32 = 2
DIDAL_CENTERED: UInt32 = 0
DIDAL_LEFTALIGNED: UInt32 = 1
DIDAL_RIGHTALIGNED: UInt32 = 2
DIDAL_MIDDLE: UInt32 = 0
DIDAL_TOPALIGNED: UInt32 = 4
DIDAL_BOTTOMALIGNED: UInt32 = 8
DIDOI_FFACTUATOR: UInt32 = 1
DIDOI_FFEFFECTTRIGGER: UInt32 = 2
DIDOI_POLLED: UInt32 = 32768
DIDOI_ASPECTPOSITION: UInt32 = 256
DIDOI_ASPECTVELOCITY: UInt32 = 512
DIDOI_ASPECTACCEL: UInt32 = 768
DIDOI_ASPECTFORCE: UInt32 = 1024
DIDOI_ASPECTMASK: UInt32 = 3840
DIDOI_GUIDISUSAGE: UInt32 = 65536
DIPH_DEVICE: UInt32 = 0
DIPH_BYOFFSET: UInt32 = 1
DIPH_BYID: UInt32 = 2
DIPH_BYUSAGE: UInt32 = 3
MAXCPOINTSNUM: UInt32 = 8
DIPROP_BUFFERSIZE: Guid = Guid('{00000000-0000-0000-0000-000000000001}')
DIPROP_AXISMODE: Guid = Guid('{00000000-0000-0000-0000-000000000002}')
DIPROPAXISMODE_ABS: UInt32 = 0
DIPROPAXISMODE_REL: UInt32 = 1
DIPROP_GRANULARITY: Guid = Guid('{00000000-0000-0000-0000-000000000003}')
DIPROP_RANGE: Guid = Guid('{00000000-0000-0000-0000-000000000004}')
DIPROP_DEADZONE: Guid = Guid('{00000000-0000-0000-0000-000000000005}')
DIPROP_SATURATION: Guid = Guid('{00000000-0000-0000-0000-000000000006}')
DIPROP_FFGAIN: Guid = Guid('{00000000-0000-0000-0000-000000000007}')
DIPROP_FFLOAD: Guid = Guid('{00000000-0000-0000-0000-000000000008}')
DIPROP_AUTOCENTER: Guid = Guid('{00000000-0000-0000-0000-000000000009}')
DIPROPAUTOCENTER_OFF: UInt32 = 0
DIPROPAUTOCENTER_ON: UInt32 = 1
DIPROP_CALIBRATIONMODE: Guid = Guid('{00000000-0000-0000-0000-00000000000a}')
DIPROPCALIBRATIONMODE_COOKED: UInt32 = 0
DIPROPCALIBRATIONMODE_RAW: UInt32 = 1
DIPROP_CALIBRATION: Guid = Guid('{00000000-0000-0000-0000-00000000000b}')
DIPROP_GUIDANDPATH: Guid = Guid('{00000000-0000-0000-0000-00000000000c}')
DIPROP_INSTANCENAME: Guid = Guid('{00000000-0000-0000-0000-00000000000d}')
DIPROP_PRODUCTNAME: Guid = Guid('{00000000-0000-0000-0000-00000000000e}')
DIPROP_JOYSTICKID: Guid = Guid('{00000000-0000-0000-0000-00000000000f}')
DIPROP_GETPORTDISPLAYNAME: Guid = Guid('{00000000-0000-0000-0000-000000000010}')
DIPROP_PHYSICALRANGE: Guid = Guid('{00000000-0000-0000-0000-000000000012}')
DIPROP_LOGICALRANGE: Guid = Guid('{00000000-0000-0000-0000-000000000013}')
DIPROP_KEYNAME: Guid = Guid('{00000000-0000-0000-0000-000000000014}')
DIPROP_CPOINTS: Guid = Guid('{00000000-0000-0000-0000-000000000015}')
DIPROP_APPDATA: Guid = Guid('{00000000-0000-0000-0000-000000000016}')
DIPROP_SCANCODE: Guid = Guid('{00000000-0000-0000-0000-000000000017}')
DIPROP_VIDPID: Guid = Guid('{00000000-0000-0000-0000-000000000018}')
DIPROP_USERNAME: Guid = Guid('{00000000-0000-0000-0000-000000000019}')
DIPROP_TYPENAME: Guid = Guid('{00000000-0000-0000-0000-00000000001a}')
DIGDD_PEEK: UInt32 = 1
DISCL_EXCLUSIVE: UInt32 = 1
DISCL_NONEXCLUSIVE: UInt32 = 2
DISCL_FOREGROUND: UInt32 = 4
DISCL_BACKGROUND: UInt32 = 8
DISCL_NOWINKEY: UInt32 = 16
DISFFC_RESET: UInt32 = 1
DISFFC_STOPALL: UInt32 = 2
DISFFC_PAUSE: UInt32 = 4
DISFFC_CONTINUE: UInt32 = 8
DISFFC_SETACTUATORSON: UInt32 = 16
DISFFC_SETACTUATORSOFF: UInt32 = 32
DIGFFS_EMPTY: UInt32 = 1
DIGFFS_STOPPED: UInt32 = 2
DIGFFS_PAUSED: UInt32 = 4
DIGFFS_ACTUATORSON: UInt32 = 16
DIGFFS_ACTUATORSOFF: UInt32 = 32
DIGFFS_POWERON: UInt32 = 64
DIGFFS_POWEROFF: UInt32 = 128
DIGFFS_SAFETYSWITCHON: UInt32 = 256
DIGFFS_SAFETYSWITCHOFF: UInt32 = 512
DIGFFS_USERFFSWITCHON: UInt32 = 1024
DIGFFS_USERFFSWITCHOFF: UInt32 = 2048
DIGFFS_DEVICELOST: UInt32 = 2147483648
DISDD_CONTINUE: UInt32 = 1
DIFEF_DEFAULT: UInt32 = 0
DIFEF_INCLUDENONSTANDARD: UInt32 = 1
DIFEF_MODIFYIFNEEDED: UInt32 = 16
DIK_ESCAPE: UInt32 = 1
DIK_1: UInt32 = 2
DIK_2: UInt32 = 3
DIK_3: UInt32 = 4
DIK_4: UInt32 = 5
DIK_5: UInt32 = 6
DIK_6: UInt32 = 7
DIK_7: UInt32 = 8
DIK_8: UInt32 = 9
DIK_9: UInt32 = 10
DIK_0: UInt32 = 11
DIK_MINUS: UInt32 = 12
DIK_EQUALS: UInt32 = 13
DIK_BACK: UInt32 = 14
DIK_TAB: UInt32 = 15
DIK_Q: UInt32 = 16
DIK_W: UInt32 = 17
DIK_E: UInt32 = 18
DIK_R: UInt32 = 19
DIK_T: UInt32 = 20
DIK_Y: UInt32 = 21
DIK_U: UInt32 = 22
DIK_I: UInt32 = 23
DIK_O: UInt32 = 24
DIK_P: UInt32 = 25
DIK_LBRACKET: UInt32 = 26
DIK_RBRACKET: UInt32 = 27
DIK_RETURN: UInt32 = 28
DIK_LCONTROL: UInt32 = 29
DIK_A: UInt32 = 30
DIK_S: UInt32 = 31
DIK_D: UInt32 = 32
DIK_F: UInt32 = 33
DIK_G: UInt32 = 34
DIK_H: UInt32 = 35
DIK_J: UInt32 = 36
DIK_K: UInt32 = 37
DIK_L: UInt32 = 38
DIK_SEMICOLON: UInt32 = 39
DIK_APOSTROPHE: UInt32 = 40
DIK_GRAVE: UInt32 = 41
DIK_LSHIFT: UInt32 = 42
DIK_BACKSLASH: UInt32 = 43
DIK_Z: UInt32 = 44
DIK_X: UInt32 = 45
DIK_C: UInt32 = 46
DIK_V: UInt32 = 47
DIK_B: UInt32 = 48
DIK_N: UInt32 = 49
DIK_M: UInt32 = 50
DIK_COMMA: UInt32 = 51
DIK_PERIOD: UInt32 = 52
DIK_SLASH: UInt32 = 53
DIK_RSHIFT: UInt32 = 54
DIK_MULTIPLY: UInt32 = 55
DIK_LMENU: UInt32 = 56
DIK_SPACE: UInt32 = 57
DIK_CAPITAL: UInt32 = 58
DIK_F1: UInt32 = 59
DIK_F2: UInt32 = 60
DIK_F3: UInt32 = 61
DIK_F4: UInt32 = 62
DIK_F5: UInt32 = 63
DIK_F6: UInt32 = 64
DIK_F7: UInt32 = 65
DIK_F8: UInt32 = 66
DIK_F9: UInt32 = 67
DIK_F10: UInt32 = 68
DIK_NUMLOCK: UInt32 = 69
DIK_SCROLL: UInt32 = 70
DIK_NUMPAD7: UInt32 = 71
DIK_NUMPAD8: UInt32 = 72
DIK_NUMPAD9: UInt32 = 73
DIK_SUBTRACT: UInt32 = 74
DIK_NUMPAD4: UInt32 = 75
DIK_NUMPAD5: UInt32 = 76
DIK_NUMPAD6: UInt32 = 77
DIK_ADD: UInt32 = 78
DIK_NUMPAD1: UInt32 = 79
DIK_NUMPAD2: UInt32 = 80
DIK_NUMPAD3: UInt32 = 81
DIK_NUMPAD0: UInt32 = 82
DIK_DECIMAL: UInt32 = 83
DIK_OEM_102: UInt32 = 86
DIK_F11: UInt32 = 87
DIK_F12: UInt32 = 88
DIK_F13: UInt32 = 100
DIK_F14: UInt32 = 101
DIK_F15: UInt32 = 102
DIK_KANA: UInt32 = 112
DIK_ABNT_C1: UInt32 = 115
DIK_CONVERT: UInt32 = 121
DIK_NOCONVERT: UInt32 = 123
DIK_YEN: UInt32 = 125
DIK_ABNT_C2: UInt32 = 126
DIK_NUMPADEQUALS: UInt32 = 141
DIK_PREVTRACK: UInt32 = 144
DIK_AT: UInt32 = 145
DIK_COLON: UInt32 = 146
DIK_UNDERLINE: UInt32 = 147
DIK_KANJI: UInt32 = 148
DIK_STOP: UInt32 = 149
DIK_AX: UInt32 = 150
DIK_UNLABELED: UInt32 = 151
DIK_NEXTTRACK: UInt32 = 153
DIK_NUMPADENTER: UInt32 = 156
DIK_RCONTROL: UInt32 = 157
DIK_MUTE: UInt32 = 160
DIK_CALCULATOR: UInt32 = 161
DIK_PLAYPAUSE: UInt32 = 162
DIK_MEDIASTOP: UInt32 = 164
DIK_VOLUMEDOWN: UInt32 = 174
DIK_VOLUMEUP: UInt32 = 176
DIK_WEBHOME: UInt32 = 178
DIK_NUMPADCOMMA: UInt32 = 179
DIK_DIVIDE: UInt32 = 181
DIK_SYSRQ: UInt32 = 183
DIK_RMENU: UInt32 = 184
DIK_PAUSE: UInt32 = 197
DIK_HOME: UInt32 = 199
DIK_UP: UInt32 = 200
DIK_PRIOR: UInt32 = 201
DIK_LEFT: UInt32 = 203
DIK_RIGHT: UInt32 = 205
DIK_END: UInt32 = 207
DIK_DOWN: UInt32 = 208
DIK_NEXT: UInt32 = 209
DIK_INSERT: UInt32 = 210
DIK_DELETE: UInt32 = 211
DIK_LWIN: UInt32 = 219
DIK_RWIN: UInt32 = 220
DIK_APPS: UInt32 = 221
DIK_POWER: UInt32 = 222
DIK_SLEEP: UInt32 = 223
DIK_WAKE: UInt32 = 227
DIK_WEBSEARCH: UInt32 = 229
DIK_WEBFAVORITES: UInt32 = 230
DIK_WEBREFRESH: UInt32 = 231
DIK_WEBSTOP: UInt32 = 232
DIK_WEBFORWARD: UInt32 = 233
DIK_WEBBACK: UInt32 = 234
DIK_MYCOMPUTER: UInt32 = 235
DIK_MAIL: UInt32 = 236
DIK_MEDIASELECT: UInt32 = 237
DIK_BACKSPACE: UInt32 = 14
DIK_NUMPADSTAR: UInt32 = 55
DIK_LALT: UInt32 = 56
DIK_CAPSLOCK: UInt32 = 58
DIK_NUMPADMINUS: UInt32 = 74
DIK_NUMPADPLUS: UInt32 = 78
DIK_NUMPADPERIOD: UInt32 = 83
DIK_NUMPADSLASH: UInt32 = 181
DIK_RALT: UInt32 = 184
DIK_UPARROW: UInt32 = 200
DIK_PGUP: UInt32 = 201
DIK_LEFTARROW: UInt32 = 203
DIK_RIGHTARROW: UInt32 = 205
DIK_DOWNARROW: UInt32 = 208
DIK_PGDN: UInt32 = 209
DIK_CIRCUMFLEX: UInt32 = 144
DIENUM_STOP: UInt32 = 0
DIENUM_CONTINUE: UInt32 = 1
DIEDFL_ALLDEVICES: UInt32 = 0
DIEDFL_ATTACHEDONLY: UInt32 = 1
DIEDFL_FORCEFEEDBACK: UInt32 = 256
DIEDFL_INCLUDEALIASES: UInt32 = 65536
DIEDFL_INCLUDEPHANTOMS: UInt32 = 131072
DIEDFL_INCLUDEHIDDEN: UInt32 = 262144
DIEDBS_MAPPEDPRI1: UInt32 = 1
DIEDBS_MAPPEDPRI2: UInt32 = 2
DIEDBS_RECENTDEVICE: UInt32 = 16
DIEDBS_NEWDEVICE: UInt32 = 32
DIEDBSFL_ATTACHEDONLY: UInt32 = 0
DIEDBSFL_THISUSER: UInt32 = 16
DIEDBSFL_FORCEFEEDBACK: UInt32 = 256
DIEDBSFL_AVAILABLEDEVICES: UInt32 = 4096
DIEDBSFL_MULTIMICEKEYBOARDS: UInt32 = 8192
DIEDBSFL_NONGAMINGDEVICES: UInt32 = 16384
DIEDBSFL_VALID: UInt32 = 28944
DI_OK: Int32 = 0
DI_NOTATTACHED: Int32 = 1
DI_BUFFEROVERFLOW: Int32 = 1
DI_PROPNOEFFECT: Int32 = 1
DI_NOEFFECT: Int32 = 1
DI_POLLEDDEVICE: win32more.Windows.Win32.Foundation.HRESULT = 2
DI_DOWNLOADSKIPPED: win32more.Windows.Win32.Foundation.HRESULT = 3
DI_EFFECTRESTARTED: win32more.Windows.Win32.Foundation.HRESULT = 4
DI_TRUNCATED: win32more.Windows.Win32.Foundation.HRESULT = 8
DI_SETTINGSNOTSAVED: win32more.Windows.Win32.Foundation.HRESULT = 11
DI_TRUNCATEDANDRESTARTED: win32more.Windows.Win32.Foundation.HRESULT = 12
DI_WRITEPROTECT: win32more.Windows.Win32.Foundation.HRESULT = 19
DIERR_OLDDIRECTINPUTVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147023746
DIERR_BETADIRECTINPUTVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147023743
DIERR_BADDRIVERVER: win32more.Windows.Win32.Foundation.HRESULT = -2147024777
DIERR_DEVICENOTREG: Int32 = -2147221164
DIERR_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147024894
DIERR_OBJECTNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147024894
DIERR_INVALIDPARAM: Int32 = -2147024809
DIERR_NOINTERFACE: Int32 = -2147467262
DIERR_GENERIC: Int32 = -2147467259
DIERR_OUTOFMEMORY: Int32 = -2147024882
DIERR_UNSUPPORTED: Int32 = -2147467263
DIERR_NOTINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147024875
DIERR_ALREADYINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147023649
DIERR_NOAGGREGATION: Int32 = -2147221232
DIERR_OTHERAPPHASPRIO: Int32 = -2147024891
DIERR_INPUTLOST: win32more.Windows.Win32.Foundation.HRESULT = -2147024866
DIERR_ACQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2147024726
DIERR_NOTACQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2147024884
DIERR_READONLY: Int32 = -2147024891
DIERR_HANDLEEXISTS: Int32 = -2147024891
DIERR_INSUFFICIENTPRIVS: Int32 = -2147220992
DIERR_DEVICEFULL: Int32 = -2147220991
DIERR_MOREDATA: Int32 = -2147220990
DIERR_NOTDOWNLOADED: Int32 = -2147220989
DIERR_HASEFFECTS: Int32 = -2147220988
DIERR_NOTEXCLUSIVEACQUIRED: Int32 = -2147220987
DIERR_INCOMPLETEEFFECT: Int32 = -2147220986
DIERR_NOTBUFFERED: Int32 = -2147220985
DIERR_EFFECTPLAYING: Int32 = -2147220984
DIERR_UNPLUGGED: Int32 = -2147220983
DIERR_REPORTFULL: Int32 = -2147220982
DIERR_MAPFILEFAIL: Int32 = -2147220981
DIKEYBOARD_ESCAPE: UInt32 = 2164261889
DIKEYBOARD_1: UInt32 = 2164261890
DIKEYBOARD_2: UInt32 = 2164261891
DIKEYBOARD_3: UInt32 = 2164261892
DIKEYBOARD_4: UInt32 = 2164261893
DIKEYBOARD_5: UInt32 = 2164261894
DIKEYBOARD_6: UInt32 = 2164261895
DIKEYBOARD_7: UInt32 = 2164261896
DIKEYBOARD_8: UInt32 = 2164261897
DIKEYBOARD_9: UInt32 = 2164261898
DIKEYBOARD_0: UInt32 = 2164261899
DIKEYBOARD_MINUS: UInt32 = 2164261900
DIKEYBOARD_EQUALS: UInt32 = 2164261901
DIKEYBOARD_BACK: UInt32 = 2164261902
DIKEYBOARD_TAB: UInt32 = 2164261903
DIKEYBOARD_Q: UInt32 = 2164261904
DIKEYBOARD_W: UInt32 = 2164261905
DIKEYBOARD_E: UInt32 = 2164261906
DIKEYBOARD_R: UInt32 = 2164261907
DIKEYBOARD_T: UInt32 = 2164261908
DIKEYBOARD_Y: UInt32 = 2164261909
DIKEYBOARD_U: UInt32 = 2164261910
DIKEYBOARD_I: UInt32 = 2164261911
DIKEYBOARD_O: UInt32 = 2164261912
DIKEYBOARD_P: UInt32 = 2164261913
DIKEYBOARD_LBRACKET: UInt32 = 2164261914
DIKEYBOARD_RBRACKET: UInt32 = 2164261915
DIKEYBOARD_RETURN: UInt32 = 2164261916
DIKEYBOARD_LCONTROL: UInt32 = 2164261917
DIKEYBOARD_A: UInt32 = 2164261918
DIKEYBOARD_S: UInt32 = 2164261919
DIKEYBOARD_D: UInt32 = 2164261920
DIKEYBOARD_F: UInt32 = 2164261921
DIKEYBOARD_G: UInt32 = 2164261922
DIKEYBOARD_H: UInt32 = 2164261923
DIKEYBOARD_J: UInt32 = 2164261924
DIKEYBOARD_K: UInt32 = 2164261925
DIKEYBOARD_L: UInt32 = 2164261926
DIKEYBOARD_SEMICOLON: UInt32 = 2164261927
DIKEYBOARD_APOSTROPHE: UInt32 = 2164261928
DIKEYBOARD_GRAVE: UInt32 = 2164261929
DIKEYBOARD_LSHIFT: UInt32 = 2164261930
DIKEYBOARD_BACKSLASH: UInt32 = 2164261931
DIKEYBOARD_Z: UInt32 = 2164261932
DIKEYBOARD_X: UInt32 = 2164261933
DIKEYBOARD_C: UInt32 = 2164261934
DIKEYBOARD_V: UInt32 = 2164261935
DIKEYBOARD_B: UInt32 = 2164261936
DIKEYBOARD_N: UInt32 = 2164261937
DIKEYBOARD_M: UInt32 = 2164261938
DIKEYBOARD_COMMA: UInt32 = 2164261939
DIKEYBOARD_PERIOD: UInt32 = 2164261940
DIKEYBOARD_SLASH: UInt32 = 2164261941
DIKEYBOARD_RSHIFT: UInt32 = 2164261942
DIKEYBOARD_MULTIPLY: UInt32 = 2164261943
DIKEYBOARD_LMENU: UInt32 = 2164261944
DIKEYBOARD_SPACE: UInt32 = 2164261945
DIKEYBOARD_CAPITAL: UInt32 = 2164261946
DIKEYBOARD_F1: UInt32 = 2164261947
DIKEYBOARD_F2: UInt32 = 2164261948
DIKEYBOARD_F3: UInt32 = 2164261949
DIKEYBOARD_F4: UInt32 = 2164261950
DIKEYBOARD_F5: UInt32 = 2164261951
DIKEYBOARD_F6: UInt32 = 2164261952
DIKEYBOARD_F7: UInt32 = 2164261953
DIKEYBOARD_F8: UInt32 = 2164261954
DIKEYBOARD_F9: UInt32 = 2164261955
DIKEYBOARD_F10: UInt32 = 2164261956
DIKEYBOARD_NUMLOCK: UInt32 = 2164261957
DIKEYBOARD_SCROLL: UInt32 = 2164261958
DIKEYBOARD_NUMPAD7: UInt32 = 2164261959
DIKEYBOARD_NUMPAD8: UInt32 = 2164261960
DIKEYBOARD_NUMPAD9: UInt32 = 2164261961
DIKEYBOARD_SUBTRACT: UInt32 = 2164261962
DIKEYBOARD_NUMPAD4: UInt32 = 2164261963
DIKEYBOARD_NUMPAD5: UInt32 = 2164261964
DIKEYBOARD_NUMPAD6: UInt32 = 2164261965
DIKEYBOARD_ADD: UInt32 = 2164261966
DIKEYBOARD_NUMPAD1: UInt32 = 2164261967
DIKEYBOARD_NUMPAD2: UInt32 = 2164261968
DIKEYBOARD_NUMPAD3: UInt32 = 2164261969
DIKEYBOARD_NUMPAD0: UInt32 = 2164261970
DIKEYBOARD_DECIMAL: UInt32 = 2164261971
DIKEYBOARD_OEM_102: UInt32 = 2164261974
DIKEYBOARD_F11: UInt32 = 2164261975
DIKEYBOARD_F12: UInt32 = 2164261976
DIKEYBOARD_F13: UInt32 = 2164261988
DIKEYBOARD_F14: UInt32 = 2164261989
DIKEYBOARD_F15: UInt32 = 2164261990
DIKEYBOARD_KANA: UInt32 = 2164262000
DIKEYBOARD_ABNT_C1: UInt32 = 2164262003
DIKEYBOARD_CONVERT: UInt32 = 2164262009
DIKEYBOARD_NOCONVERT: UInt32 = 2164262011
DIKEYBOARD_YEN: UInt32 = 2164262013
DIKEYBOARD_ABNT_C2: UInt32 = 2164262014
DIKEYBOARD_NUMPADEQUALS: UInt32 = 2164262029
DIKEYBOARD_PREVTRACK: UInt32 = 2164262032
DIKEYBOARD_AT: UInt32 = 2164262033
DIKEYBOARD_COLON: UInt32 = 2164262034
DIKEYBOARD_UNDERLINE: UInt32 = 2164262035
DIKEYBOARD_KANJI: UInt32 = 2164262036
DIKEYBOARD_STOP: UInt32 = 2164262037
DIKEYBOARD_AX: UInt32 = 2164262038
DIKEYBOARD_UNLABELED: UInt32 = 2164262039
DIKEYBOARD_NEXTTRACK: UInt32 = 2164262041
DIKEYBOARD_NUMPADENTER: UInt32 = 2164262044
DIKEYBOARD_RCONTROL: UInt32 = 2164262045
DIKEYBOARD_MUTE: UInt32 = 2164262048
DIKEYBOARD_CALCULATOR: UInt32 = 2164262049
DIKEYBOARD_PLAYPAUSE: UInt32 = 2164262050
DIKEYBOARD_MEDIASTOP: UInt32 = 2164262052
DIKEYBOARD_VOLUMEDOWN: UInt32 = 2164262062
DIKEYBOARD_VOLUMEUP: UInt32 = 2164262064
DIKEYBOARD_WEBHOME: UInt32 = 2164262066
DIKEYBOARD_NUMPADCOMMA: UInt32 = 2164262067
DIKEYBOARD_DIVIDE: UInt32 = 2164262069
DIKEYBOARD_SYSRQ: UInt32 = 2164262071
DIKEYBOARD_RMENU: UInt32 = 2164262072
DIKEYBOARD_PAUSE: UInt32 = 2164262085
DIKEYBOARD_HOME: UInt32 = 2164262087
DIKEYBOARD_UP: UInt32 = 2164262088
DIKEYBOARD_PRIOR: UInt32 = 2164262089
DIKEYBOARD_LEFT: UInt32 = 2164262091
DIKEYBOARD_RIGHT: UInt32 = 2164262093
DIKEYBOARD_END: UInt32 = 2164262095
DIKEYBOARD_DOWN: UInt32 = 2164262096
DIKEYBOARD_NEXT: UInt32 = 2164262097
DIKEYBOARD_INSERT: UInt32 = 2164262098
DIKEYBOARD_DELETE: UInt32 = 2164262099
DIKEYBOARD_LWIN: UInt32 = 2164262107
DIKEYBOARD_RWIN: UInt32 = 2164262108
DIKEYBOARD_APPS: UInt32 = 2164262109
DIKEYBOARD_POWER: UInt32 = 2164262110
DIKEYBOARD_SLEEP: UInt32 = 2164262111
DIKEYBOARD_WAKE: UInt32 = 2164262115
DIKEYBOARD_WEBSEARCH: UInt32 = 2164262117
DIKEYBOARD_WEBFAVORITES: UInt32 = 2164262118
DIKEYBOARD_WEBREFRESH: UInt32 = 2164262119
DIKEYBOARD_WEBSTOP: UInt32 = 2164262120
DIKEYBOARD_WEBFORWARD: UInt32 = 2164262121
DIKEYBOARD_WEBBACK: UInt32 = 2164262122
DIKEYBOARD_MYCOMPUTER: UInt32 = 2164262123
DIKEYBOARD_MAIL: UInt32 = 2164262124
DIKEYBOARD_MEDIASELECT: UInt32 = 2164262125
DIVOICE_CHANNEL1: UInt32 = 2197816321
DIVOICE_CHANNEL2: UInt32 = 2197816322
DIVOICE_CHANNEL3: UInt32 = 2197816323
DIVOICE_CHANNEL4: UInt32 = 2197816324
DIVOICE_CHANNEL5: UInt32 = 2197816325
DIVOICE_CHANNEL6: UInt32 = 2197816326
DIVOICE_CHANNEL7: UInt32 = 2197816327
DIVOICE_CHANNEL8: UInt32 = 2197816328
DIVOICE_TEAM: UInt32 = 2197816329
DIVOICE_ALL: UInt32 = 2197816330
DIVOICE_RECORDMUTE: UInt32 = 2197816331
DIVOICE_PLAYBACKMUTE: UInt32 = 2197816332
DIVOICE_TRANSMIT: UInt32 = 2197816333
DIVOICE_VOICECOMMAND: UInt32 = 2197816336
DIVIRTUAL_DRIVING_RACE: UInt32 = 16777216
DIAXIS_DRIVINGR_STEER: UInt32 = 16812545
DIAXIS_DRIVINGR_ACCELERATE: UInt32 = 17011202
DIAXIS_DRIVINGR_BRAKE: UInt32 = 17043971
DIBUTTON_DRIVINGR_SHIFTUP: UInt32 = 16780289
DIBUTTON_DRIVINGR_SHIFTDOWN: UInt32 = 16780290
DIBUTTON_DRIVINGR_VIEW: UInt32 = 16784387
DIBUTTON_DRIVINGR_MENU: UInt32 = 16778493
DIAXIS_DRIVINGR_ACCEL_AND_BRAKE: UInt32 = 16861700
DIHATSWITCH_DRIVINGR_GLANCE: UInt32 = 16795137
DIBUTTON_DRIVINGR_BRAKE: UInt32 = 16796676
DIBUTTON_DRIVINGR_DASHBOARD: UInt32 = 16794629
DIBUTTON_DRIVINGR_AIDS: UInt32 = 16794630
DIBUTTON_DRIVINGR_MAP: UInt32 = 16794631
DIBUTTON_DRIVINGR_BOOST: UInt32 = 16794632
DIBUTTON_DRIVINGR_PIT: UInt32 = 16794633
DIBUTTON_DRIVINGR_ACCELERATE_LINK: UInt32 = 17028320
DIBUTTON_DRIVINGR_STEER_LEFT_LINK: UInt32 = 16829668
DIBUTTON_DRIVINGR_STEER_RIGHT_LINK: UInt32 = 16829676
DIBUTTON_DRIVINGR_GLANCE_LEFT_LINK: UInt32 = 17286372
DIBUTTON_DRIVINGR_GLANCE_RIGHT_LINK: UInt32 = 17286380
DIBUTTON_DRIVINGR_DEVICE: UInt32 = 16794878
DIBUTTON_DRIVINGR_PAUSE: UInt32 = 16794876
DIVIRTUAL_DRIVING_COMBAT: UInt32 = 33554432
DIAXIS_DRIVINGC_STEER: UInt32 = 33589761
DIAXIS_DRIVINGC_ACCELERATE: UInt32 = 33788418
DIAXIS_DRIVINGC_BRAKE: UInt32 = 33821187
DIBUTTON_DRIVINGC_FIRE: UInt32 = 33557505
DIBUTTON_DRIVINGC_WEAPONS: UInt32 = 33557506
DIBUTTON_DRIVINGC_TARGET: UInt32 = 33557507
DIBUTTON_DRIVINGC_MENU: UInt32 = 33555709
DIAXIS_DRIVINGC_ACCEL_AND_BRAKE: UInt32 = 33638916
DIHATSWITCH_DRIVINGC_GLANCE: UInt32 = 33572353
DIBUTTON_DRIVINGC_SHIFTUP: UInt32 = 33573892
DIBUTTON_DRIVINGC_SHIFTDOWN: UInt32 = 33573893
DIBUTTON_DRIVINGC_DASHBOARD: UInt32 = 33571846
DIBUTTON_DRIVINGC_AIDS: UInt32 = 33571847
DIBUTTON_DRIVINGC_BRAKE: UInt32 = 33573896
DIBUTTON_DRIVINGC_FIRESECONDARY: UInt32 = 33573897
DIBUTTON_DRIVINGC_ACCELERATE_LINK: UInt32 = 33805536
DIBUTTON_DRIVINGC_STEER_LEFT_LINK: UInt32 = 33606884
DIBUTTON_DRIVINGC_STEER_RIGHT_LINK: UInt32 = 33606892
DIBUTTON_DRIVINGC_GLANCE_LEFT_LINK: UInt32 = 34063588
DIBUTTON_DRIVINGC_GLANCE_RIGHT_LINK: UInt32 = 34063596
DIBUTTON_DRIVINGC_DEVICE: UInt32 = 33572094
DIBUTTON_DRIVINGC_PAUSE: UInt32 = 33572092
DIVIRTUAL_DRIVING_TANK: UInt32 = 50331648
DIAXIS_DRIVINGT_STEER: UInt32 = 50366977
DIAXIS_DRIVINGT_BARREL: UInt32 = 50397698
DIAXIS_DRIVINGT_ACCELERATE: UInt32 = 50565635
DIAXIS_DRIVINGT_ROTATE: UInt32 = 50463236
DIBUTTON_DRIVINGT_FIRE: UInt32 = 50334721
DIBUTTON_DRIVINGT_WEAPONS: UInt32 = 50334722
DIBUTTON_DRIVINGT_TARGET: UInt32 = 50334723
DIBUTTON_DRIVINGT_MENU: UInt32 = 50332925
DIHATSWITCH_DRIVINGT_GLANCE: UInt32 = 50349569
DIAXIS_DRIVINGT_BRAKE: UInt32 = 50614789
DIAXIS_DRIVINGT_ACCEL_AND_BRAKE: UInt32 = 50416134
DIBUTTON_DRIVINGT_VIEW: UInt32 = 50355204
DIBUTTON_DRIVINGT_DASHBOARD: UInt32 = 50355205
DIBUTTON_DRIVINGT_BRAKE: UInt32 = 50351110
DIBUTTON_DRIVINGT_FIRESECONDARY: UInt32 = 50351111
DIBUTTON_DRIVINGT_ACCELERATE_LINK: UInt32 = 50582752
DIBUTTON_DRIVINGT_STEER_LEFT_LINK: UInt32 = 50384100
DIBUTTON_DRIVINGT_STEER_RIGHT_LINK: UInt32 = 50384108
DIBUTTON_DRIVINGT_BARREL_UP_LINK: UInt32 = 50414816
DIBUTTON_DRIVINGT_BARREL_DOWN_LINK: UInt32 = 50414824
DIBUTTON_DRIVINGT_ROTATE_LEFT_LINK: UInt32 = 50480356
DIBUTTON_DRIVINGT_ROTATE_RIGHT_LINK: UInt32 = 50480364
DIBUTTON_DRIVINGT_GLANCE_LEFT_LINK: UInt32 = 50840804
DIBUTTON_DRIVINGT_GLANCE_RIGHT_LINK: UInt32 = 50840812
DIBUTTON_DRIVINGT_DEVICE: UInt32 = 50349310
DIBUTTON_DRIVINGT_PAUSE: UInt32 = 50349308
DIVIRTUAL_FLYING_CIVILIAN: UInt32 = 67108864
DIAXIS_FLYINGC_BANK: UInt32 = 67144193
DIAXIS_FLYINGC_PITCH: UInt32 = 67176962
DIAXIS_FLYINGC_THROTTLE: UInt32 = 67342851
DIBUTTON_FLYINGC_VIEW: UInt32 = 67118081
DIBUTTON_FLYINGC_DISPLAY: UInt32 = 67118082
DIBUTTON_FLYINGC_GEAR: UInt32 = 67120131
DIBUTTON_FLYINGC_MENU: UInt32 = 67110141
DIHATSWITCH_FLYINGC_GLANCE: UInt32 = 67126785
DIAXIS_FLYINGC_BRAKE: UInt32 = 67398148
DIAXIS_FLYINGC_RUDDER: UInt32 = 67260933
DIAXIS_FLYINGC_FLAPS: UInt32 = 67459590
DIBUTTON_FLYINGC_FLAPSUP: UInt32 = 67134468
DIBUTTON_FLYINGC_FLAPSDOWN: UInt32 = 67134469
DIBUTTON_FLYINGC_BRAKE_LINK: UInt32 = 67398880
DIBUTTON_FLYINGC_FASTER_LINK: UInt32 = 67359968
DIBUTTON_FLYINGC_SLOWER_LINK: UInt32 = 67359976
DIBUTTON_FLYINGC_GLANCE_LEFT_LINK: UInt32 = 67618020
DIBUTTON_FLYINGC_GLANCE_RIGHT_LINK: UInt32 = 67618028
DIBUTTON_FLYINGC_GLANCE_UP_LINK: UInt32 = 67618016
DIBUTTON_FLYINGC_GLANCE_DOWN_LINK: UInt32 = 67618024
DIBUTTON_FLYINGC_DEVICE: UInt32 = 67126526
DIBUTTON_FLYINGC_PAUSE: UInt32 = 67126524
DIVIRTUAL_FLYING_MILITARY: UInt32 = 83886080
DIAXIS_FLYINGM_BANK: UInt32 = 83921409
DIAXIS_FLYINGM_PITCH: UInt32 = 83954178
DIAXIS_FLYINGM_THROTTLE: UInt32 = 84120067
DIBUTTON_FLYINGM_FIRE: UInt32 = 83889153
DIBUTTON_FLYINGM_WEAPONS: UInt32 = 83889154
DIBUTTON_FLYINGM_TARGET: UInt32 = 83889155
DIBUTTON_FLYINGM_MENU: UInt32 = 83887357
DIHATSWITCH_FLYINGM_GLANCE: UInt32 = 83904001
DIBUTTON_FLYINGM_COUNTER: UInt32 = 83909636
DIAXIS_FLYINGM_RUDDER: UInt32 = 84036100
DIAXIS_FLYINGM_BRAKE: UInt32 = 84173317
DIBUTTON_FLYINGM_VIEW: UInt32 = 83911685
DIBUTTON_FLYINGM_DISPLAY: UInt32 = 83911686
DIAXIS_FLYINGM_FLAPS: UInt32 = 84234758
DIBUTTON_FLYINGM_FLAPSUP: UInt32 = 83907591
DIBUTTON_FLYINGM_FLAPSDOWN: UInt32 = 83907592
DIBUTTON_FLYINGM_FIRESECONDARY: UInt32 = 83905545
DIBUTTON_FLYINGM_GEAR: UInt32 = 83911690
DIBUTTON_FLYINGM_BRAKE_LINK: UInt32 = 84174048
DIBUTTON_FLYINGM_FASTER_LINK: UInt32 = 84137184
DIBUTTON_FLYINGM_SLOWER_LINK: UInt32 = 84137192
DIBUTTON_FLYINGM_GLANCE_LEFT_LINK: UInt32 = 84395236
DIBUTTON_FLYINGM_GLANCE_RIGHT_LINK: UInt32 = 84395244
DIBUTTON_FLYINGM_GLANCE_UP_LINK: UInt32 = 84395232
DIBUTTON_FLYINGM_GLANCE_DOWN_LINK: UInt32 = 84395240
DIBUTTON_FLYINGM_DEVICE: UInt32 = 83903742
DIBUTTON_FLYINGM_PAUSE: UInt32 = 83903740
DIVIRTUAL_FLYING_HELICOPTER: UInt32 = 100663296
DIAXIS_FLYINGH_BANK: UInt32 = 100698625
DIAXIS_FLYINGH_PITCH: UInt32 = 100731394
DIAXIS_FLYINGH_COLLECTIVE: UInt32 = 100764163
DIBUTTON_FLYINGH_FIRE: UInt32 = 100668417
DIBUTTON_FLYINGH_WEAPONS: UInt32 = 100668418
DIBUTTON_FLYINGH_TARGET: UInt32 = 100668419
DIBUTTON_FLYINGH_MENU: UInt32 = 100664573
DIHATSWITCH_FLYINGH_GLANCE: UInt32 = 100681217
DIAXIS_FLYINGH_TORQUE: UInt32 = 100817412
DIAXIS_FLYINGH_THROTTLE: UInt32 = 100915717
DIBUTTON_FLYINGH_COUNTER: UInt32 = 100684804
DIBUTTON_FLYINGH_VIEW: UInt32 = 100688901
DIBUTTON_FLYINGH_GEAR: UInt32 = 100688902
DIBUTTON_FLYINGH_FIRESECONDARY: UInt32 = 100682759
DIBUTTON_FLYINGH_FASTER_LINK: UInt32 = 100916448
DIBUTTON_FLYINGH_SLOWER_LINK: UInt32 = 100916456
DIBUTTON_FLYINGH_GLANCE_LEFT_LINK: UInt32 = 101172452
DIBUTTON_FLYINGH_GLANCE_RIGHT_LINK: UInt32 = 101172460
DIBUTTON_FLYINGH_GLANCE_UP_LINK: UInt32 = 101172448
DIBUTTON_FLYINGH_GLANCE_DOWN_LINK: UInt32 = 101172456
DIBUTTON_FLYINGH_DEVICE: UInt32 = 100680958
DIBUTTON_FLYINGH_PAUSE: UInt32 = 100680956
DIVIRTUAL_SPACESIM: UInt32 = 117440512
DIAXIS_SPACESIM_LATERAL: UInt32 = 117473793
DIAXIS_SPACESIM_MOVE: UInt32 = 117506562
DIAXIS_SPACESIM_THROTTLE: UInt32 = 117670403
DIBUTTON_SPACESIM_FIRE: UInt32 = 117441537
DIBUTTON_SPACESIM_WEAPONS: UInt32 = 117441538
DIBUTTON_SPACESIM_TARGET: UInt32 = 117441539
DIBUTTON_SPACESIM_MENU: UInt32 = 117441789
DIHATSWITCH_SPACESIM_GLANCE: UInt32 = 117458433
DIAXIS_SPACESIM_CLIMB: UInt32 = 117555716
DIAXIS_SPACESIM_ROTATE: UInt32 = 117588485
DIBUTTON_SPACESIM_VIEW: UInt32 = 117457924
DIBUTTON_SPACESIM_DISPLAY: UInt32 = 117457925
DIBUTTON_SPACESIM_RAISE: UInt32 = 117457926
DIBUTTON_SPACESIM_LOWER: UInt32 = 117457927
DIBUTTON_SPACESIM_GEAR: UInt32 = 117457928
DIBUTTON_SPACESIM_FIRESECONDARY: UInt32 = 117457929
DIBUTTON_SPACESIM_LEFT_LINK: UInt32 = 117490916
DIBUTTON_SPACESIM_RIGHT_LINK: UInt32 = 117490924
DIBUTTON_SPACESIM_FORWARD_LINK: UInt32 = 117523680
DIBUTTON_SPACESIM_BACKWARD_LINK: UInt32 = 117523688
DIBUTTON_SPACESIM_FASTER_LINK: UInt32 = 117687520
DIBUTTON_SPACESIM_SLOWER_LINK: UInt32 = 117687528
DIBUTTON_SPACESIM_TURN_LEFT_LINK: UInt32 = 117589220
DIBUTTON_SPACESIM_TURN_RIGHT_LINK: UInt32 = 117589228
DIBUTTON_SPACESIM_GLANCE_LEFT_LINK: UInt32 = 117949668
DIBUTTON_SPACESIM_GLANCE_RIGHT_LINK: UInt32 = 117949676
DIBUTTON_SPACESIM_GLANCE_UP_LINK: UInt32 = 117949664
DIBUTTON_SPACESIM_GLANCE_DOWN_LINK: UInt32 = 117949672
DIBUTTON_SPACESIM_DEVICE: UInt32 = 117458174
DIBUTTON_SPACESIM_PAUSE: UInt32 = 117458172
DIVIRTUAL_FIGHTING_HAND2HAND: UInt32 = 134217728
DIAXIS_FIGHTINGH_LATERAL: UInt32 = 134251009
DIAXIS_FIGHTINGH_MOVE: UInt32 = 134283778
DIBUTTON_FIGHTINGH_PUNCH: UInt32 = 134218753
DIBUTTON_FIGHTINGH_KICK: UInt32 = 134218754
DIBUTTON_FIGHTINGH_BLOCK: UInt32 = 134218755
DIBUTTON_FIGHTINGH_CROUCH: UInt32 = 134218756
DIBUTTON_FIGHTINGH_JUMP: UInt32 = 134218757
DIBUTTON_FIGHTINGH_SPECIAL1: UInt32 = 134218758
DIBUTTON_FIGHTINGH_SPECIAL2: UInt32 = 134218759
DIBUTTON_FIGHTINGH_MENU: UInt32 = 134219005
DIBUTTON_FIGHTINGH_SELECT: UInt32 = 134235144
DIHATSWITCH_FIGHTINGH_SLIDE: UInt32 = 134235649
DIBUTTON_FIGHTINGH_DISPLAY: UInt32 = 134235145
DIAXIS_FIGHTINGH_ROTATE: UInt32 = 134365699
DIBUTTON_FIGHTINGH_DODGE: UInt32 = 134235146
DIBUTTON_FIGHTINGH_LEFT_LINK: UInt32 = 134268132
DIBUTTON_FIGHTINGH_RIGHT_LINK: UInt32 = 134268140
DIBUTTON_FIGHTINGH_FORWARD_LINK: UInt32 = 134300896
DIBUTTON_FIGHTINGH_BACKWARD_LINK: UInt32 = 134300904
DIBUTTON_FIGHTINGH_DEVICE: UInt32 = 134235390
DIBUTTON_FIGHTINGH_PAUSE: UInt32 = 134235388
DIVIRTUAL_FIGHTING_FPS: UInt32 = 150994944
DIAXIS_FPS_ROTATE: UInt32 = 151028225
DIAXIS_FPS_MOVE: UInt32 = 151060994
DIBUTTON_FPS_FIRE: UInt32 = 150995969
DIBUTTON_FPS_WEAPONS: UInt32 = 150995970
DIBUTTON_FPS_APPLY: UInt32 = 150995971
DIBUTTON_FPS_SELECT: UInt32 = 150995972
DIBUTTON_FPS_CROUCH: UInt32 = 150995973
DIBUTTON_FPS_JUMP: UInt32 = 150995974
DIAXIS_FPS_LOOKUPDOWN: UInt32 = 151093763
DIBUTTON_FPS_STRAFE: UInt32 = 150995975
DIBUTTON_FPS_MENU: UInt32 = 150996221
DIHATSWITCH_FPS_GLANCE: UInt32 = 151012865
DIBUTTON_FPS_DISPLAY: UInt32 = 151012360
DIAXIS_FPS_SIDESTEP: UInt32 = 151142916
DIBUTTON_FPS_DODGE: UInt32 = 151012361
DIBUTTON_FPS_GLANCEL: UInt32 = 151012362
DIBUTTON_FPS_GLANCER: UInt32 = 151012363
DIBUTTON_FPS_FIRESECONDARY: UInt32 = 151012364
DIBUTTON_FPS_ROTATE_LEFT_LINK: UInt32 = 151045348
DIBUTTON_FPS_ROTATE_RIGHT_LINK: UInt32 = 151045356
DIBUTTON_FPS_FORWARD_LINK: UInt32 = 151078112
DIBUTTON_FPS_BACKWARD_LINK: UInt32 = 151078120
DIBUTTON_FPS_GLANCE_UP_LINK: UInt32 = 151110880
DIBUTTON_FPS_GLANCE_DOWN_LINK: UInt32 = 151110888
DIBUTTON_FPS_STEP_LEFT_LINK: UInt32 = 151143652
DIBUTTON_FPS_STEP_RIGHT_LINK: UInt32 = 151143660
DIBUTTON_FPS_DEVICE: UInt32 = 151012606
DIBUTTON_FPS_PAUSE: UInt32 = 151012604
DIVIRTUAL_FIGHTING_THIRDPERSON: UInt32 = 167772160
DIAXIS_TPS_TURN: UInt32 = 167903745
DIAXIS_TPS_MOVE: UInt32 = 167838210
DIBUTTON_TPS_RUN: UInt32 = 167773185
DIBUTTON_TPS_ACTION: UInt32 = 167773186
DIBUTTON_TPS_SELECT: UInt32 = 167773187
DIBUTTON_TPS_USE: UInt32 = 167773188
DIBUTTON_TPS_JUMP: UInt32 = 167773189
DIBUTTON_TPS_MENU: UInt32 = 167773437
DIHATSWITCH_TPS_GLANCE: UInt32 = 167790081
DIBUTTON_TPS_VIEW: UInt32 = 167789574
DIBUTTON_TPS_STEPLEFT: UInt32 = 167789575
DIBUTTON_TPS_STEPRIGHT: UInt32 = 167789576
DIAXIS_TPS_STEP: UInt32 = 167821827
DIBUTTON_TPS_DODGE: UInt32 = 167789577
DIBUTTON_TPS_INVENTORY: UInt32 = 167789578
DIBUTTON_TPS_TURN_LEFT_LINK: UInt32 = 167920868
DIBUTTON_TPS_TURN_RIGHT_LINK: UInt32 = 167920876
DIBUTTON_TPS_FORWARD_LINK: UInt32 = 167855328
DIBUTTON_TPS_BACKWARD_LINK: UInt32 = 167855336
DIBUTTON_TPS_GLANCE_UP_LINK: UInt32 = 168281312
DIBUTTON_TPS_GLANCE_DOWN_LINK: UInt32 = 168281320
DIBUTTON_TPS_GLANCE_LEFT_LINK: UInt32 = 168281316
DIBUTTON_TPS_GLANCE_RIGHT_LINK: UInt32 = 168281324
DIBUTTON_TPS_DEVICE: UInt32 = 167789822
DIBUTTON_TPS_PAUSE: UInt32 = 167789820
DIVIRTUAL_STRATEGY_ROLEPLAYING: UInt32 = 184549376
DIAXIS_STRATEGYR_LATERAL: UInt32 = 184582657
DIAXIS_STRATEGYR_MOVE: UInt32 = 184615426
DIBUTTON_STRATEGYR_GET: UInt32 = 184550401
DIBUTTON_STRATEGYR_APPLY: UInt32 = 184550402
DIBUTTON_STRATEGYR_SELECT: UInt32 = 184550403
DIBUTTON_STRATEGYR_ATTACK: UInt32 = 184550404
DIBUTTON_STRATEGYR_CAST: UInt32 = 184550405
DIBUTTON_STRATEGYR_CROUCH: UInt32 = 184550406
DIBUTTON_STRATEGYR_JUMP: UInt32 = 184550407
DIBUTTON_STRATEGYR_MENU: UInt32 = 184550653
DIHATSWITCH_STRATEGYR_GLANCE: UInt32 = 184567297
DIBUTTON_STRATEGYR_MAP: UInt32 = 184566792
DIBUTTON_STRATEGYR_DISPLAY: UInt32 = 184566793
DIAXIS_STRATEGYR_ROTATE: UInt32 = 184697347
DIBUTTON_STRATEGYR_LEFT_LINK: UInt32 = 184599780
DIBUTTON_STRATEGYR_RIGHT_LINK: UInt32 = 184599788
DIBUTTON_STRATEGYR_FORWARD_LINK: UInt32 = 184632544
DIBUTTON_STRATEGYR_BACK_LINK: UInt32 = 184632552
DIBUTTON_STRATEGYR_ROTATE_LEFT_LINK: UInt32 = 184698084
DIBUTTON_STRATEGYR_ROTATE_RIGHT_LINK: UInt32 = 184698092
DIBUTTON_STRATEGYR_DEVICE: UInt32 = 184567038
DIBUTTON_STRATEGYR_PAUSE: UInt32 = 184567036
DIVIRTUAL_STRATEGY_TURN: UInt32 = 201326592
DIAXIS_STRATEGYT_LATERAL: UInt32 = 201359873
DIAXIS_STRATEGYT_MOVE: UInt32 = 201392642
DIBUTTON_STRATEGYT_SELECT: UInt32 = 201327617
DIBUTTON_STRATEGYT_INSTRUCT: UInt32 = 201327618
DIBUTTON_STRATEGYT_APPLY: UInt32 = 201327619
DIBUTTON_STRATEGYT_TEAM: UInt32 = 201327620
DIBUTTON_STRATEGYT_TURN: UInt32 = 201327621
DIBUTTON_STRATEGYT_MENU: UInt32 = 201327869
DIBUTTON_STRATEGYT_ZOOM: UInt32 = 201344006
DIBUTTON_STRATEGYT_MAP: UInt32 = 201344007
DIBUTTON_STRATEGYT_DISPLAY: UInt32 = 201344008
DIBUTTON_STRATEGYT_LEFT_LINK: UInt32 = 201376996
DIBUTTON_STRATEGYT_RIGHT_LINK: UInt32 = 201377004
DIBUTTON_STRATEGYT_FORWARD_LINK: UInt32 = 201409760
DIBUTTON_STRATEGYT_BACK_LINK: UInt32 = 201409768
DIBUTTON_STRATEGYT_DEVICE: UInt32 = 201344254
DIBUTTON_STRATEGYT_PAUSE: UInt32 = 201344252
DIVIRTUAL_SPORTS_HUNTING: UInt32 = 218103808
DIAXIS_HUNTING_LATERAL: UInt32 = 218137089
DIAXIS_HUNTING_MOVE: UInt32 = 218169858
DIBUTTON_HUNTING_FIRE: UInt32 = 218104833
DIBUTTON_HUNTING_AIM: UInt32 = 218104834
DIBUTTON_HUNTING_WEAPON: UInt32 = 218104835
DIBUTTON_HUNTING_BINOCULAR: UInt32 = 218104836
DIBUTTON_HUNTING_CALL: UInt32 = 218104837
DIBUTTON_HUNTING_MAP: UInt32 = 218104838
DIBUTTON_HUNTING_SPECIAL: UInt32 = 218104839
DIBUTTON_HUNTING_MENU: UInt32 = 218105085
DIHATSWITCH_HUNTING_GLANCE: UInt32 = 218121729
DIBUTTON_HUNTING_DISPLAY: UInt32 = 218121224
DIAXIS_HUNTING_ROTATE: UInt32 = 218251779
DIBUTTON_HUNTING_CROUCH: UInt32 = 218121225
DIBUTTON_HUNTING_JUMP: UInt32 = 218121226
DIBUTTON_HUNTING_FIRESECONDARY: UInt32 = 218121227
DIBUTTON_HUNTING_LEFT_LINK: UInt32 = 218154212
DIBUTTON_HUNTING_RIGHT_LINK: UInt32 = 218154220
DIBUTTON_HUNTING_FORWARD_LINK: UInt32 = 218186976
DIBUTTON_HUNTING_BACK_LINK: UInt32 = 218186984
DIBUTTON_HUNTING_ROTATE_LEFT_LINK: UInt32 = 218252516
DIBUTTON_HUNTING_ROTATE_RIGHT_LINK: UInt32 = 218252524
DIBUTTON_HUNTING_DEVICE: UInt32 = 218121470
DIBUTTON_HUNTING_PAUSE: UInt32 = 218121468
DIVIRTUAL_SPORTS_FISHING: UInt32 = 234881024
DIAXIS_FISHING_LATERAL: UInt32 = 234914305
DIAXIS_FISHING_MOVE: UInt32 = 234947074
DIBUTTON_FISHING_CAST: UInt32 = 234882049
DIBUTTON_FISHING_TYPE: UInt32 = 234882050
DIBUTTON_FISHING_BINOCULAR: UInt32 = 234882051
DIBUTTON_FISHING_BAIT: UInt32 = 234882052
DIBUTTON_FISHING_MAP: UInt32 = 234882053
DIBUTTON_FISHING_MENU: UInt32 = 234882301
DIHATSWITCH_FISHING_GLANCE: UInt32 = 234898945
DIBUTTON_FISHING_DISPLAY: UInt32 = 234898438
DIAXIS_FISHING_ROTATE: UInt32 = 235028995
DIBUTTON_FISHING_CROUCH: UInt32 = 234898439
DIBUTTON_FISHING_JUMP: UInt32 = 234898440
DIBUTTON_FISHING_LEFT_LINK: UInt32 = 234931428
DIBUTTON_FISHING_RIGHT_LINK: UInt32 = 234931436
DIBUTTON_FISHING_FORWARD_LINK: UInt32 = 234964192
DIBUTTON_FISHING_BACK_LINK: UInt32 = 234964200
DIBUTTON_FISHING_ROTATE_LEFT_LINK: UInt32 = 235029732
DIBUTTON_FISHING_ROTATE_RIGHT_LINK: UInt32 = 235029740
DIBUTTON_FISHING_DEVICE: UInt32 = 234898686
DIBUTTON_FISHING_PAUSE: UInt32 = 234898684
DIVIRTUAL_SPORTS_BASEBALL_BAT: UInt32 = 251658240
DIAXIS_BASEBALLB_LATERAL: UInt32 = 251691521
DIAXIS_BASEBALLB_MOVE: UInt32 = 251724290
DIBUTTON_BASEBALLB_SELECT: UInt32 = 251659265
DIBUTTON_BASEBALLB_NORMAL: UInt32 = 251659266
DIBUTTON_BASEBALLB_POWER: UInt32 = 251659267
DIBUTTON_BASEBALLB_BUNT: UInt32 = 251659268
DIBUTTON_BASEBALLB_STEAL: UInt32 = 251659269
DIBUTTON_BASEBALLB_BURST: UInt32 = 251659270
DIBUTTON_BASEBALLB_SLIDE: UInt32 = 251659271
DIBUTTON_BASEBALLB_CONTACT: UInt32 = 251659272
DIBUTTON_BASEBALLB_MENU: UInt32 = 251659517
DIBUTTON_BASEBALLB_NOSTEAL: UInt32 = 251675657
DIBUTTON_BASEBALLB_BOX: UInt32 = 251675658
DIBUTTON_BASEBALLB_LEFT_LINK: UInt32 = 251708644
DIBUTTON_BASEBALLB_RIGHT_LINK: UInt32 = 251708652
DIBUTTON_BASEBALLB_FORWARD_LINK: UInt32 = 251741408
DIBUTTON_BASEBALLB_BACK_LINK: UInt32 = 251741416
DIBUTTON_BASEBALLB_DEVICE: UInt32 = 251675902
DIBUTTON_BASEBALLB_PAUSE: UInt32 = 251675900
DIVIRTUAL_SPORTS_BASEBALL_PITCH: UInt32 = 268435456
DIAXIS_BASEBALLP_LATERAL: UInt32 = 268468737
DIAXIS_BASEBALLP_MOVE: UInt32 = 268501506
DIBUTTON_BASEBALLP_SELECT: UInt32 = 268436481
DIBUTTON_BASEBALLP_PITCH: UInt32 = 268436482
DIBUTTON_BASEBALLP_BASE: UInt32 = 268436483
DIBUTTON_BASEBALLP_THROW: UInt32 = 268436484
DIBUTTON_BASEBALLP_FAKE: UInt32 = 268436485
DIBUTTON_BASEBALLP_MENU: UInt32 = 268436733
DIBUTTON_BASEBALLP_WALK: UInt32 = 268452870
DIBUTTON_BASEBALLP_LOOK: UInt32 = 268452871
DIBUTTON_BASEBALLP_LEFT_LINK: UInt32 = 268485860
DIBUTTON_BASEBALLP_RIGHT_LINK: UInt32 = 268485868
DIBUTTON_BASEBALLP_FORWARD_LINK: UInt32 = 268518624
DIBUTTON_BASEBALLP_BACK_LINK: UInt32 = 268518632
DIBUTTON_BASEBALLP_DEVICE: UInt32 = 268453118
DIBUTTON_BASEBALLP_PAUSE: UInt32 = 268453116
DIVIRTUAL_SPORTS_BASEBALL_FIELD: UInt32 = 285212672
DIAXIS_BASEBALLF_LATERAL: UInt32 = 285245953
DIAXIS_BASEBALLF_MOVE: UInt32 = 285278722
DIBUTTON_BASEBALLF_NEAREST: UInt32 = 285213697
DIBUTTON_BASEBALLF_THROW1: UInt32 = 285213698
DIBUTTON_BASEBALLF_THROW2: UInt32 = 285213699
DIBUTTON_BASEBALLF_BURST: UInt32 = 285213700
DIBUTTON_BASEBALLF_JUMP: UInt32 = 285213701
DIBUTTON_BASEBALLF_DIVE: UInt32 = 285213702
DIBUTTON_BASEBALLF_MENU: UInt32 = 285213949
DIBUTTON_BASEBALLF_SHIFTIN: UInt32 = 285230087
DIBUTTON_BASEBALLF_SHIFTOUT: UInt32 = 285230088
DIBUTTON_BASEBALLF_AIM_LEFT_LINK: UInt32 = 285263076
DIBUTTON_BASEBALLF_AIM_RIGHT_LINK: UInt32 = 285263084
DIBUTTON_BASEBALLF_FORWARD_LINK: UInt32 = 285295840
DIBUTTON_BASEBALLF_BACK_LINK: UInt32 = 285295848
DIBUTTON_BASEBALLF_DEVICE: UInt32 = 285230334
DIBUTTON_BASEBALLF_PAUSE: UInt32 = 285230332
DIVIRTUAL_SPORTS_BASKETBALL_OFFENSE: UInt32 = 301989888
DIAXIS_BBALLO_LATERAL: UInt32 = 302023169
DIAXIS_BBALLO_MOVE: UInt32 = 302055938
DIBUTTON_BBALLO_SHOOT: UInt32 = 301990913
DIBUTTON_BBALLO_DUNK: UInt32 = 301990914
DIBUTTON_BBALLO_PASS: UInt32 = 301990915
DIBUTTON_BBALLO_FAKE: UInt32 = 301990916
DIBUTTON_BBALLO_SPECIAL: UInt32 = 301990917
DIBUTTON_BBALLO_PLAYER: UInt32 = 301990918
DIBUTTON_BBALLO_BURST: UInt32 = 301990919
DIBUTTON_BBALLO_CALL: UInt32 = 301990920
DIBUTTON_BBALLO_MENU: UInt32 = 301991165
DIHATSWITCH_BBALLO_GLANCE: UInt32 = 302007809
DIBUTTON_BBALLO_SCREEN: UInt32 = 302007305
DIBUTTON_BBALLO_PLAY: UInt32 = 302007306
DIBUTTON_BBALLO_JAB: UInt32 = 302007307
DIBUTTON_BBALLO_POST: UInt32 = 302007308
DIBUTTON_BBALLO_TIMEOUT: UInt32 = 302007309
DIBUTTON_BBALLO_SUBSTITUTE: UInt32 = 302007310
DIBUTTON_BBALLO_LEFT_LINK: UInt32 = 302040292
DIBUTTON_BBALLO_RIGHT_LINK: UInt32 = 302040300
DIBUTTON_BBALLO_FORWARD_LINK: UInt32 = 302073056
DIBUTTON_BBALLO_BACK_LINK: UInt32 = 302073064
DIBUTTON_BBALLO_DEVICE: UInt32 = 302007550
DIBUTTON_BBALLO_PAUSE: UInt32 = 302007548
DIVIRTUAL_SPORTS_BASKETBALL_DEFENSE: UInt32 = 318767104
DIAXIS_BBALLD_LATERAL: UInt32 = 318800385
DIAXIS_BBALLD_MOVE: UInt32 = 318833154
DIBUTTON_BBALLD_JUMP: UInt32 = 318768129
DIBUTTON_BBALLD_STEAL: UInt32 = 318768130
DIBUTTON_BBALLD_FAKE: UInt32 = 318768131
DIBUTTON_BBALLD_SPECIAL: UInt32 = 318768132
DIBUTTON_BBALLD_PLAYER: UInt32 = 318768133
DIBUTTON_BBALLD_BURST: UInt32 = 318768134
DIBUTTON_BBALLD_PLAY: UInt32 = 318768135
DIBUTTON_BBALLD_MENU: UInt32 = 318768381
DIHATSWITCH_BBALLD_GLANCE: UInt32 = 318785025
DIBUTTON_BBALLD_TIMEOUT: UInt32 = 318784520
DIBUTTON_BBALLD_SUBSTITUTE: UInt32 = 318784521
DIBUTTON_BBALLD_LEFT_LINK: UInt32 = 318817508
DIBUTTON_BBALLD_RIGHT_LINK: UInt32 = 318817516
DIBUTTON_BBALLD_FORWARD_LINK: UInt32 = 318850272
DIBUTTON_BBALLD_BACK_LINK: UInt32 = 318850280
DIBUTTON_BBALLD_DEVICE: UInt32 = 318784766
DIBUTTON_BBALLD_PAUSE: UInt32 = 318784764
DIVIRTUAL_SPORTS_FOOTBALL_FIELD: UInt32 = 335544320
DIBUTTON_FOOTBALLP_PLAY: UInt32 = 335545345
DIBUTTON_FOOTBALLP_SELECT: UInt32 = 335545346
DIBUTTON_FOOTBALLP_HELP: UInt32 = 335545347
DIBUTTON_FOOTBALLP_MENU: UInt32 = 335545597
DIBUTTON_FOOTBALLP_DEVICE: UInt32 = 335561982
DIBUTTON_FOOTBALLP_PAUSE: UInt32 = 335561980
DIVIRTUAL_SPORTS_FOOTBALL_QBCK: UInt32 = 352321536
DIAXIS_FOOTBALLQ_LATERAL: UInt32 = 352354817
DIAXIS_FOOTBALLQ_MOVE: UInt32 = 352387586
DIBUTTON_FOOTBALLQ_SELECT: UInt32 = 352322561
DIBUTTON_FOOTBALLQ_SNAP: UInt32 = 352322562
DIBUTTON_FOOTBALLQ_JUMP: UInt32 = 352322563
DIBUTTON_FOOTBALLQ_SLIDE: UInt32 = 352322564
DIBUTTON_FOOTBALLQ_PASS: UInt32 = 352322565
DIBUTTON_FOOTBALLQ_FAKE: UInt32 = 352322566
DIBUTTON_FOOTBALLQ_MENU: UInt32 = 352322813
DIBUTTON_FOOTBALLQ_FAKESNAP: UInt32 = 352338951
DIBUTTON_FOOTBALLQ_MOTION: UInt32 = 352338952
DIBUTTON_FOOTBALLQ_AUDIBLE: UInt32 = 352338953
DIBUTTON_FOOTBALLQ_LEFT_LINK: UInt32 = 352371940
DIBUTTON_FOOTBALLQ_RIGHT_LINK: UInt32 = 352371948
DIBUTTON_FOOTBALLQ_FORWARD_LINK: UInt32 = 352404704
DIBUTTON_FOOTBALLQ_BACK_LINK: UInt32 = 352404712
DIBUTTON_FOOTBALLQ_DEVICE: UInt32 = 352339198
DIBUTTON_FOOTBALLQ_PAUSE: UInt32 = 352339196
DIVIRTUAL_SPORTS_FOOTBALL_OFFENSE: UInt32 = 369098752
DIAXIS_FOOTBALLO_LATERAL: UInt32 = 369132033
DIAXIS_FOOTBALLO_MOVE: UInt32 = 369164802
DIBUTTON_FOOTBALLO_JUMP: UInt32 = 369099777
DIBUTTON_FOOTBALLO_LEFTARM: UInt32 = 369099778
DIBUTTON_FOOTBALLO_RIGHTARM: UInt32 = 369099779
DIBUTTON_FOOTBALLO_THROW: UInt32 = 369099780
DIBUTTON_FOOTBALLO_SPIN: UInt32 = 369099781
DIBUTTON_FOOTBALLO_MENU: UInt32 = 369100029
DIBUTTON_FOOTBALLO_JUKE: UInt32 = 369116166
DIBUTTON_FOOTBALLO_SHOULDER: UInt32 = 369116167
DIBUTTON_FOOTBALLO_TURBO: UInt32 = 369116168
DIBUTTON_FOOTBALLO_DIVE: UInt32 = 369116169
DIBUTTON_FOOTBALLO_ZOOM: UInt32 = 369116170
DIBUTTON_FOOTBALLO_SUBSTITUTE: UInt32 = 369116171
DIBUTTON_FOOTBALLO_LEFT_LINK: UInt32 = 369149156
DIBUTTON_FOOTBALLO_RIGHT_LINK: UInt32 = 369149164
DIBUTTON_FOOTBALLO_FORWARD_LINK: UInt32 = 369181920
DIBUTTON_FOOTBALLO_BACK_LINK: UInt32 = 369181928
DIBUTTON_FOOTBALLO_DEVICE: UInt32 = 369116414
DIBUTTON_FOOTBALLO_PAUSE: UInt32 = 369116412
DIVIRTUAL_SPORTS_FOOTBALL_DEFENSE: UInt32 = 385875968
DIAXIS_FOOTBALLD_LATERAL: UInt32 = 385909249
DIAXIS_FOOTBALLD_MOVE: UInt32 = 385942018
DIBUTTON_FOOTBALLD_PLAY: UInt32 = 385876993
DIBUTTON_FOOTBALLD_SELECT: UInt32 = 385876994
DIBUTTON_FOOTBALLD_JUMP: UInt32 = 385876995
DIBUTTON_FOOTBALLD_TACKLE: UInt32 = 385876996
DIBUTTON_FOOTBALLD_FAKE: UInt32 = 385876997
DIBUTTON_FOOTBALLD_SUPERTACKLE: UInt32 = 385876998
DIBUTTON_FOOTBALLD_MENU: UInt32 = 385877245
DIBUTTON_FOOTBALLD_SPIN: UInt32 = 385893383
DIBUTTON_FOOTBALLD_SWIM: UInt32 = 385893384
DIBUTTON_FOOTBALLD_BULLRUSH: UInt32 = 385893385
DIBUTTON_FOOTBALLD_RIP: UInt32 = 385893386
DIBUTTON_FOOTBALLD_AUDIBLE: UInt32 = 385893387
DIBUTTON_FOOTBALLD_ZOOM: UInt32 = 385893388
DIBUTTON_FOOTBALLD_SUBSTITUTE: UInt32 = 385893389
DIBUTTON_FOOTBALLD_LEFT_LINK: UInt32 = 385926372
DIBUTTON_FOOTBALLD_RIGHT_LINK: UInt32 = 385926380
DIBUTTON_FOOTBALLD_FORWARD_LINK: UInt32 = 385959136
DIBUTTON_FOOTBALLD_BACK_LINK: UInt32 = 385959144
DIBUTTON_FOOTBALLD_DEVICE: UInt32 = 385893630
DIBUTTON_FOOTBALLD_PAUSE: UInt32 = 385893628
DIVIRTUAL_SPORTS_GOLF: UInt32 = 402653184
DIAXIS_GOLF_LATERAL: UInt32 = 402686465
DIAXIS_GOLF_MOVE: UInt32 = 402719234
DIBUTTON_GOLF_SWING: UInt32 = 402654209
DIBUTTON_GOLF_SELECT: UInt32 = 402654210
DIBUTTON_GOLF_UP: UInt32 = 402654211
DIBUTTON_GOLF_DOWN: UInt32 = 402654212
DIBUTTON_GOLF_TERRAIN: UInt32 = 402654213
DIBUTTON_GOLF_FLYBY: UInt32 = 402654214
DIBUTTON_GOLF_MENU: UInt32 = 402654461
DIHATSWITCH_GOLF_SCROLL: UInt32 = 402671105
DIBUTTON_GOLF_ZOOM: UInt32 = 402670599
DIBUTTON_GOLF_TIMEOUT: UInt32 = 402670600
DIBUTTON_GOLF_SUBSTITUTE: UInt32 = 402670601
DIBUTTON_GOLF_LEFT_LINK: UInt32 = 402703588
DIBUTTON_GOLF_RIGHT_LINK: UInt32 = 402703596
DIBUTTON_GOLF_FORWARD_LINK: UInt32 = 402736352
DIBUTTON_GOLF_BACK_LINK: UInt32 = 402736360
DIBUTTON_GOLF_DEVICE: UInt32 = 402670846
DIBUTTON_GOLF_PAUSE: UInt32 = 402670844
DIVIRTUAL_SPORTS_HOCKEY_OFFENSE: UInt32 = 419430400
DIAXIS_HOCKEYO_LATERAL: UInt32 = 419463681
DIAXIS_HOCKEYO_MOVE: UInt32 = 419496450
DIBUTTON_HOCKEYO_SHOOT: UInt32 = 419431425
DIBUTTON_HOCKEYO_PASS: UInt32 = 419431426
DIBUTTON_HOCKEYO_BURST: UInt32 = 419431427
DIBUTTON_HOCKEYO_SPECIAL: UInt32 = 419431428
DIBUTTON_HOCKEYO_FAKE: UInt32 = 419431429
DIBUTTON_HOCKEYO_MENU: UInt32 = 419431677
DIHATSWITCH_HOCKEYO_SCROLL: UInt32 = 419448321
DIBUTTON_HOCKEYO_ZOOM: UInt32 = 419447814
DIBUTTON_HOCKEYO_STRATEGY: UInt32 = 419447815
DIBUTTON_HOCKEYO_TIMEOUT: UInt32 = 419447816
DIBUTTON_HOCKEYO_SUBSTITUTE: UInt32 = 419447817
DIBUTTON_HOCKEYO_LEFT_LINK: UInt32 = 419480804
DIBUTTON_HOCKEYO_RIGHT_LINK: UInt32 = 419480812
DIBUTTON_HOCKEYO_FORWARD_LINK: UInt32 = 419513568
DIBUTTON_HOCKEYO_BACK_LINK: UInt32 = 419513576
DIBUTTON_HOCKEYO_DEVICE: UInt32 = 419448062
DIBUTTON_HOCKEYO_PAUSE: UInt32 = 419448060
DIVIRTUAL_SPORTS_HOCKEY_DEFENSE: UInt32 = 436207616
DIAXIS_HOCKEYD_LATERAL: UInt32 = 436240897
DIAXIS_HOCKEYD_MOVE: UInt32 = 436273666
DIBUTTON_HOCKEYD_PLAYER: UInt32 = 436208641
DIBUTTON_HOCKEYD_STEAL: UInt32 = 436208642
DIBUTTON_HOCKEYD_BURST: UInt32 = 436208643
DIBUTTON_HOCKEYD_BLOCK: UInt32 = 436208644
DIBUTTON_HOCKEYD_FAKE: UInt32 = 436208645
DIBUTTON_HOCKEYD_MENU: UInt32 = 436208893
DIHATSWITCH_HOCKEYD_SCROLL: UInt32 = 436225537
DIBUTTON_HOCKEYD_ZOOM: UInt32 = 436225030
DIBUTTON_HOCKEYD_STRATEGY: UInt32 = 436225031
DIBUTTON_HOCKEYD_TIMEOUT: UInt32 = 436225032
DIBUTTON_HOCKEYD_SUBSTITUTE: UInt32 = 436225033
DIBUTTON_HOCKEYD_LEFT_LINK: UInt32 = 436258020
DIBUTTON_HOCKEYD_RIGHT_LINK: UInt32 = 436258028
DIBUTTON_HOCKEYD_FORWARD_LINK: UInt32 = 436290784
DIBUTTON_HOCKEYD_BACK_LINK: UInt32 = 436290792
DIBUTTON_HOCKEYD_DEVICE: UInt32 = 436225278
DIBUTTON_HOCKEYD_PAUSE: UInt32 = 436225276
DIVIRTUAL_SPORTS_HOCKEY_GOALIE: UInt32 = 452984832
DIAXIS_HOCKEYG_LATERAL: UInt32 = 453018113
DIAXIS_HOCKEYG_MOVE: UInt32 = 453050882
DIBUTTON_HOCKEYG_PASS: UInt32 = 452985857
DIBUTTON_HOCKEYG_POKE: UInt32 = 452985858
DIBUTTON_HOCKEYG_STEAL: UInt32 = 452985859
DIBUTTON_HOCKEYG_BLOCK: UInt32 = 452985860
DIBUTTON_HOCKEYG_MENU: UInt32 = 452986109
DIHATSWITCH_HOCKEYG_SCROLL: UInt32 = 453002753
DIBUTTON_HOCKEYG_ZOOM: UInt32 = 453002245
DIBUTTON_HOCKEYG_STRATEGY: UInt32 = 453002246
DIBUTTON_HOCKEYG_TIMEOUT: UInt32 = 453002247
DIBUTTON_HOCKEYG_SUBSTITUTE: UInt32 = 453002248
DIBUTTON_HOCKEYG_LEFT_LINK: UInt32 = 453035236
DIBUTTON_HOCKEYG_RIGHT_LINK: UInt32 = 453035244
DIBUTTON_HOCKEYG_FORWARD_LINK: UInt32 = 453068000
DIBUTTON_HOCKEYG_BACK_LINK: UInt32 = 453068008
DIBUTTON_HOCKEYG_DEVICE: UInt32 = 453002494
DIBUTTON_HOCKEYG_PAUSE: UInt32 = 453002492
DIVIRTUAL_SPORTS_BIKING_MOUNTAIN: UInt32 = 469762048
DIAXIS_BIKINGM_TURN: UInt32 = 469795329
DIAXIS_BIKINGM_PEDAL: UInt32 = 469828098
DIBUTTON_BIKINGM_JUMP: UInt32 = 469763073
DIBUTTON_BIKINGM_CAMERA: UInt32 = 469763074
DIBUTTON_BIKINGM_SPECIAL1: UInt32 = 469763075
DIBUTTON_BIKINGM_SELECT: UInt32 = 469763076
DIBUTTON_BIKINGM_SPECIAL2: UInt32 = 469763077
DIBUTTON_BIKINGM_MENU: UInt32 = 469763325
DIHATSWITCH_BIKINGM_SCROLL: UInt32 = 469779969
DIBUTTON_BIKINGM_ZOOM: UInt32 = 469779462
DIAXIS_BIKINGM_BRAKE: UInt32 = 470041091
DIBUTTON_BIKINGM_LEFT_LINK: UInt32 = 469812452
DIBUTTON_BIKINGM_RIGHT_LINK: UInt32 = 469812460
DIBUTTON_BIKINGM_FASTER_LINK: UInt32 = 469845216
DIBUTTON_BIKINGM_SLOWER_LINK: UInt32 = 469845224
DIBUTTON_BIKINGM_BRAKE_BUTTON_LINK: UInt32 = 470041832
DIBUTTON_BIKINGM_DEVICE: UInt32 = 469779710
DIBUTTON_BIKINGM_PAUSE: UInt32 = 469779708
DIVIRTUAL_SPORTS_SKIING: UInt32 = 486539264
DIAXIS_SKIING_TURN: UInt32 = 486572545
DIAXIS_SKIING_SPEED: UInt32 = 486605314
DIBUTTON_SKIING_JUMP: UInt32 = 486540289
DIBUTTON_SKIING_CROUCH: UInt32 = 486540290
DIBUTTON_SKIING_CAMERA: UInt32 = 486540291
DIBUTTON_SKIING_SPECIAL1: UInt32 = 486540292
DIBUTTON_SKIING_SELECT: UInt32 = 486540293
DIBUTTON_SKIING_SPECIAL2: UInt32 = 486540294
DIBUTTON_SKIING_MENU: UInt32 = 486540541
DIHATSWITCH_SKIING_GLANCE: UInt32 = 486557185
DIBUTTON_SKIING_ZOOM: UInt32 = 486556679
DIBUTTON_SKIING_LEFT_LINK: UInt32 = 486589668
DIBUTTON_SKIING_RIGHT_LINK: UInt32 = 486589676
DIBUTTON_SKIING_FASTER_LINK: UInt32 = 486622432
DIBUTTON_SKIING_SLOWER_LINK: UInt32 = 486622440
DIBUTTON_SKIING_DEVICE: UInt32 = 486556926
DIBUTTON_SKIING_PAUSE: UInt32 = 486556924
DIVIRTUAL_SPORTS_SOCCER_OFFENSE: UInt32 = 503316480
DIAXIS_SOCCERO_LATERAL: UInt32 = 503349761
DIAXIS_SOCCERO_MOVE: UInt32 = 503382530
DIAXIS_SOCCERO_BEND: UInt32 = 503415299
DIBUTTON_SOCCERO_SHOOT: UInt32 = 503317505
DIBUTTON_SOCCERO_PASS: UInt32 = 503317506
DIBUTTON_SOCCERO_FAKE: UInt32 = 503317507
DIBUTTON_SOCCERO_PLAYER: UInt32 = 503317508
DIBUTTON_SOCCERO_SPECIAL1: UInt32 = 503317509
DIBUTTON_SOCCERO_SELECT: UInt32 = 503317510
DIBUTTON_SOCCERO_MENU: UInt32 = 503317757
DIHATSWITCH_SOCCERO_GLANCE: UInt32 = 503334401
DIBUTTON_SOCCERO_SUBSTITUTE: UInt32 = 503333895
DIBUTTON_SOCCERO_SHOOTLOW: UInt32 = 503333896
DIBUTTON_SOCCERO_SHOOTHIGH: UInt32 = 503333897
DIBUTTON_SOCCERO_PASSTHRU: UInt32 = 503333898
DIBUTTON_SOCCERO_SPRINT: UInt32 = 503333899
DIBUTTON_SOCCERO_CONTROL: UInt32 = 503333900
DIBUTTON_SOCCERO_HEAD: UInt32 = 503333901
DIBUTTON_SOCCERO_LEFT_LINK: UInt32 = 503366884
DIBUTTON_SOCCERO_RIGHT_LINK: UInt32 = 503366892
DIBUTTON_SOCCERO_FORWARD_LINK: UInt32 = 503399648
DIBUTTON_SOCCERO_BACK_LINK: UInt32 = 503399656
DIBUTTON_SOCCERO_DEVICE: UInt32 = 503334142
DIBUTTON_SOCCERO_PAUSE: UInt32 = 503334140
DIVIRTUAL_SPORTS_SOCCER_DEFENSE: UInt32 = 520093696
DIAXIS_SOCCERD_LATERAL: UInt32 = 520126977
DIAXIS_SOCCERD_MOVE: UInt32 = 520159746
DIBUTTON_SOCCERD_BLOCK: UInt32 = 520094721
DIBUTTON_SOCCERD_STEAL: UInt32 = 520094722
DIBUTTON_SOCCERD_FAKE: UInt32 = 520094723
DIBUTTON_SOCCERD_PLAYER: UInt32 = 520094724
DIBUTTON_SOCCERD_SPECIAL: UInt32 = 520094725
DIBUTTON_SOCCERD_SELECT: UInt32 = 520094726
DIBUTTON_SOCCERD_SLIDE: UInt32 = 520094727
DIBUTTON_SOCCERD_MENU: UInt32 = 520094973
DIHATSWITCH_SOCCERD_GLANCE: UInt32 = 520111617
DIBUTTON_SOCCERD_FOUL: UInt32 = 520111112
DIBUTTON_SOCCERD_HEAD: UInt32 = 520111113
DIBUTTON_SOCCERD_CLEAR: UInt32 = 520111114
DIBUTTON_SOCCERD_GOALIECHARGE: UInt32 = 520111115
DIBUTTON_SOCCERD_SUBSTITUTE: UInt32 = 520111116
DIBUTTON_SOCCERD_LEFT_LINK: UInt32 = 520144100
DIBUTTON_SOCCERD_RIGHT_LINK: UInt32 = 520144108
DIBUTTON_SOCCERD_FORWARD_LINK: UInt32 = 520176864
DIBUTTON_SOCCERD_BACK_LINK: UInt32 = 520176872
DIBUTTON_SOCCERD_DEVICE: UInt32 = 520111358
DIBUTTON_SOCCERD_PAUSE: UInt32 = 520111356
DIVIRTUAL_SPORTS_RACQUET: UInt32 = 536870912
DIAXIS_RACQUET_LATERAL: UInt32 = 536904193
DIAXIS_RACQUET_MOVE: UInt32 = 536936962
DIBUTTON_RACQUET_SWING: UInt32 = 536871937
DIBUTTON_RACQUET_BACKSWING: UInt32 = 536871938
DIBUTTON_RACQUET_SMASH: UInt32 = 536871939
DIBUTTON_RACQUET_SPECIAL: UInt32 = 536871940
DIBUTTON_RACQUET_SELECT: UInt32 = 536871941
DIBUTTON_RACQUET_MENU: UInt32 = 536872189
DIHATSWITCH_RACQUET_GLANCE: UInt32 = 536888833
DIBUTTON_RACQUET_TIMEOUT: UInt32 = 536888326
DIBUTTON_RACQUET_SUBSTITUTE: UInt32 = 536888327
DIBUTTON_RACQUET_LEFT_LINK: UInt32 = 536921316
DIBUTTON_RACQUET_RIGHT_LINK: UInt32 = 536921324
DIBUTTON_RACQUET_FORWARD_LINK: UInt32 = 536954080
DIBUTTON_RACQUET_BACK_LINK: UInt32 = 536954088
DIBUTTON_RACQUET_DEVICE: UInt32 = 536888574
DIBUTTON_RACQUET_PAUSE: UInt32 = 536888572
DIVIRTUAL_ARCADE_SIDE2SIDE: UInt32 = 553648128
DIAXIS_ARCADES_LATERAL: UInt32 = 553681409
DIAXIS_ARCADES_MOVE: UInt32 = 553714178
DIBUTTON_ARCADES_THROW: UInt32 = 553649153
DIBUTTON_ARCADES_CARRY: UInt32 = 553649154
DIBUTTON_ARCADES_ATTACK: UInt32 = 553649155
DIBUTTON_ARCADES_SPECIAL: UInt32 = 553649156
DIBUTTON_ARCADES_SELECT: UInt32 = 553649157
DIBUTTON_ARCADES_MENU: UInt32 = 553649405
DIHATSWITCH_ARCADES_VIEW: UInt32 = 553666049
DIBUTTON_ARCADES_LEFT_LINK: UInt32 = 553698532
DIBUTTON_ARCADES_RIGHT_LINK: UInt32 = 553698540
DIBUTTON_ARCADES_FORWARD_LINK: UInt32 = 553731296
DIBUTTON_ARCADES_BACK_LINK: UInt32 = 553731304
DIBUTTON_ARCADES_VIEW_UP_LINK: UInt32 = 554157280
DIBUTTON_ARCADES_VIEW_DOWN_LINK: UInt32 = 554157288
DIBUTTON_ARCADES_VIEW_LEFT_LINK: UInt32 = 554157284
DIBUTTON_ARCADES_VIEW_RIGHT_LINK: UInt32 = 554157292
DIBUTTON_ARCADES_DEVICE: UInt32 = 553665790
DIBUTTON_ARCADES_PAUSE: UInt32 = 553665788
DIVIRTUAL_ARCADE_PLATFORM: UInt32 = 570425344
DIAXIS_ARCADEP_LATERAL: UInt32 = 570458625
DIAXIS_ARCADEP_MOVE: UInt32 = 570491394
DIBUTTON_ARCADEP_JUMP: UInt32 = 570426369
DIBUTTON_ARCADEP_FIRE: UInt32 = 570426370
DIBUTTON_ARCADEP_CROUCH: UInt32 = 570426371
DIBUTTON_ARCADEP_SPECIAL: UInt32 = 570426372
DIBUTTON_ARCADEP_SELECT: UInt32 = 570426373
DIBUTTON_ARCADEP_MENU: UInt32 = 570426621
DIHATSWITCH_ARCADEP_VIEW: UInt32 = 570443265
DIBUTTON_ARCADEP_FIRESECONDARY: UInt32 = 570442758
DIBUTTON_ARCADEP_LEFT_LINK: UInt32 = 570475748
DIBUTTON_ARCADEP_RIGHT_LINK: UInt32 = 570475756
DIBUTTON_ARCADEP_FORWARD_LINK: UInt32 = 570508512
DIBUTTON_ARCADEP_BACK_LINK: UInt32 = 570508520
DIBUTTON_ARCADEP_VIEW_UP_LINK: UInt32 = 570934496
DIBUTTON_ARCADEP_VIEW_DOWN_LINK: UInt32 = 570934504
DIBUTTON_ARCADEP_VIEW_LEFT_LINK: UInt32 = 570934500
DIBUTTON_ARCADEP_VIEW_RIGHT_LINK: UInt32 = 570934508
DIBUTTON_ARCADEP_DEVICE: UInt32 = 570443006
DIBUTTON_ARCADEP_PAUSE: UInt32 = 570443004
DIVIRTUAL_CAD_2DCONTROL: UInt32 = 587202560
DIAXIS_2DCONTROL_LATERAL: UInt32 = 587235841
DIAXIS_2DCONTROL_MOVE: UInt32 = 587268610
DIAXIS_2DCONTROL_INOUT: UInt32 = 587301379
DIBUTTON_2DCONTROL_SELECT: UInt32 = 587203585
DIBUTTON_2DCONTROL_SPECIAL1: UInt32 = 587203586
DIBUTTON_2DCONTROL_SPECIAL: UInt32 = 587203587
DIBUTTON_2DCONTROL_SPECIAL2: UInt32 = 587203588
DIBUTTON_2DCONTROL_MENU: UInt32 = 587203837
DIHATSWITCH_2DCONTROL_HATSWITCH: UInt32 = 587220481
DIAXIS_2DCONTROL_ROTATEZ: UInt32 = 587350532
DIBUTTON_2DCONTROL_DISPLAY: UInt32 = 587219973
DIBUTTON_2DCONTROL_DEVICE: UInt32 = 587220222
DIBUTTON_2DCONTROL_PAUSE: UInt32 = 587220220
DIVIRTUAL_CAD_3DCONTROL: UInt32 = 603979776
DIAXIS_3DCONTROL_LATERAL: UInt32 = 604013057
DIAXIS_3DCONTROL_MOVE: UInt32 = 604045826
DIAXIS_3DCONTROL_INOUT: UInt32 = 604078595
DIBUTTON_3DCONTROL_SELECT: UInt32 = 603980801
DIBUTTON_3DCONTROL_SPECIAL1: UInt32 = 603980802
DIBUTTON_3DCONTROL_SPECIAL: UInt32 = 603980803
DIBUTTON_3DCONTROL_SPECIAL2: UInt32 = 603980804
DIBUTTON_3DCONTROL_MENU: UInt32 = 603981053
DIHATSWITCH_3DCONTROL_HATSWITCH: UInt32 = 603997697
DIAXIS_3DCONTROL_ROTATEX: UInt32 = 604193284
DIAXIS_3DCONTROL_ROTATEY: UInt32 = 604160517
DIAXIS_3DCONTROL_ROTATEZ: UInt32 = 604127750
DIBUTTON_3DCONTROL_DISPLAY: UInt32 = 603997189
DIBUTTON_3DCONTROL_DEVICE: UInt32 = 603997438
DIBUTTON_3DCONTROL_PAUSE: UInt32 = 603997436
DIVIRTUAL_CAD_FLYBY: UInt32 = 620756992
DIAXIS_CADF_LATERAL: UInt32 = 620790273
DIAXIS_CADF_MOVE: UInt32 = 620823042
DIAXIS_CADF_INOUT: UInt32 = 620855811
DIBUTTON_CADF_SELECT: UInt32 = 620758017
DIBUTTON_CADF_SPECIAL1: UInt32 = 620758018
DIBUTTON_CADF_SPECIAL: UInt32 = 620758019
DIBUTTON_CADF_SPECIAL2: UInt32 = 620758020
DIBUTTON_CADF_MENU: UInt32 = 620758269
DIHATSWITCH_CADF_HATSWITCH: UInt32 = 620774913
DIAXIS_CADF_ROTATEX: UInt32 = 620970500
DIAXIS_CADF_ROTATEY: UInt32 = 620937733
DIAXIS_CADF_ROTATEZ: UInt32 = 620904966
DIBUTTON_CADF_DISPLAY: UInt32 = 620774405
DIBUTTON_CADF_DEVICE: UInt32 = 620774654
DIBUTTON_CADF_PAUSE: UInt32 = 620774652
DIVIRTUAL_CAD_MODEL: UInt32 = 637534208
DIAXIS_CADM_LATERAL: UInt32 = 637567489
DIAXIS_CADM_MOVE: UInt32 = 637600258
DIAXIS_CADM_INOUT: UInt32 = 637633027
DIBUTTON_CADM_SELECT: UInt32 = 637535233
DIBUTTON_CADM_SPECIAL1: UInt32 = 637535234
DIBUTTON_CADM_SPECIAL: UInt32 = 637535235
DIBUTTON_CADM_SPECIAL2: UInt32 = 637535236
DIBUTTON_CADM_MENU: UInt32 = 637535485
DIHATSWITCH_CADM_HATSWITCH: UInt32 = 637552129
DIAXIS_CADM_ROTATEX: UInt32 = 637747716
DIAXIS_CADM_ROTATEY: UInt32 = 637714949
DIAXIS_CADM_ROTATEZ: UInt32 = 637682182
DIBUTTON_CADM_DISPLAY: UInt32 = 637551621
DIBUTTON_CADM_DEVICE: UInt32 = 637551870
DIBUTTON_CADM_PAUSE: UInt32 = 637551868
DIVIRTUAL_REMOTE_CONTROL: UInt32 = 654311424
DIAXIS_REMOTE_SLIDER: UInt32 = 654639617
DIBUTTON_REMOTE_MUTE: UInt32 = 654312449
DIBUTTON_REMOTE_SELECT: UInt32 = 654312450
DIBUTTON_REMOTE_PLAY: UInt32 = 654320643
DIBUTTON_REMOTE_CUE: UInt32 = 654320644
DIBUTTON_REMOTE_REVIEW: UInt32 = 654320645
DIBUTTON_REMOTE_CHANGE: UInt32 = 654320646
DIBUTTON_REMOTE_RECORD: UInt32 = 654320647
DIBUTTON_REMOTE_MENU: UInt32 = 654312701
DIAXIS_REMOTE_SLIDER2: UInt32 = 654656002
DIBUTTON_REMOTE_TV: UInt32 = 654334984
DIBUTTON_REMOTE_CABLE: UInt32 = 654334985
DIBUTTON_REMOTE_CD: UInt32 = 654334986
DIBUTTON_REMOTE_VCR: UInt32 = 654334987
DIBUTTON_REMOTE_TUNER: UInt32 = 654334988
DIBUTTON_REMOTE_DVD: UInt32 = 654334989
DIBUTTON_REMOTE_ADJUST: UInt32 = 654334990
DIBUTTON_REMOTE_DIGIT0: UInt32 = 654332943
DIBUTTON_REMOTE_DIGIT1: UInt32 = 654332944
DIBUTTON_REMOTE_DIGIT2: UInt32 = 654332945
DIBUTTON_REMOTE_DIGIT3: UInt32 = 654332946
DIBUTTON_REMOTE_DIGIT4: UInt32 = 654332947
DIBUTTON_REMOTE_DIGIT5: UInt32 = 654332948
DIBUTTON_REMOTE_DIGIT6: UInt32 = 654332949
DIBUTTON_REMOTE_DIGIT7: UInt32 = 654332950
DIBUTTON_REMOTE_DIGIT8: UInt32 = 654332951
DIBUTTON_REMOTE_DIGIT9: UInt32 = 654332952
DIBUTTON_REMOTE_DEVICE: UInt32 = 654329086
DIBUTTON_REMOTE_PAUSE: UInt32 = 654329084
DIVIRTUAL_BROWSER_CONTROL: UInt32 = 671088640
DIAXIS_BROWSER_LATERAL: UInt32 = 671121921
DIAXIS_BROWSER_MOVE: UInt32 = 671154690
DIBUTTON_BROWSER_SELECT: UInt32 = 671089665
DIAXIS_BROWSER_VIEW: UInt32 = 671187459
DIBUTTON_BROWSER_REFRESH: UInt32 = 671089666
DIBUTTON_BROWSER_MENU: UInt32 = 671089917
DIBUTTON_BROWSER_SEARCH: UInt32 = 671106051
DIBUTTON_BROWSER_STOP: UInt32 = 671106052
DIBUTTON_BROWSER_HOME: UInt32 = 671106053
DIBUTTON_BROWSER_FAVORITES: UInt32 = 671106054
DIBUTTON_BROWSER_NEXT: UInt32 = 671106055
DIBUTTON_BROWSER_PREVIOUS: UInt32 = 671106056
DIBUTTON_BROWSER_HISTORY: UInt32 = 671106057
DIBUTTON_BROWSER_PRINT: UInt32 = 671106058
DIBUTTON_BROWSER_DEVICE: UInt32 = 671106302
DIBUTTON_BROWSER_PAUSE: UInt32 = 671106300
DIVIRTUAL_DRIVING_MECHA: UInt32 = 687865856
DIAXIS_MECHA_STEER: UInt32 = 687899137
DIAXIS_MECHA_TORSO: UInt32 = 687931906
DIAXIS_MECHA_ROTATE: UInt32 = 687997443
DIAXIS_MECHA_THROTTLE: UInt32 = 688095748
DIBUTTON_MECHA_FIRE: UInt32 = 687866881
DIBUTTON_MECHA_WEAPONS: UInt32 = 687866882
DIBUTTON_MECHA_TARGET: UInt32 = 687866883
DIBUTTON_MECHA_REVERSE: UInt32 = 687866884
DIBUTTON_MECHA_ZOOM: UInt32 = 687866885
DIBUTTON_MECHA_JUMP: UInt32 = 687866886
DIBUTTON_MECHA_MENU: UInt32 = 687867133
DIBUTTON_MECHA_CENTER: UInt32 = 687883271
DIHATSWITCH_MECHA_GLANCE: UInt32 = 687883777
DIBUTTON_MECHA_VIEW: UInt32 = 687883272
DIBUTTON_MECHA_FIRESECONDARY: UInt32 = 687883273
DIBUTTON_MECHA_LEFT_LINK: UInt32 = 687916260
DIBUTTON_MECHA_RIGHT_LINK: UInt32 = 687916268
DIBUTTON_MECHA_FORWARD_LINK: UInt32 = 687949024
DIBUTTON_MECHA_BACK_LINK: UInt32 = 687949032
DIBUTTON_MECHA_ROTATE_LEFT_LINK: UInt32 = 688014564
DIBUTTON_MECHA_ROTATE_RIGHT_LINK: UInt32 = 688014572
DIBUTTON_MECHA_FASTER_LINK: UInt32 = 688112864
DIBUTTON_MECHA_SLOWER_LINK: UInt32 = 688112872
DIBUTTON_MECHA_DEVICE: UInt32 = 687883518
DIBUTTON_MECHA_PAUSE: UInt32 = 687883516
DIAXIS_ANY_X_1: UInt32 = 4278239745
DIAXIS_ANY_X_2: UInt32 = 4278239746
DIAXIS_ANY_Y_1: UInt32 = 4278272513
DIAXIS_ANY_Y_2: UInt32 = 4278272514
DIAXIS_ANY_Z_1: UInt32 = 4278305281
DIAXIS_ANY_Z_2: UInt32 = 4278305282
DIAXIS_ANY_R_1: UInt32 = 4278338049
DIAXIS_ANY_R_2: UInt32 = 4278338050
DIAXIS_ANY_U_1: UInt32 = 4278370817
DIAXIS_ANY_U_2: UInt32 = 4278370818
DIAXIS_ANY_V_1: UInt32 = 4278403585
DIAXIS_ANY_V_2: UInt32 = 4278403586
DIAXIS_ANY_A_1: UInt32 = 4278436353
DIAXIS_ANY_A_2: UInt32 = 4278436354
DIAXIS_ANY_B_1: UInt32 = 4278469121
DIAXIS_ANY_B_2: UInt32 = 4278469122
DIAXIS_ANY_C_1: UInt32 = 4278501889
DIAXIS_ANY_C_2: UInt32 = 4278501890
DIAXIS_ANY_S_1: UInt32 = 4278534657
DIAXIS_ANY_S_2: UInt32 = 4278534658
DIAXIS_ANY_1: UInt32 = 4278206977
DIAXIS_ANY_2: UInt32 = 4278206978
DIAXIS_ANY_3: UInt32 = 4278206979
DIAXIS_ANY_4: UInt32 = 4278206980
DIPOV_ANY_1: UInt32 = 4278208001
DIPOV_ANY_2: UInt32 = 4278208002
DIPOV_ANY_3: UInt32 = 4278208003
DIPOV_ANY_4: UInt32 = 4278208004
JOY_PASSDRIVERDATA: Int32 = 268435456
JOY_HWS_ISHEADTRACKER: Int32 = 33554432
JOY_HWS_ISGAMEPORTDRIVER: Int32 = 67108864
JOY_HWS_ISANALOGPORTDRIVER: Int32 = 134217728
JOY_HWS_AUTOLOAD: Int32 = 268435456
JOY_HWS_NODEVNODE: Int32 = 536870912
JOY_HWS_ISGAMEPORTBUS: Int32 = -2147483648
JOY_HWS_GAMEPORTBUSBUSY: Int32 = 1
JOY_US_VOLATILE: Int32 = 8
JOY_OEMPOLL_PASSDRIVERDATA: UInt32 = 7
BUTTON_BIT_POWER: UInt32 = 1
BUTTON_BIT_WINDOWS: UInt32 = 2
BUTTON_BIT_VOLUMEUP: UInt32 = 4
BUTTON_BIT_VOLUMEDOWN: UInt32 = 8
BUTTON_BIT_ROTATION_LOCK: UInt32 = 16
BUTTON_BIT_BACK: UInt32 = 32
BUTTON_BIT_SEARCH: UInt32 = 64
BUTTON_BIT_CAMERAFOCUS: UInt32 = 128
BUTTON_BIT_CAMERASHUTTER: UInt32 = 256
BUTTON_BIT_RINGERTOGGLE: UInt32 = 512
BUTTON_BIT_HEADSET: UInt32 = 1024
BUTTON_BIT_HWKBDEPLOY: UInt32 = 2048
BUTTON_BIT_CAMERALENS: UInt32 = 4096
BUTTON_BIT_OEMCUSTOM: UInt32 = 8192
BUTTON_BIT_OEMCUSTOM2: UInt32 = 16384
BUTTON_BIT_OEMCUSTOM3: UInt32 = 32768
BUTTON_BIT_ALLBUTTONSMASK: UInt32 = 16383
IOCTL_BUTTON_SET_ENABLED_ON_IDLE: UInt32 = 721576
IOCTL_BUTTON_GET_ENABLED_ON_IDLE: UInt32 = 721580
@winfunctype('DINPUT8.dll')
def DirectInput8Create(hinst: win32more.Windows.Win32.Foundation.HINSTANCE, dwVersion: UInt32, riidltf: POINTER(Guid), ppvOut: POINTER(VoidPtr), punkOuter: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('WINMM.dll')
def joyConfigChanged(dwFlags: UInt32) -> UInt32: ...
@winfunctype('HID.dll')
def HidP_GetCaps(PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Capabilities: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_CAPS)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetLinkCollectionNodes(LinkCollectionNodes: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_LINK_COLLECTION_NODE), LinkCollectionNodesLength: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetSpecificButtonCaps(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, ButtonCaps: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_BUTTON_CAPS), ButtonCapsLength: POINTER(UInt16), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetButtonCaps(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, ButtonCaps: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_BUTTON_CAPS), ButtonCapsLength: POINTER(UInt16), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetSpecificValueCaps(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, ValueCaps: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_VALUE_CAPS), ValueCapsLength: POINTER(UInt16), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetValueCaps(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, ValueCaps: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_VALUE_CAPS), ValueCapsLength: POINTER(UInt16), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetExtendedAttributes(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, DataIndex: UInt16, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Attributes: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_EXTENDED_ATTRIBUTES), LengthAttributes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_InitializeReportForID(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, ReportID: Byte, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_SetData(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, DataList: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_DATA), DataLength: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetData(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, DataList: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_DATA), DataLength: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_MaxDataListLength(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> UInt32: ...
@winfunctype('HID.dll')
def HidP_SetUsages(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, UsageList: POINTER(UInt16), UsageLength: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_UnsetUsages(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, UsageList: POINTER(UInt16), UsageLength: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetUsages(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, UsageList: POINTER(UInt16), UsageLength: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetUsagesEx(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, LinkCollection: UInt16, ButtonList: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.USAGE_AND_PAGE), UsageLength: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_MaxUsageListLength(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> UInt32: ...
@winfunctype('HID.dll')
def HidP_SetUsageValue(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, UsageValue: UInt32, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_SetScaledUsageValue(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, UsageValue: Int32, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_SetUsageValueArray(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, UsageValue: win32more.Windows.Win32.Foundation.PSTR, UsageValueByteLength: UInt16, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetUsageValue(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, UsageValue: POINTER(UInt32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetScaledUsageValue(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, UsageValue: POINTER(Int32), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetUsageValueArray(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, UsageValue: win32more.Windows.Win32.Foundation.PSTR, UsageValueByteLength: UInt16, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_UsageListDifference(PreviousUsageList: POINTER(UInt16), CurrentUsageList: POINTER(UInt16), BreakUsageList: POINTER(UInt16), MakeUsageList: POINTER(UInt16), UsageListLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_GetButtonArray(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, ButtonData: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_BUTTON_ARRAY_DATA), ButtonDataLength: POINTER(UInt16), PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_SetButtonArray(ReportType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE, UsagePage: UInt16, LinkCollection: UInt16, Usage: UInt16, ButtonData: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_BUTTON_ARRAY_DATA), ButtonDataLength: UInt16, PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA, Report: win32more.Windows.Win32.Foundation.PSTR, ReportLength: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidP_TranslateUsagesToI8042ScanCodes(ChangedUsageList: POINTER(UInt16), UsageListLength: UInt32, KeyAction: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_KEYBOARD_DIRECTION, ModifierState: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_KEYBOARD_MODIFIER_STATE), InsertCodesProcedure: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_INSERT_SCANCODES, InsertCodesContext: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('HID.dll')
def HidD_GetAttributes(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Attributes: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDD_ATTRIBUTES)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetHidGuid(HidGuid: POINTER(Guid)) -> Void: ...
@winfunctype('HID.dll')
def HidD_GetPreparsedData(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, PreparsedData: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_FreePreparsedData(PreparsedData: win32more.Windows.Win32.Devices.HumanInterfaceDevice.PHIDP_PREPARSED_DATA) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_FlushQueue(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetConfiguration(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Configuration: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDD_CONFIGURATION), ConfigurationLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_SetConfiguration(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Configuration: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDD_CONFIGURATION), ConfigurationLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetFeature(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, ReportBuffer: VoidPtr, ReportBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_SetFeature(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, ReportBuffer: VoidPtr, ReportBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetInputReport(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, ReportBuffer: VoidPtr, ReportBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_SetOutputReport(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, ReportBuffer: VoidPtr, ReportBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetNumInputBuffers(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, NumberBuffers: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_SetNumInputBuffers(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, NumberBuffers: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetPhysicalDescriptor(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Buffer: VoidPtr, BufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetManufacturerString(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Buffer: VoidPtr, BufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetProductString(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Buffer: VoidPtr, BufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetIndexedString(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, StringIndex: UInt32, Buffer: VoidPtr, BufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetSerialNumberString(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Buffer: VoidPtr, BufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('HID.dll')
def HidD_GetMsGenreDescriptor(HidDeviceObject: win32more.Windows.Win32.Foundation.HANDLE, Buffer: VoidPtr, BufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
class CPOINT(Structure):
    lP: Int32
    dwLog: UInt32
class DIACTIONA(Structure):
    uAppData: UIntPtr
    dwSemantic: UInt32
    dwFlags: UInt32
    Anonymous: _Anonymous_e__Union
    guidInstance: Guid
    dwObjID: UInt32
    dwHow: UInt32
    class _Anonymous_e__Union(Union):
        lptszActionName: win32more.Windows.Win32.Foundation.PSTR
        uResIdString: UInt32
class DIACTIONFORMATA(Structure):
    dwSize: UInt32
    dwActionSize: UInt32
    dwDataSize: UInt32
    dwNumActions: UInt32
    rgoAction: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONA)
    guidActionMap: Guid
    dwGenre: UInt32
    dwBufferSize: UInt32
    lAxisMin: Int32
    lAxisMax: Int32
    hInstString: win32more.Windows.Win32.Foundation.HINSTANCE
    ftTimeStamp: win32more.Windows.Win32.Foundation.FILETIME
    dwCRC: UInt32
    tszActionMap: win32more.Windows.Win32.Foundation.CHAR * 260
class DIACTIONFORMATW(Structure):
    dwSize: UInt32
    dwActionSize: UInt32
    dwDataSize: UInt32
    dwNumActions: UInt32
    rgoAction: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONW)
    guidActionMap: Guid
    dwGenre: UInt32
    dwBufferSize: UInt32
    lAxisMin: Int32
    lAxisMax: Int32
    hInstString: win32more.Windows.Win32.Foundation.HINSTANCE
    ftTimeStamp: win32more.Windows.Win32.Foundation.FILETIME
    dwCRC: UInt32
    tszActionMap: Char * 260
DIACTIONFORMAT = UnicodeAlias('DIACTIONFORMATW')
class DIACTIONW(Structure):
    uAppData: UIntPtr
    dwSemantic: UInt32
    dwFlags: UInt32
    Anonymous: _Anonymous_e__Union
    guidInstance: Guid
    dwObjID: UInt32
    dwHow: UInt32
    class _Anonymous_e__Union(Union):
        lptszActionName: win32more.Windows.Win32.Foundation.PWSTR
        uResIdString: UInt32
DIACTION = UnicodeAlias('DIACTIONW')
class DICOLORSET(Structure):
    dwSize: UInt32
    cTextFore: UInt32
    cTextHighlight: UInt32
    cCalloutLine: UInt32
    cCalloutHighlight: UInt32
    cBorder: UInt32
    cControlFill: UInt32
    cHighlightFill: UInt32
    cAreaFill: UInt32
class DICONDITION(Structure):
    lOffset: Int32
    lPositiveCoefficient: Int32
    lNegativeCoefficient: Int32
    dwPositiveSaturation: UInt32
    dwNegativeSaturation: UInt32
    lDeadBand: Int32
class DICONFIGUREDEVICESPARAMSA(Structure):
    dwSize: UInt32
    dwcUsers: UInt32
    lptszUserNames: win32more.Windows.Win32.Foundation.PSTR
    dwcFormats: UInt32
    lprgFormats: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATA)
    hwnd: win32more.Windows.Win32.Foundation.HWND
    dics: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DICOLORSET
    lpUnkDDSTarget: win32more.Windows.Win32.System.Com.IUnknown
class DICONFIGUREDEVICESPARAMSW(Structure):
    dwSize: UInt32
    dwcUsers: UInt32
    lptszUserNames: win32more.Windows.Win32.Foundation.PWSTR
    dwcFormats: UInt32
    lprgFormats: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATW)
    hwnd: win32more.Windows.Win32.Foundation.HWND
    dics: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DICOLORSET
    lpUnkDDSTarget: win32more.Windows.Win32.System.Com.IUnknown
DICONFIGUREDEVICESPARAMS = UnicodeAlias('DICONFIGUREDEVICESPARAMSW')
class DICONSTANTFORCE(Structure):
    lMagnitude: Int32
class DICUSTOMFORCE(Structure):
    cChannels: UInt32
    dwSamplePeriod: UInt32
    cSamples: UInt32
    rglForceData: POINTER(Int32)
class DIDATAFORMAT(Structure):
    dwSize: UInt32
    dwObjSize: UInt32
    dwFlags: UInt32
    dwDataSize: UInt32
    dwNumObjs: UInt32
    rgodf: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIOBJECTDATAFORMAT)
class DIDEVCAPS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwDevType: UInt32
    dwAxes: UInt32
    dwButtons: UInt32
    dwPOVs: UInt32
    dwFFSamplePeriod: UInt32
    dwFFMinTimeResolution: UInt32
    dwFirmwareRevision: UInt32
    dwHardwareRevision: UInt32
    dwFFDriverVersion: UInt32
class DIDEVCAPS_DX3(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwDevType: UInt32
    dwAxes: UInt32
    dwButtons: UInt32
    dwPOVs: UInt32
class DIDEVICEIMAGEINFOA(Structure):
    tszImagePath: win32more.Windows.Win32.Foundation.CHAR * 260
    dwFlags: UInt32
    dwViewID: UInt32
    rcOverlay: win32more.Windows.Win32.Foundation.RECT
    dwObjID: UInt32
    dwcValidPts: UInt32
    rgptCalloutLine: win32more.Windows.Win32.Foundation.POINT * 5
    rcCalloutRect: win32more.Windows.Win32.Foundation.RECT
    dwTextAlign: UInt32
class DIDEVICEIMAGEINFOHEADERA(Structure):
    dwSize: UInt32
    dwSizeImageInfo: UInt32
    dwcViews: UInt32
    dwcButtons: UInt32
    dwcAxes: UInt32
    dwcPOVs: UInt32
    dwBufferSize: UInt32
    dwBufferUsed: UInt32
    lprgImageInfoArray: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEIMAGEINFOA)
class DIDEVICEIMAGEINFOHEADERW(Structure):
    dwSize: UInt32
    dwSizeImageInfo: UInt32
    dwcViews: UInt32
    dwcButtons: UInt32
    dwcAxes: UInt32
    dwcPOVs: UInt32
    dwBufferSize: UInt32
    dwBufferUsed: UInt32
    lprgImageInfoArray: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEIMAGEINFOW)
DIDEVICEIMAGEINFOHEADER = UnicodeAlias('DIDEVICEIMAGEINFOHEADERW')
class DIDEVICEIMAGEINFOW(Structure):
    tszImagePath: Char * 260
    dwFlags: UInt32
    dwViewID: UInt32
    rcOverlay: win32more.Windows.Win32.Foundation.RECT
    dwObjID: UInt32
    dwcValidPts: UInt32
    rgptCalloutLine: win32more.Windows.Win32.Foundation.POINT * 5
    rcCalloutRect: win32more.Windows.Win32.Foundation.RECT
    dwTextAlign: UInt32
DIDEVICEIMAGEINFO = UnicodeAlias('DIDEVICEIMAGEINFOW')
class DIDEVICEINSTANCEA(Structure):
    dwSize: UInt32
    guidInstance: Guid
    guidProduct: Guid
    dwDevType: UInt32
    tszInstanceName: win32more.Windows.Win32.Foundation.CHAR * 260
    tszProductName: win32more.Windows.Win32.Foundation.CHAR * 260
    guidFFDriver: Guid
    wUsagePage: UInt16
    wUsage: UInt16
class DIDEVICEINSTANCEW(Structure):
    dwSize: UInt32
    guidInstance: Guid
    guidProduct: Guid
    dwDevType: UInt32
    tszInstanceName: Char * 260
    tszProductName: Char * 260
    guidFFDriver: Guid
    wUsagePage: UInt16
    wUsage: UInt16
DIDEVICEINSTANCE = UnicodeAlias('DIDEVICEINSTANCEW')
class DIDEVICEINSTANCE_DX3A(Structure):
    dwSize: UInt32
    guidInstance: Guid
    guidProduct: Guid
    dwDevType: UInt32
    tszInstanceName: win32more.Windows.Win32.Foundation.CHAR * 260
    tszProductName: win32more.Windows.Win32.Foundation.CHAR * 260
class DIDEVICEINSTANCE_DX3W(Structure):
    dwSize: UInt32
    guidInstance: Guid
    guidProduct: Guid
    dwDevType: UInt32
    tszInstanceName: Char * 260
    tszProductName: Char * 260
DIDEVICEINSTANCE_DX3 = UnicodeAlias('DIDEVICEINSTANCE_DX3W')
class DIDEVICEOBJECTDATA(Structure):
    dwOfs: UInt32
    dwData: UInt32
    dwTimeStamp: UInt32
    dwSequence: UInt32
    uAppData: UIntPtr
class DIDEVICEOBJECTDATA_DX3(Structure):
    dwOfs: UInt32
    dwData: UInt32
    dwTimeStamp: UInt32
    dwSequence: UInt32
class DIDEVICEOBJECTINSTANCEA(Structure):
    dwSize: UInt32
    guidType: Guid
    dwOfs: UInt32
    dwType: UInt32
    dwFlags: UInt32
    tszName: win32more.Windows.Win32.Foundation.CHAR * 260
    dwFFMaxForce: UInt32
    dwFFForceResolution: UInt32
    wCollectionNumber: UInt16
    wDesignatorIndex: UInt16
    wUsagePage: UInt16
    wUsage: UInt16
    dwDimension: UInt32
    wExponent: UInt16
    wReportId: UInt16
class DIDEVICEOBJECTINSTANCEW(Structure):
    dwSize: UInt32
    guidType: Guid
    dwOfs: UInt32
    dwType: UInt32
    dwFlags: UInt32
    tszName: Char * 260
    dwFFMaxForce: UInt32
    dwFFForceResolution: UInt32
    wCollectionNumber: UInt16
    wDesignatorIndex: UInt16
    wUsagePage: UInt16
    wUsage: UInt16
    dwDimension: UInt32
    wExponent: UInt16
    wReportId: UInt16
DIDEVICEOBJECTINSTANCE = UnicodeAlias('DIDEVICEOBJECTINSTANCEW')
class DIDEVICEOBJECTINSTANCE_DX3A(Structure):
    dwSize: UInt32
    guidType: Guid
    dwOfs: UInt32
    dwType: UInt32
    dwFlags: UInt32
    tszName: win32more.Windows.Win32.Foundation.CHAR * 260
class DIDEVICEOBJECTINSTANCE_DX3W(Structure):
    dwSize: UInt32
    guidType: Guid
    dwOfs: UInt32
    dwType: UInt32
    dwFlags: UInt32
    tszName: Char * 260
DIDEVICEOBJECTINSTANCE_DX3 = UnicodeAlias('DIDEVICEOBJECTINSTANCE_DX3W')
class DIDEVICESTATE(Structure):
    dwSize: UInt32
    dwState: UInt32
    dwLoad: UInt32
class DIDRIVERVERSIONS(Structure):
    dwSize: UInt32
    dwFirmwareRevision: UInt32
    dwHardwareRevision: UInt32
    dwFFDriverVersion: UInt32
class DIEFFECT(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwDuration: UInt32
    dwSamplePeriod: UInt32
    dwGain: UInt32
    dwTriggerButton: UInt32
    dwTriggerRepeatInterval: UInt32
    cAxes: UInt32
    rgdwAxes: POINTER(UInt32)
    rglDirection: POINTER(Int32)
    lpEnvelope: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIENVELOPE)
    cbTypeSpecificParams: UInt32
    lpvTypeSpecificParams: VoidPtr
    dwStartDelay: UInt32
class DIEFFECTATTRIBUTES(Structure):
    dwEffectId: UInt32
    dwEffType: UInt32
    dwStaticParams: UInt32
    dwDynamicParams: UInt32
    dwCoords: UInt32
class DIEFFECTINFOA(Structure):
    dwSize: UInt32
    guid: Guid
    dwEffType: UInt32
    dwStaticParams: UInt32
    dwDynamicParams: UInt32
    tszName: win32more.Windows.Win32.Foundation.CHAR * 260
class DIEFFECTINFOW(Structure):
    dwSize: UInt32
    guid: Guid
    dwEffType: UInt32
    dwStaticParams: UInt32
    dwDynamicParams: UInt32
    tszName: Char * 260
DIEFFECTINFO = UnicodeAlias('DIEFFECTINFOW')
class DIEFFECT_DX5(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwDuration: UInt32
    dwSamplePeriod: UInt32
    dwGain: UInt32
    dwTriggerButton: UInt32
    dwTriggerRepeatInterval: UInt32
    cAxes: UInt32
    rgdwAxes: POINTER(UInt32)
    rglDirection: POINTER(Int32)
    lpEnvelope: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIENVELOPE)
    cbTypeSpecificParams: UInt32
    lpvTypeSpecificParams: VoidPtr
class DIEFFESCAPE(Structure):
    dwSize: UInt32
    dwCommand: UInt32
    lpvInBuffer: VoidPtr
    cbInBuffer: UInt32
    lpvOutBuffer: VoidPtr
    cbOutBuffer: UInt32
class DIENVELOPE(Structure):
    dwSize: UInt32
    dwAttackLevel: UInt32
    dwAttackTime: UInt32
    dwFadeLevel: UInt32
    dwFadeTime: UInt32
class DIFFDEVICEATTRIBUTES(Structure):
    dwFlags: UInt32
    dwFFSamplePeriod: UInt32
    dwFFMinTimeResolution: UInt32
class DIFFOBJECTATTRIBUTES(Structure):
    dwFFMaxForce: UInt32
    dwFFForceResolution: UInt32
class DIFILEEFFECT(Structure):
    dwSize: UInt32
    GuidEffect: Guid
    lpDiEffect: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT)
    szFriendlyName: win32more.Windows.Win32.Foundation.CHAR * 260
class DIHIDFFINITINFO(Structure):
    dwSize: UInt32
    pwszDeviceInterface: win32more.Windows.Win32.Foundation.PWSTR
    GuidInstance: Guid
class DIJOYCONFIG(Structure):
    dwSize: UInt32
    guidInstance: Guid
    hwc: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGHWCONFIG
    dwGain: UInt32
    wszType: Char * 256
    wszCallout: Char * 256
    guidGameport: Guid
class DIJOYCONFIG_DX5(Structure):
    dwSize: UInt32
    guidInstance: Guid
    hwc: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGHWCONFIG
    dwGain: UInt32
    wszType: Char * 256
    wszCallout: Char * 256
class DIJOYSTATE(Structure):
    lX: Int32
    lY: Int32
    lZ: Int32
    lRx: Int32
    lRy: Int32
    lRz: Int32
    rglSlider: Int32 * 2
    rgdwPOV: UInt32 * 4
    rgbButtons: Byte * 32
class DIJOYSTATE2(Structure):
    lX: Int32
    lY: Int32
    lZ: Int32
    lRx: Int32
    lRy: Int32
    lRz: Int32
    rglSlider: Int32 * 2
    rgdwPOV: UInt32 * 4
    rgbButtons: Byte * 128
    lVX: Int32
    lVY: Int32
    lVZ: Int32
    lVRx: Int32
    lVRy: Int32
    lVRz: Int32
    rglVSlider: Int32 * 2
    lAX: Int32
    lAY: Int32
    lAZ: Int32
    lARx: Int32
    lARy: Int32
    lARz: Int32
    rglASlider: Int32 * 2
    lFX: Int32
    lFY: Int32
    lFZ: Int32
    lFRx: Int32
    lFRy: Int32
    lFRz: Int32
    rglFSlider: Int32 * 2
class DIJOYTYPEINFO(Structure):
    dwSize: UInt32
    hws: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGHWSETTINGS
    clsidConfig: Guid
    wszDisplayName: Char * 256
    wszCallout: Char * 260
    wszHardwareId: Char * 256
    dwFlags1: UInt32
    dwFlags2: UInt32
    wszMapFile: Char * 256
class DIJOYTYPEINFO_DX5(Structure):
    dwSize: UInt32
    hws: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGHWSETTINGS
    clsidConfig: Guid
    wszDisplayName: Char * 256
    wszCallout: Char * 260
class DIJOYTYPEINFO_DX6(Structure):
    dwSize: UInt32
    hws: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGHWSETTINGS
    clsidConfig: Guid
    wszDisplayName: Char * 256
    wszCallout: Char * 260
    wszHardwareId: Char * 256
    dwFlags1: UInt32
class DIJOYUSERVALUES(Structure):
    dwSize: UInt32
    ruv: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGUSERVALUES
    wszGlobalDriver: Char * 256
    wszGameportEmulator: Char * 256
class DIMOUSESTATE(Structure):
    lX: Int32
    lY: Int32
    lZ: Int32
    rgbButtons: Byte * 4
class DIMOUSESTATE2(Structure):
    lX: Int32
    lY: Int32
    lZ: Int32
    rgbButtons: Byte * 8
class DIOBJECTATTRIBUTES(Structure):
    dwFlags: UInt32
    wUsagePage: UInt16
    wUsage: UInt16
class DIOBJECTCALIBRATION(Structure):
    lMin: Int32
    lCenter: Int32
    lMax: Int32
class DIOBJECTDATAFORMAT(Structure):
    pguid: POINTER(Guid)
    dwOfs: UInt32
    dwType: UInt32
    dwFlags: UInt32
class DIPERIODIC(Structure):
    dwMagnitude: UInt32
    lOffset: Int32
    dwPhase: UInt32
    dwPeriod: UInt32
class DIPOVCALIBRATION(Structure):
    lMin: Int32 * 5
    lMax: Int32 * 5
class DIPROPCAL(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    lMin: Int32
    lCenter: Int32
    lMax: Int32
class DIPROPCALPOV(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    lMin: Int32 * 5
    lMax: Int32 * 5
class DIPROPCPOINTS(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    dwCPointsNum: UInt32
    cp: win32more.Windows.Win32.Devices.HumanInterfaceDevice.CPOINT * 8
class DIPROPDWORD(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    dwData: UInt32
class DIPROPGUIDANDPATH(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    guidClass: Guid
    wszPath: Char * 260
class DIPROPHEADER(Structure):
    dwSize: UInt32
    dwHeaderSize: UInt32
    dwObj: UInt32
    dwHow: UInt32
class DIPROPPOINTER(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    uData: UIntPtr
class DIPROPRANGE(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    lMin: Int32
    lMax: Int32
class DIPROPSTRING(Structure):
    diph: win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER
    wsz: Char * 260
class DIRAMPFORCE(Structure):
    lStart: Int32
    lEnd: Int32
GPIOBUTTONS_BUTTON_TYPE = Int32
GPIO_BUTTON_POWER: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 0
GPIO_BUTTON_WINDOWS: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 1
GPIO_BUTTON_VOLUME_UP: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 2
GPIO_BUTTON_VOLUME_DOWN: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 3
GPIO_BUTTON_ROTATION_LOCK: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 4
GPIO_BUTTON_BACK: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 5
GPIO_BUTTON_SEARCH: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 6
GPIO_BUTTON_CAMERA_FOCUS: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 7
GPIO_BUTTON_CAMERA_SHUTTER: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 8
GPIO_BUTTON_RINGER_TOGGLE: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 9
GPIO_BUTTON_HEADSET: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 10
GPIO_BUTTON_HWKB_DEPLOY: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 11
GPIO_BUTTON_CAMERA_LENS: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 12
GPIO_BUTTON_OEM_CUSTOM: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 13
GPIO_BUTTON_OEM_CUSTOM2: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 14
GPIO_BUTTON_OEM_CUSTOM3: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 15
GPIO_BUTTON_COUNT_MIN: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 5
GPIO_BUTTON_COUNT: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE = 16
class HIDD_ATTRIBUTES(Structure):
    Size: UInt32
    VendorID: UInt16
    ProductID: UInt16
    VersionNumber: UInt16
class HIDD_CONFIGURATION(Structure):
    cookie: VoidPtr
    size: UInt32
    RingBufferSize: UInt32
    _pack_ = 4
class HIDP_BUTTON_ARRAY_DATA(Structure):
    ArrayIndex: UInt16
    On: win32more.Windows.Win32.Foundation.BOOLEAN
class HIDP_BUTTON_CAPS(Structure):
    UsagePage: UInt16
    ReportID: Byte
    IsAlias: win32more.Windows.Win32.Foundation.BOOLEAN
    BitField: UInt16
    LinkCollection: UInt16
    LinkUsage: UInt16
    LinkUsagePage: UInt16
    IsRange: win32more.Windows.Win32.Foundation.BOOLEAN
    IsStringRange: win32more.Windows.Win32.Foundation.BOOLEAN
    IsDesignatorRange: win32more.Windows.Win32.Foundation.BOOLEAN
    IsAbsolute: win32more.Windows.Win32.Foundation.BOOLEAN
    ReportCount: UInt16
    Reserved2: UInt16
    Reserved: UInt32 * 9
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Range: _Range_e__Struct
        NotRange: _NotRange_e__Struct
        class _Range_e__Struct(Structure):
            UsageMin: UInt16
            UsageMax: UInt16
            StringMin: UInt16
            StringMax: UInt16
            DesignatorMin: UInt16
            DesignatorMax: UInt16
            DataIndexMin: UInt16
            DataIndexMax: UInt16
        class _NotRange_e__Struct(Structure):
            Usage: UInt16
            Reserved1: UInt16
            StringIndex: UInt16
            Reserved2: UInt16
            DesignatorIndex: UInt16
            Reserved3: UInt16
            DataIndex: UInt16
            Reserved4: UInt16
class HIDP_CAPS(Structure):
    Usage: UInt16
    UsagePage: UInt16
    InputReportByteLength: UInt16
    OutputReportByteLength: UInt16
    FeatureReportByteLength: UInt16
    Reserved: UInt16 * 17
    NumberLinkCollectionNodes: UInt16
    NumberInputButtonCaps: UInt16
    NumberInputValueCaps: UInt16
    NumberInputDataIndices: UInt16
    NumberOutputButtonCaps: UInt16
    NumberOutputValueCaps: UInt16
    NumberOutputDataIndices: UInt16
    NumberFeatureButtonCaps: UInt16
    NumberFeatureValueCaps: UInt16
    NumberFeatureDataIndices: UInt16
class HIDP_DATA(Structure):
    DataIndex: UInt16
    Reserved: UInt16
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        RawValue: UInt32
        On: win32more.Windows.Win32.Foundation.BOOLEAN
class HIDP_EXTENDED_ATTRIBUTES(Structure):
    NumGlobalUnknowns: Byte
    Reserved: Byte * 3
    GlobalUnknowns: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_UNKNOWN_TOKEN)
    Data: UInt32 * 1
    _pack_ = 4
HIDP_KEYBOARD_DIRECTION = Int32
HidP_Keyboard_Break: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_KEYBOARD_DIRECTION = 0
HidP_Keyboard_Make: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_KEYBOARD_DIRECTION = 1
class HIDP_KEYBOARD_MODIFIER_STATE(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        ul: UInt32
        class _Anonymous_e__Struct(Structure):
            LeftControl: Annotated[UInt32, 1]
            LeftShift: Annotated[UInt32, 1]
            LeftAlt: Annotated[UInt32, 1]
            LeftGUI: Annotated[UInt32, 1]
            RightControl: Annotated[UInt32, 1]
            RightShift: Annotated[UInt32, 1]
            RightAlt: Annotated[UInt32, 1]
            RigthGUI: Annotated[UInt32, 1]
            CapsLock: Annotated[UInt32, 1]
            ScollLock: Annotated[UInt32, 1]
            NumLock: Annotated[UInt32, 1]
            Reserved: Annotated[UInt32, 21]
class HIDP_LINK_COLLECTION_NODE(Structure):
    LinkUsage: UInt16
    LinkUsagePage: UInt16
    Parent: UInt16
    NumberOfChildren: UInt16
    NextSibling: UInt16
    FirstChild: UInt16
    CollectionType: Annotated[UInt32, 8]
    IsAlias: Annotated[UInt32, 1]
    Reserved: Annotated[UInt32, 23]
    UserContext: VoidPtr
    _pack_ = 4
HIDP_REPORT_TYPE = Int32
HidP_Input: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE = 0
HidP_Output: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE = 1
HidP_Feature: win32more.Windows.Win32.Devices.HumanInterfaceDevice.HIDP_REPORT_TYPE = 2
class HIDP_UNKNOWN_TOKEN(Structure):
    Token: Byte
    Reserved: Byte * 3
    BitField: UInt32
class HIDP_VALUE_CAPS(Structure):
    UsagePage: UInt16
    ReportID: Byte
    IsAlias: win32more.Windows.Win32.Foundation.BOOLEAN
    BitField: UInt16
    LinkCollection: UInt16
    LinkUsage: UInt16
    LinkUsagePage: UInt16
    IsRange: win32more.Windows.Win32.Foundation.BOOLEAN
    IsStringRange: win32more.Windows.Win32.Foundation.BOOLEAN
    IsDesignatorRange: win32more.Windows.Win32.Foundation.BOOLEAN
    IsAbsolute: win32more.Windows.Win32.Foundation.BOOLEAN
    HasNull: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved: Byte
    BitSize: UInt16
    ReportCount: UInt16
    Reserved2: UInt16 * 5
    UnitsExp: UInt32
    Units: UInt32
    LogicalMin: Int32
    LogicalMax: Int32
    PhysicalMin: Int32
    PhysicalMax: Int32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Range: _Range_e__Struct
        NotRange: _NotRange_e__Struct
        class _Range_e__Struct(Structure):
            UsageMin: UInt16
            UsageMax: UInt16
            StringMin: UInt16
            StringMax: UInt16
            DesignatorMin: UInt16
            DesignatorMax: UInt16
            DataIndexMin: UInt16
            DataIndexMax: UInt16
        class _NotRange_e__Struct(Structure):
            Usage: UInt16
            Reserved1: UInt16
            StringIndex: UInt16
            Reserved2: UInt16
            DesignatorIndex: UInt16
            Reserved3: UInt16
            DataIndex: UInt16
            Reserved4: UInt16
class HID_COLLECTION_INFORMATION(Structure):
    DescriptorSize: UInt32
    Polled: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved1: Byte * 1
    VendorID: UInt16
    ProductID: UInt16
    VersionNumber: UInt16
class HID_DRIVER_CONFIG(Structure):
    Size: UInt32
    RingBufferSize: UInt32
class HID_XFER_PACKET(Structure):
    reportBuffer: POINTER(Byte)
    reportBufferLen: UInt32
    reportId: Byte
class IDirectInput2A(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputA
    _iid_ = Guid('{5944e662-aa8a-11cf-bfc7-444553540000}')
    @commethod(8)
    def FindDevice(self, param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PSTR, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInput2W(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputW
    _iid_ = Guid('{5944e663-aa8a-11cf-bfc7-444553540000}')
    @commethod(8)
    def FindDevice(self, param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PWSTR, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInput2 = UnicodeAlias('IDirectInput2W')
class IDirectInput7A(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInput2A
    _iid_ = Guid('{9a4cb684-236d-11d3-8e9d-00c04f6844ae}')
    @commethod(9)
    def CreateDeviceEx(self, param0: POINTER(Guid), param1: POINTER(Guid), param2: POINTER(VoidPtr), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInput7W(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInput2W
    _iid_ = Guid('{9a4cb685-236d-11d3-8e9d-00c04f6844ae}')
    @commethod(9)
    def CreateDeviceEx(self, param0: POINTER(Guid), param1: POINTER(Guid), param2: POINTER(VoidPtr), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInput7 = UnicodeAlias('IDirectInput7W')
class IDirectInput8A(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bf798030-483a-4da2-aa99-5d64ed369700}')
    @commethod(3)
    def CreateDevice(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDevice8A), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumDevices(self, param0: UInt32, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICESCALLBACKA, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDeviceStatus(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def FindDevice(self, param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PSTR, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumDevicesBySemantics(self, param0: win32more.Windows.Win32.Foundation.PSTR, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATA), param2: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICESBYSEMANTICSCBA, param3: VoidPtr, param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ConfigureDevices(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDICONFIGUREDEVICESCALLBACK, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DICONFIGUREDEVICESPARAMSA), param2: UInt32, param3: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInput8W(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bf798031-483a-4da2-aa99-5d64ed369700}')
    @commethod(3)
    def CreateDevice(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDevice8W), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumDevices(self, param0: UInt32, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICESCALLBACKW, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDeviceStatus(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def FindDevice(self, param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PWSTR, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumDevicesBySemantics(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATW), param2: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICESBYSEMANTICSCBW, param3: VoidPtr, param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ConfigureDevices(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDICONFIGUREDEVICESCALLBACK, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DICONFIGUREDEVICESPARAMSW), param2: UInt32, param3: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInput8 = UnicodeAlias('IDirectInput8W')
class IDirectInputA(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{89521360-aa8a-11cf-bfc7-444553540000}')
    @commethod(3)
    def CreateDevice(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDeviceA), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumDevices(self, param0: UInt32, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICESCALLBACKA, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDeviceStatus(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputDevice2A(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDeviceA
    _iid_ = Guid('{5944e682-c92e-11cf-bfc7-444553540000}')
    @commethod(18)
    def CreateEffect(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT), param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputEffect), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def EnumEffects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSCALLBACKA, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetEffectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECTINFOA), param1: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetForceFeedbackState(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SendForceFeedbackCommand(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def EnumCreatedEffectObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMCREATEDEFFECTOBJECTSCALLBACK, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def Escape(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFESCAPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Poll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SendDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputDevice2W(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDeviceW
    _iid_ = Guid('{5944e683-c92e-11cf-bfc7-444553540000}')
    @commethod(18)
    def CreateEffect(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT), param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputEffect), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def EnumEffects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSCALLBACKW, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetEffectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECTINFOW), param1: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetForceFeedbackState(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SendForceFeedbackCommand(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def EnumCreatedEffectObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMCREATEDEFFECTOBJECTSCALLBACK, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def Escape(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFESCAPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Poll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SendDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInputDevice2 = UnicodeAlias('IDirectInputDevice2W')
class IDirectInputDevice7A(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDevice2A
    _iid_ = Guid('{57d7c6bc-2356-11d3-8e9d-00c04f6844ae}')
    @commethod(27)
    def EnumEffectsInFile(self, param0: win32more.Windows.Win32.Foundation.PSTR, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSINFILECALLBACK, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def WriteEffectToFile(self, param0: win32more.Windows.Win32.Foundation.PSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIFILEEFFECT), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputDevice7W(ComPtr):
    extends: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDevice2W
    _iid_ = Guid('{57d7c6bd-2356-11d3-8e9d-00c04f6844ae}')
    @commethod(27)
    def EnumEffectsInFile(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSINFILECALLBACK, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def WriteEffectToFile(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIFILEEFFECT), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInputDevice7 = UnicodeAlias('IDirectInputDevice7W')
class IDirectInputDevice8A(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{54d41080-dc15-4833-a41b-748f73a38179}')
    @commethod(3)
    def GetCapabilities(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICEOBJECTSCALLBACKA, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Acquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Unacquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDeviceState(self, param0: UInt32, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetDataFormat(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDATAFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetEventNotification(self, param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetObjectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTINSTANCEA), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetDeviceInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateEffect(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT), param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputEffect), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def EnumEffects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSCALLBACKA, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetEffectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECTINFOA), param1: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetForceFeedbackState(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SendForceFeedbackCommand(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def EnumCreatedEffectObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMCREATEDEFFECTOBJECTSCALLBACK, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def Escape(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFESCAPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Poll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SendDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def EnumEffectsInFile(self, param0: win32more.Windows.Win32.Foundation.PSTR, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSINFILECALLBACK, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def WriteEffectToFile(self, param0: win32more.Windows.Win32.Foundation.PSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIFILEEFFECT), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def BuildActionMap(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATA), param1: win32more.Windows.Win32.Foundation.PSTR, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetActionMap(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATA), param1: win32more.Windows.Win32.Foundation.PSTR, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetImageInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEIMAGEINFOHEADERA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputDevice8W(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{54d41081-dc15-4833-a41b-748f73a38179}')
    @commethod(3)
    def GetCapabilities(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICEOBJECTSCALLBACKW, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Acquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Unacquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDeviceState(self, param0: UInt32, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetDataFormat(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDATAFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetEventNotification(self, param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetObjectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTINSTANCEW), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetDeviceInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateEffect(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT), param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputEffect), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def EnumEffects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSCALLBACKW, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetEffectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECTINFOW), param1: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetForceFeedbackState(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SendForceFeedbackCommand(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def EnumCreatedEffectObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMCREATEDEFFECTOBJECTSCALLBACK, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def Escape(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFESCAPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Poll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SendDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def EnumEffectsInFile(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMEFFECTSINFILECALLBACK, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def WriteEffectToFile(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIFILEEFFECT), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def BuildActionMap(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATW), param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetActionMap(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIACTIONFORMATW), param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetImageInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEIMAGEINFOHEADERW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInputDevice8 = UnicodeAlias('IDirectInputDevice8W')
class IDirectInputDeviceA(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5944e680-c92e-11cf-bfc7-444553540000}')
    @commethod(3)
    def GetCapabilities(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICEOBJECTSCALLBACKA, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Acquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Unacquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDeviceState(self, param0: UInt32, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetDataFormat(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDATAFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetEventNotification(self, param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetObjectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTINSTANCEA), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetDeviceInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputDeviceW(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5944e681-c92e-11cf-bfc7-444553540000}')
    @commethod(3)
    def GetCapabilities(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumObjects(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICEOBJECTSCALLBACKW, param1: VoidPtr, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetProperty(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIPROPHEADER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Acquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Unacquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDeviceState(self, param0: UInt32, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetDeviceData(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTDATA), param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetDataFormat(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDATAFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetEventNotification(self, param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetObjectInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTINSTANCEW), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetDeviceInfo(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInputDevice = UnicodeAlias('IDirectInputDeviceW')
class IDirectInputEffect(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e7e1f7c0-88d2-11d0-9ad0-00a0c9a06e35}')
    @commethod(3)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32, param2: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEffectGuid(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetParameters(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetParameters(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Start(self, param0: UInt32, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Stop(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetEffectStatus(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Download(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Unload(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Escape(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFESCAPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputEffectDriver(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{02538130-898f-11d0-9ad0-00a0c9a06e35}')
    @commethod(3)
    def DeviceID(self, param0: UInt32, param1: UInt32, param2: UInt32, param3: UInt32, param4: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetVersions(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDRIVERVERSIONS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Escape(self, param0: UInt32, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFESCAPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetGain(self, param0: UInt32, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SendForceFeedbackCommand(self, param0: UInt32, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetForceFeedbackState(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICESTATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DownloadEffect(self, param0: UInt32, param1: UInt32, param2: POINTER(UInt32), param3: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECT), param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DestroyEffect(self, param0: UInt32, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def StartEffect(self, param0: UInt32, param1: UInt32, param2: UInt32, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def StopEffect(self, param0: UInt32, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetEffectStatus(self, param0: UInt32, param1: UInt32, param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputJoyConfig(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1de12ab1-c9f5-11cf-bfc7-444553540000}')
    @commethod(3)
    def Acquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Unacquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SendNotify(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def EnumTypes(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIJOYTYPECALLBACK, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetTypeInfo(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYTYPEINFO), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetTypeInfo(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYTYPEINFO), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DeleteType(self, param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetConfig(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYCONFIG), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetConfig(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYCONFIG), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def DeleteConfig(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetUserValues(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYUSERVALUES), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetUserValues(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYUSERVALUES), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddNewHardware(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def OpenTypeKey(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OpenConfigKey(self, param0: UInt32, param1: UInt32, param2: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputJoyConfig8(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{eb0d7dfa-1990-4f27-b4d6-edf2eec4a44c}')
    @commethod(3)
    def Acquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Unacquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SendNotify(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def EnumTypes(self, param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIJOYTYPECALLBACK, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetTypeInfo(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYTYPEINFO), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetTypeInfo(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYTYPEINFO), param2: UInt32, param3: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DeleteType(self, param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetConfig(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYCONFIG), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetConfig(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYCONFIG), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def DeleteConfig(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetUserValues(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYUSERVALUES), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetUserValues(self, param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIJOYUSERVALUES), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddNewHardware(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def OpenTypeKey(self, param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OpenAppStatusKey(self, param0: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectInputW(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{89521361-aa8a-11cf-bfc7-444553540000}')
    @commethod(3)
    def CreateDevice(self, param0: POINTER(Guid), param1: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDeviceW), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumDevices(self, param0: UInt32, param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.LPDIENUMDEVICESCALLBACKW, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDeviceStatus(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RunControlPanel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Initialize(self, param0: win32more.Windows.Win32.Foundation.HINSTANCE, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IDirectInput = UnicodeAlias('IDirectInputW')
class INDICATOR_LIST(Structure):
    MakeCode: UInt16
    IndicatorFlags: UInt16
class INPUT_BUTTON_ENABLE_INFO(Structure):
    ButtonType: win32more.Windows.Win32.Devices.HumanInterfaceDevice.GPIOBUTTONS_BUTTON_TYPE
    Enabled: win32more.Windows.Win32.Foundation.BOOLEAN
class JOYCALIBRATE(Structure):
    wXbase: UInt32
    wXdelta: UInt32
    wYbase: UInt32
    wYdelta: UInt32
    wZbase: UInt32
    wZdelta: UInt32
class JOYPOS(Structure):
    dwX: UInt32
    dwY: UInt32
    dwZ: UInt32
    dwR: UInt32
    dwU: UInt32
    dwV: UInt32
class JOYRANGE(Structure):
    jpMin: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYPOS
    jpMax: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYPOS
    jpCenter: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYPOS
class JOYREGHWCONFIG(Structure):
    hws: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGHWSETTINGS
    dwUsageSettings: UInt32
    hwv: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYREGHWVALUES
    dwType: UInt32
    dwReserved: UInt32
class JOYREGHWSETTINGS(Structure):
    dwFlags: UInt32
    dwNumButtons: UInt32
class JOYREGHWVALUES(Structure):
    jrvHardware: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYRANGE
    dwPOVValues: UInt32 * 4
    dwCalFlags: UInt32
class JOYREGUSERVALUES(Structure):
    dwTimeOut: UInt32
    jrvRanges: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYRANGE
    jpDeadZone: win32more.Windows.Win32.Devices.HumanInterfaceDevice.JOYPOS
class KEYBOARD_ATTRIBUTES(Structure):
    KeyboardIdentifier: win32more.Windows.Win32.Devices.HumanInterfaceDevice.KEYBOARD_ID
    KeyboardMode: UInt16
    NumberOfFunctionKeys: UInt16
    NumberOfIndicators: UInt16
    NumberOfKeysTotal: UInt16
    InputDataQueueLength: UInt32
    KeyRepeatMinimum: win32more.Windows.Win32.Devices.HumanInterfaceDevice.KEYBOARD_TYPEMATIC_PARAMETERS
    KeyRepeatMaximum: win32more.Windows.Win32.Devices.HumanInterfaceDevice.KEYBOARD_TYPEMATIC_PARAMETERS
class KEYBOARD_EXTENDED_ATTRIBUTES(Structure):
    Version: Byte
    FormFactor: Byte
    KeyType: Byte
    PhysicalLayout: Byte
    VendorSpecificPhysicalLayout: Byte
    IETFLanguageTagIndex: Byte
    ImplementedInputAssistControls: Byte
class KEYBOARD_ID(Structure):
    Type: Byte
    Subtype: Byte
class KEYBOARD_IME_STATUS(Structure):
    UnitId: UInt16
    ImeOpen: UInt32
    ImeConvMode: UInt32
class KEYBOARD_INDICATOR_PARAMETERS(Structure):
    UnitId: UInt16
    LedFlags: UInt16
class KEYBOARD_INDICATOR_TRANSLATION(Structure):
    NumberOfIndicatorKeys: UInt16
    IndicatorList: win32more.Windows.Win32.Devices.HumanInterfaceDevice.INDICATOR_LIST * 1
class KEYBOARD_INPUT_DATA(Structure):
    UnitId: UInt16
    MakeCode: UInt16
    Flags: UInt16
    Reserved: UInt16
    ExtraInformation: UInt32
class KEYBOARD_TYPEMATIC_PARAMETERS(Structure):
    UnitId: UInt16
    Rate: UInt16
    Delay: UInt16
class KEYBOARD_UNIT_ID_PARAMETER(Structure):
    UnitId: UInt16
@winfunctype_pointer
def LPDICONFIGUREDEVICESCALLBACK(param0: win32more.Windows.Win32.System.Com.IUnknown, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIENUMCREATEDEFFECTOBJECTSCALLBACK(param0: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputEffect, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIENUMDEVICEOBJECTSCALLBACKA(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTINSTANCEA), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIENUMDEVICEOBJECTSCALLBACKW(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEOBJECTINSTANCEW), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
LPDIENUMDEVICEOBJECTSCALLBACK = UnicodeAlias('LPDIENUMDEVICEOBJECTSCALLBACKW')
@winfunctype_pointer
def LPDIENUMDEVICESBYSEMANTICSCBA(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEA), param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDevice8A, param2: UInt32, param3: UInt32, param4: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIENUMDEVICESBYSEMANTICSCBW(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEW), param1: win32more.Windows.Win32.Devices.HumanInterfaceDevice.IDirectInputDevice8W, param2: UInt32, param3: UInt32, param4: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
LPDIENUMDEVICESBYSEMANTICSCB = UnicodeAlias('LPDIENUMDEVICESBYSEMANTICSCBW')
@winfunctype_pointer
def LPDIENUMDEVICESCALLBACKA(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEA), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIENUMDEVICESCALLBACKW(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIDEVICEINSTANCEW), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
LPDIENUMDEVICESCALLBACK = UnicodeAlias('LPDIENUMDEVICESCALLBACKW')
@winfunctype_pointer
def LPDIENUMEFFECTSCALLBACKA(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECTINFOA), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIENUMEFFECTSCALLBACKW(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIEFFECTINFOW), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
LPDIENUMEFFECTSCALLBACK = UnicodeAlias('LPDIENUMEFFECTSCALLBACKW')
@winfunctype_pointer
def LPDIENUMEFFECTSINFILECALLBACK(param0: POINTER(win32more.Windows.Win32.Devices.HumanInterfaceDevice.DIFILEEFFECT), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIJOYTYPECALLBACK(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPFNSHOWJOYCPL(hWnd: win32more.Windows.Win32.Foundation.HWND) -> Void: ...
class MOUSE_ATTRIBUTES(Structure):
    MouseIdentifier: UInt16
    NumberOfButtons: UInt16
    SampleRate: UInt16
    InputDataQueueLength: UInt32
class MOUSE_INPUT_DATA(Structure):
    UnitId: UInt16
    Flags: UInt16
    Anonymous: _Anonymous_e__Union
    RawButtons: UInt32
    LastX: Int32
    LastY: Int32
    ExtraInformation: UInt32
    class _Anonymous_e__Union(Union):
        Buttons: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            ButtonFlags: UInt16
            ButtonData: UInt16
class MOUSE_UNIT_ID_PARAMETER(Structure):
    UnitId: UInt16
@winfunctype_pointer
def PFN_HidP_GetVersionInternal(Version: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PHIDP_INSERT_SCANCODES(Context: VoidPtr, NewScanCodes: win32more.Windows.Win32.Foundation.PSTR, Length: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
PHIDP_PREPARSED_DATA = IntPtr
class USAGE_AND_PAGE(Structure):
    Usage: UInt16
    UsagePage: UInt16


make_ready(__name__)
